@@ -81,6 +81,8 @@ public class Gate extends Supervisor {
 		// 遷移先を返して下さい。
 		// 遷移先ページを指定すると、input()は呼ばれず、output()を
 		// コールします。
+		// 詳しくは http://paraselene.sourceforge.jp/doku.php/31.topic3/1.illegalrequest
+		// を参照して下さい。
 		return null;
 	}
 
@@ -91,7 +93,7 @@ public class Gate extends Supervisor {
 	public int getRequestMaxCount() {
 		// 同時リクエスト数を制限する場合は、0より大きな値を返して下さい。
 		// 同時接続数がそれを超過するとステータス503を返します。
-		return 0;
+		return 40;
 	}
 
 	/**
@@ -101,6 +103,21 @@ public class Gate extends Supervisor {
 	public boolean isPRG() {
 		// SSLアクセラレータ使用時など、元のURLが取得不可能な状況となる場合は
 		// false を返して下さい。
+		// 詳しくは http://paraselene.sourceforge.jp/doku.php/31.topic3/4.faq
+		// を参照して下さい。
+		return true;
+	}
+
+	/**
+	 * セッション管理方法指定。
+	 * @return true:アクセス単位に分離、false:通常動作。
+	 */
+	public boolean isMultiStageSession() {
+		// リダイレクト動作が発生します。isPRG と同様の注意が必要です。
+		// SSLアクセラレータ使用時など、元のURLが取得不可能な状況となる場合は
+		// false を返して下さい。
+		// 詳しくは http://paraselene.sourceforge.jp/doku.php/31.topic3/4.faq
+		// を参照して下さい。
 		return true;
 	}
 }
