@@ -8,6 +8,7 @@ import paraselene.tag.*;
 import paraselene.tag.form.*;
 import paraselene.tag.list.*;
 import paraselene.tag.table.*;
+import paraselene.tag.ruby.*;
 import paraselene.dyna.*;
 import paraselene.css.*;
 import paraselene.ui.*;
@@ -16,36 +17,59 @@ import paraselene.ui.*;
  * サイトページ基底クラス。
  * 全てのページの共通メソッドを持たせたい場合にはこのクラスに記述できます。
  */
-public abstract class SuperPage extends Page {
+public abstract class SuperPage extends #1.#x.SuperPage implements Skin.PageInspecter {
+	private static final long serialVersionUID = 1L;
+	//--------------------------------------------------------------------
+	// HTMLテンプレートをサポートするためのコードです(ここから)
+	//--------------------------------------------------------------------
 	/**
-	 * name 属性の検証。
-	 * @param page 検証するページ
-	 * @param exclude 検証から除外する name。
-	 * @return エラーとなった name。
+	 * HTMLテンプレート。
+	 * 各引数は、実行環境に合わせて設定して下さい。
 	 */
-	public abstract NameDefine[] inspectName( Page page, String ... exclude );
+	protected static final Skin SKIN = new Skin(
+		DOMINION,
+		"UTF-8",	// URIデコード時の文字コード
+		null,		// paraselene.ui.UI は明示されずとも自動的に追加されます
+		// <param>タグでURIと判断する name 属性
+		"data", "codebase", "movie"
+	);
 	/**
-	 * 入力値の検証メイン処理。
-	 * @param req リクエスト内容。
-	 * @param fw デフォルト遷移先。
-	 * @exception PageException 処理の継続が不可能(ブラウザには500を返す)。
+	 * inspectNameで検証から除外するものがあれば指定して下さい。
+	 * @return 除外するname。
 	 */
-	public abstract Forward inputMain( RequestParameter req, Forward fw ) throws PageException;
+	protected String[] getExcludeName() {
+		return new String[0];
+	}
 	/**
-	 * 出力情報の設定メイン処理。
-	 * @param from 遷移元ページ。
-	 * @param req リクエスト内容。
-	 * @return 出力ページ。
-	 * nullを返すとthisをリターンしたのと同じ扱いにされます。
-	 * @exception PageException 処理の継続が不可能(ブラウザには500を返す)。
+	 * ページ検証。テンプレートとして適用不可ならば例外をスローして下さい。
+	 * @param page 検証するテンプレートを読み込んだページ。
+	 * @exception テンプレート適用処理の中断。
 	 */
-	public abstract Page outputMain( Page from, RequestParameter req ) throws PageException;
+	public void inspect( DynamicPage page ) throws Exception {
+		NameDefine[]	result = inspectName( page, getExcludeName() );
+		if ( result != null ) {
+			String	message = NameDefine.toString( result );
+			throw new Exception( message );
+		}
+	}
 	/**
-	 * 初回outputの呼び出しメイン処理。
-	 * @param req リクエスト内容。
-	 * @exception PageException 処理の継続が不可能(ブラウザには500を返す)。
+	 * テンプレート適用。
+	 * @exception DynamicPageException テンプレート適用失敗。
 	 */
-	public abstract void firstOutputMain( RequestParameter req ) throws PageException;
+	protected void apply() throws PageException {
+		try {
+			/* ディレクトリを示すパラメータは実行環境に合わせて指定して下さい。
+			   第二引数は、/で始まる文字列でなければなりません。
+			*/
+			SKIN.apply( new java.io.File( "#3" ), "", this, this );
+		}
+		catch( DynamicPageException e ) {
+			throw new PageException( e );
+		}
+	}
+	//--------------------------------------------------------------------
+	// HTMLテンプレートをサポートするためのコードです(ここまで)
+	//--------------------------------------------------------------------
 
 	/**
 	 * コンストラクタ。
@@ -141,6 +165,7 @@ public abstract class SuperPage extends Page {
 	 */
 	public AjaxSupport getAjaxSupport() {
 		return AjaxSupport.NO;
+		//return AjaxSupport.POPUP_DIALOG;
 	}
 
 	/**
@@ -151,7 +176,7 @@ public abstract class SuperPage extends Page {
 	 * @param fw デフォルト遷移先。
 	 * @exception PageException 処理の継続が不可能(ブラウザには500を返す)。
 	 */
-	public final Forward input( RequestParameter req, Forward fw ) throws PageException {
+	public Forward input( RequestParameter req, Forward fw ) throws PageException {
 		// 共通処理等あれば記述して下さい。
 		return inputMain( req, fw );
 	}
@@ -161,7 +186,10 @@ public abstract class SuperPage extends Page {
 	 * @param req リクエスト内容。
 	 * @exception PageException 処理の継続が不可能(ブラウザには500を返す)。
 	 */
-	public final void firstOutput( RequestParameter req ) throws PageException {
+	public void firstOutput( RequestParameter req ) throws PageException {
+	/* テンプレートHTMLを利用する場合は、apply()を呼び出して下さい。
+		apply();
+	 */
 		// 共通処理等あれば記述して下さい。
 		firstOutputMain( req );
 	}
@@ -174,7 +202,7 @@ public abstract class SuperPage extends Page {
 	 * nullを返すとthisをリターンしたのと同じ扱いにされます。
 	 * @exception PageException 処理の継続が不可能(ブラウザには500を返す)。
 	 */
-	public final Page output( Page from, RequestParameter req ) throws PageException {
+	public Page output( Page from, RequestParameter req ) throws PageException {
 		// 共通処理等あれば記述して下さい。
 		return outputMain( from, req );
 	}
