@@ -5,13 +5,14 @@ import paraselene.tag.*;
 import paraselene.tag.form.*;
 import paraselene.tag.list.*;
 import paraselene.tag.table.*;
+import paraselene.tag.ruby.*;
 import paraselene.css.*;
 import paraselene.dyna.*;
 
 /**
  * #3
  */
-public abstract class #4 extends #1.SuperPage #a{
+public abstract class #4 extends #1.#z#2.SuperPage #a{
 private static final long serialVersionUID = 1L;
 /**
  * コンストラクタ。
