@@ -65,17 +65,17 @@ public class HSL {
 	/**
 	 * 色相。値の範囲は、0 ～ 359 の角度表現です。<br>
 	 */
-	public int hue;
+	public double hue;
 	/**
 	 * 彩度。値の範囲は、0 ～ 100 です。<br>
 	 * 100は純色、0は灰色です。
 	 */
-	public int saturation;
+	public double saturation;
 	/**
 	 * 輝度。値の範囲は、0 ～ 100 です。<br>
 	 * 0は黒、100を白、50が純色です。
 	 */
-	public int lightness;
+	public double lightness;
 
 	/**
 	 * コンストラクタ。
@@ -83,13 +83,13 @@ public class HSL {
 	 * @param s 彩度。
 	 * @param l 輝度。
 	 */
-	public HSL( int h, int s, int l ) {
+	public HSL( double h, double s, double l ) {
 		hue = round( h );
 		saturation = per( s );
 		lightness = per( l );
 	}
 
-	private static int round( int r ) {
+	private static double round( double r ) {
 		while( true ) {
 			if ( r < 0 )	r += 360;
 			if ( r >= 360 )	r -= 360;
@@ -97,57 +97,60 @@ public class HSL {
 		}
 	}
 
-	private static int per( int p ) {
+	private static double per( double p ) {
 		if ( p < 0 )	return 0;
 		if ( p > 100 )	return 100;
 		return p;
 	}
 
-	private static int rgb_to_per( int v ) {
+	private static double rgb_to_per( double v ) {
+		if ( v > 0 )	v += 1;
 		return per( v * 100 / 256 );
 	}
 
-	private static int per_to_rgb( int v ) {
+	private static int per_to_rgb( double v ) {
 		v = v * 256 / 100;
 		if ( v > 255 )	v = 255;
+		if ( v < 255 )	v -= 1;
 		if ( v < 0 )	v = 0;
-		return v;
+		return (int)v;
 	}
 
-	private static int max( int ... v ) {
-		int	m = v[0];
+	private static double max( double ... v ) {
+		double	m = v[0];
 		for ( int i = 1; i < v.length; i++ ) {
 			if ( m < v[i] )	m = v[i];
 		}
 		return m;
 	}
 
-	private static int min( int ... v ) {
-		int	m = v[0];
+	private static double min( double ... v ) {
+		double	m = v[0];
 		for ( int  i = 1; i < v.length; i++ ) {
 			if ( m > v[i] )	m = v[i];
 		}
 		return m;
 	}
 
-	private static int toC( int v, int max, int min ) {
+	private static double toC( double v, double max, double min ) {
 		return (max - v) / (max - min);
 	}
 
 	static HSL getHSL( Color c ) {
-		int	r = rgb_to_per( c.getRed() );
-		int	g = rgb_to_per( c.getGreen() );
-		int	b = rgb_to_per( c.getBlue() );
-		int	max = max( r, g, b );
-		int	min = min( r, g, b );
-		int	l = (max + min) / 2, h = 0, s = 0;
+		double	r = rgb_to_per( c.getRed() );
+		double	g = rgb_to_per( c.getGreen() );
+		double	b = rgb_to_per( c.getBlue() );
+		double	max = max( r, g, b );
+		double	min = min( r, g, b );
+		double	l = per( (max + min) / 2 ), h = 0, s = 0;
 		if ( max != min ) {
 			s = ( l > 50 )?
-				(max - min) / ( 2 - max - min ):
+				(max - min) / ( 200 - max - min ):
 				(max - min) / ( max + min );
-			int	cr = toC( r, max, min );
-			int	cg = toC( g, max, min );
-			int	cb = toC( b, max, min );
+			s *= 100;
+			double	cr = toC( r, max, min );
+			double	cg = toC( g, max, min );
+			double	cb = toC( b, max, min );
 			if ( r == max ) {
 				h = cb - cg;
 			}
@@ -157,11 +160,12 @@ public class HSL {
 			else {
 				h = 4 + cg - cr;
 			}
+			h *= 60;
 		}
 		return new HSL( h, s, l );
 	}
 
-	private static int getH( int h, int max, int min ) {
+	private static double getH( double h, double max, double min ) {
 		h = round( h );
 		if ( h < 60 )	return min + (max - min) * h / 60;
 		if ( h < 180 )	return max;
@@ -170,21 +174,28 @@ public class HSL {
 	}
 
 	void toColor( Color c ) {
-		int	h = round( hue );
-		int	s = per( saturation );
-		int	l = per( lightness );
+		double	h = round( hue );
+		double	s = per( saturation );
+		double	l = per( lightness );
 		if ( s == 0 ) {
-			l = per_to_rgb( l );
-			c.setColor( l, l, l );
+			int v = per_to_rgb( l );
+			c.setColor( v, v, v );
 			return;
 		}
-		int	max = (l > 50)?	l * (100 - s) + s:	l * ( 100 + s );
-		int	min = 2 * l - max;
+		double	max = (l > 50)?	l * (100 - s) + s:	l * ( 100 + s );
+		double	min = 2 * l - max;
 		int	r = per_to_rgb( getH( h + 120, max, min ) );
 		int	g = per_to_rgb( getH( h, max, min ) );
 		int	b = per_to_rgb( getH( h - 120, max, min ) );
 		c.setColor( r, g, b );
 	}
 
+	/**
+	 * 文字列化。
+	 * @return hsl(xx,xx%,xx%)の形式で返します。
+	 */
+	public String toString() {
+		return String.format( "hsl(%f, %f%%, %f%%)", hue, saturation, lightness );
+	}
 }
 
