@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2012  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -18,6 +18,33 @@ import paraselene.supervisor.*;
 import paraselene.tag.form.*;
 import paraselene.ajax.data.*;
 
+class EclipseForm extends Form {
+	private static final String NAME = "paraselene_back_form";
+	static final String MYFORM = "forms['" + NAME + "']";
+	EclipseForm( Page p ) {
+		super();
+		try {
+			setAttribute( p.createURI( "action", PageFactory.PARASELENE_SERVICE ) );
+			setAttribute( "name", NAME );
+		}
+		catch( Page.PageException e ) {}
+		Input	hidden = Input.createHidden( PageFactory.CLOSE_ID, "" );
+		hidden.setAttribute( "id", PageFactory.CLOSE_ID );
+		addHTMLPart( hidden );
+	}
+	private String	agency = null;
+	String getAgency() {
+		if ( agency != null )	return agency;
+		StringBuilder	buf = new StringBuilder( "paraselene.back_handler(" );
+		buf = buf.append( MYFORM ).append( "," );
+		buf = buf.append( get_id( form_ajax.makeID() ) ).append( "," );
+		buf = buf.append( get_id( form_dummy.makeID() ) ).append( "," );
+		buf = buf.append( "'" );
+		buf = buf.append( getAssignedPage().getUniqueKey() );
+		buf = buf.append( "');" );
+		return agency = buf.toString();
+	}
+}
 
 /**
  * HTMLページ。
@@ -26,12 +53,12 @@ public abstract class Page implements Serializable {
 	/**
 	 * ページ処理中例外。
 	 */
-	public class PageException extends Exception {
+	public static class PageException extends Exception {
 		private Throwable ex = null;
 		private Object	obj = null;
 		private Page	page;
 		private RequestParameter	request;
-		private boolean	input_call;
+		private volatile boolean	input_call;
 		/**
 		 * コンストラクタ。
 		 * 別の例外をラップします。
@@ -187,20 +214,27 @@ public abstract class Page implements Serializable {
 	private ArrayList<Clickable>	clickable = new ArrayList<Clickable>();
 	private Page	parent_page = null;
 
-	private int name_seq = 0;
+	private volatile int name_seq = 0;
 	private Tag	contents = null;
-	private boolean init_f = true;
+	private volatile boolean init_f = true;
 
-	private boolean xml_f = false;
+	private volatile boolean xml_f = false;
 	private String	doctype_def = null;
 	private static final long serialVersionUID = 2L;
 
-	private Popup.Type popup_type = null;
+	private DialogType popup_type = null;
+	private Tag	popup_hint = null;
 
 	private static volatile short page_id;
 	private static final Object	obj4uniKey = new Object();
 	private String uniKey;
 
+	private Date	make_date = new Date();
+	/**
+	 * インスタンスが作られた時間を返します。
+	 */
+	public Date getCreateDate() { return make_date; }
+
 	/**
 	 * 親ページの取得。
 	 * @return 親ページ、もしくは this を返す。
@@ -223,7 +257,9 @@ public abstract class Page implements Serializable {
 	 * @return PageBypassedDivの配列。無ければ 0 個の配列を返します。
 	 */
 	public PageBypassedDiv[] getPageBypassedDiv() {
-		return bypass.toArray( new PageBypassedDiv[0] );
+		synchronized( bypass ) {
+			return bypass.toArray( new PageBypassedDiv[0] );
+		}
 	}
 
 	private static PageHooker[] sort( PageHooker[] ph ) {
@@ -243,7 +279,9 @@ public abstract class Page implements Serializable {
 	 * @return PageHookerの配列。無ければ 0 個の配列を返します。
 	 */
 	public PageHooker[] getPageHooker() {
-		return sort( hook.toArray( new PageHooker[0] ) );
+		synchronized( hook ) {
+			return sort( hook.toArray( new PageHooker[0] ) );
+		}
 	}
 
 	private void makeKey() {
@@ -264,15 +302,24 @@ public abstract class Page implements Serializable {
 	 * @return ポップアップ状態。
 	 * ポップアップでなければ null です。
 	 */
-	public Popup.Type getPopupType() {
+	public DialogType getPopupType() {
 		return popup_type;
 	}
 
+	/**
+	 * ポップアップ表示する基準のタグを返します。
+	 * @return タグ。基準がなければnull。
+	 */
+	public Tag getPopupHint() {
+		return popup_hint;
+	}
+
 	/**
 	 * 使用しないで下さい。
 	 */
-	public void setPopupType( Popup.Type type ) {
+	public void setPopupType( DialogType type, Tag hint ) {
 		popup_type = type;
+		popup_hint = hint;
 	}
 
 	/**
@@ -357,7 +404,7 @@ public abstract class Page implements Serializable {
 		init_f = flag;
 		if ( flag && beginning_called ) {
 			beginning_called = false;
-			beginning( now_req );
+			beginning( now_req, null );
 		}
 	}
 
@@ -378,8 +425,10 @@ public abstract class Page implements Serializable {
 	 */
 	public String[] getDefineNameIndex() {
 		ArrayList<String>	list = new ArrayList<String>();
-		for ( String k:	tag_m_dic.keySet() ) {
-			list.add( k );
+		synchronized( tag_m_dic ) {
+			for ( String k:	tag_m_dic.keySet() ) {
+				list.add( k );
+			}
 		}
 		return list.toArray( new String[0] );
 	}
@@ -390,8 +439,10 @@ public abstract class Page implements Serializable {
 	 */
 	public String[] getDefineName() {
 		ArrayList<String>	list = new ArrayList<String>();
-		for ( String k: tag_1_dic.keySet() ) {
-			list.add( k );
+		synchronized( tag_1_dic ) {
+			for ( String k: tag_1_dic.keySet() ) {
+				list.add( k );
+			}
 		}
 		return list.toArray( new String[0] );
 	}
@@ -495,55 +546,53 @@ public abstract class Page implements Serializable {
 	 */
 	public Page reflect( RequestParameter req ) {
 		clicked_tag = null;
-		int	click_cnt = clickable.size();
-		for ( int i = 0; i < click_cnt; i++ ) {
-			Clickable	c = clickable.get( i );
-			c.setClicked( false );
-		}
+		synchronized( clickable ) {
+			int	click_cnt = clickable.size();
+			for ( int i = 0; i < click_cnt; i++ ) {
+				Clickable	c = clickable.get( i );
+				c.setClicked( false );
+			}
 
-		if ( agency_page != null ) {
-			Page	page = agency_page.reflect( req );
-			if ( page != null )	return page;
-		}
-
-		PageBypassedDiv[]	div = getPageBypassedDiv();
-		for ( int i = 0; i < div.length; i++ ) {
-			Page	page = div[i].getBypassPage();
-			if ( page != null ) {
-				page = page.reflect( req );
+			if ( agency_page != null ) {
+				Page	page = agency_page.reflect( req );
 				if ( page != null )	return page;
 			}
-		}
-		modified = new Control[0];
-		if ( getMainTag() == null )	return null;
 
-		for ( int i = 0; i < click_cnt; i++ ) {
-			Clickable	c = clickable.get( i );
-			if ( c.isClicked( req ) ) {
-				clicked_tag = c;
-				c.setClicked( true );
-				break;
+			PageBypassedDiv[]	div = getPageBypassedDiv();
+			for ( int i = 0; i < div.length; i++ ) {
+				Page	page = div[i].getBypassPage();
+				if ( page != null ) {
+					page = page.reflect( req );
+					if ( page != null )	return page;
+				}
+			}
+			modified = new Control[0];
+			if ( getMainTag() == null )	return null;
+
+			for ( int i = 0; i < click_cnt; i++ ) {
+				Clickable	c = clickable.get( i );
+				if ( c.isClicked( req ) ) {
+					clicked_tag = c;
+					c.setClicked( true );
+					break;
+				}
 			}
 		}
 		if ( clicked_tag instanceof Anchor )	return this;
 
-		ArrayList<Form>	form = getForm( getMainTag(), new ArrayList<Form>() );
-		int	form_cnt = form.size();
 		String	form_id = "paraselene_form_id";	// 不一致用ダミー
 		RequestItem	item = req.getItem( Form.FORM_ID );
 		if ( item != null ) {
 			form_id = item.getValue();
 		}
-		for ( int i = form_cnt - 1; i >= 0; i-- ) {
-			Form	f = form.get( i );
-			if ( !f.getID().equals( form_id ) ) {
-				form.remove( i );
-			}
-		}
 		ArrayList<Control>	list = new ArrayList<Control>();
-		form_cnt = form.size();
-		for ( int i = 0; i < form_cnt; i++ ) {
-			list.addAll( form.get( i ).reflect( req ) );
+		boolean	hit = false;
+		for ( Form f: getForm( getMainTag(), new ArrayList<Form>() ) ) {
+			if ( f.getID().equals( form_id ) ) {
+				list.addAll( f.reflect( req ) );
+				hit = true;
+				break;
+			}
 		}
 		modified = list.toArray( new Control[0] );
 		if ( modified.length > 0 ) {
@@ -556,7 +605,7 @@ public abstract class Page implements Serializable {
 		}
 
 		if ( getClickedTag() != null )	return this;
-		if ( form_cnt > 0 )	return this;
+		if ( hit )	return this;
 		return null;
 	}
 
@@ -587,7 +636,7 @@ public abstract class Page implements Serializable {
 	 */
 	public Attribute createURI( String name, String uri ) throws PageException {
 		try {
-			return new Attribute( name, new URIValue( uri, getCharset() ) );
+			return new Attribute( name, new URIValue( uri, getParentPage().getCharset() ) );
 		}
 		catch( Exception e ) {
 			throw new PageException( e );
@@ -665,7 +714,7 @@ public abstract class Page implements Serializable {
 			buf = buf.append( fragment );
 		}
 		try {
-			URIValue	uv = new URIValue( buf.toString(), getCharset() );
+			URIValue	uv = new URIValue( buf.toString(), getParentPage().getCharset() );
 			if ( query.length > 0 ) {
 				uv.setQuery( query );
 			}
@@ -681,7 +730,8 @@ public abstract class Page implements Serializable {
 	 * 別名URI中の部分文字列取得。
 	 * 別名URI(接頭辞)と.na(接尾辞)を省いた部分文字列を取得します。
 	 * @param req リクエスト。
-	 * @return 部分文字列。
+	 * @return 部分文字列。Alias呼び出しでなければnull。
+	 * 接頭辞と接尾辞を省いた結果が空文字列ならば、空文字列を返します。
 	 */
 	public String pickAliasURI( RequestParameter req ) {
 		String	alias = getAliasURI();
@@ -689,7 +739,7 @@ public abstract class Page implements Serializable {
 			return null;
 		}
 		if ( TransactionSequencer.EXTENSION.equals( alias.substring( alias.length() - 3 ) ) ) {
-			return null;
+			return "";
 		}
 		String	uri = req.getURI().getPath();
 		String[] path = uri.split( "/" );
@@ -719,7 +769,9 @@ public abstract class Page implements Serializable {
 	 * @return タグ。配列化されたタグならnullを返します。
 	 */
 	public Tag getTag( String name ) {
-		return tag_1_dic.get( name );
+		synchronized( tag_1_dic ) {
+			return tag_1_dic.get( name );
+		}
 	}
 
 	/**
@@ -731,7 +783,10 @@ public abstract class Page implements Serializable {
 		if ( name == null )	return new Tag[0];
 		String[]	pre = name.split( "\\$" );
 		ArrayList<Tag>	list = new ArrayList<Tag>();
-		HashMap<String,Tag>	map = tag_m_dic.get( pre[0] );
+		HashMap<String,Tag>	map = null;
+		synchronized( tag_m_dic ) {
+			map = tag_m_dic.get( pre[0] );
+		}
 		if ( map == null )	return new Tag[0];
 		for ( String k : map.keySet() ) {
 			list.add( map.get( k ) );
@@ -790,14 +845,24 @@ public abstract class Page implements Serializable {
 	}
 
 	private void clearDic( String name ) {
-		Tag	tag = tag_1_dic.remove( name );
-		name_dic.remove( tag );
+		Tag	tag = null;
+		synchronized( tag_1_dic ) {
+			tag = tag_1_dic.remove( name );
+		}
+		synchronized( name_dic ) {
+			name_dic.remove( tag );
+		}
 		String	index = getIndexName( name );
-		HashMap<String,Tag>	map = tag_m_dic.get( index );
+		HashMap<String,Tag>	map = null;
+		synchronized( tag_m_dic ) {
+			map = tag_m_dic.get( index );
+		}
 		if ( map == null )	return;
 		map.remove( name );
 		if ( map.size() == 0 ) {
-			tag_m_dic.remove( index );
+			synchronized( tag_m_dic ) {
+				tag_m_dic.remove( index );
+			}
 		}
 	}
 
@@ -806,14 +871,19 @@ public abstract class Page implements Serializable {
 		String	index = getIndexName( org_name );
 		for ( ; ; name_seq++ ) {
 			org_name = String.format( "%s$%d", index, name_seq );
-			if ( tag_1_dic.get( org_name ) == null )	break;
+			synchronized( tag_1_dic ) {
+				if ( tag_1_dic.get( org_name ) == null )	break;
+			}
 		}
 		return org_name;
 	}
 
 	private void nameTagSingle(Tag tag ) {
 		if ( tag == null )	return;
-		String	old_name = name_dic.get( tag );
+		String	old_name = null;
+		synchronized( name_dic ) {
+			old_name = name_dic.get( tag );
+		}
 		String	new_name = tag.getNameAttribute();
 		if ( old_name == null && new_name == null ) return;
 		if ( old_name != null && new_name == null ) {
@@ -824,21 +894,29 @@ public abstract class Page implements Serializable {
 			if ( old_name.equals( new_name ) )	return;
 			clearDic( old_name );
 		}
-		if ( tag_1_dic.get( new_name ) != null ) {
-			new_name = extendName( tag );
-			try {
-				tag.setAttribute( new Attribute( "name", new_name ) );
+		synchronized( tag_1_dic ) {
+			if ( tag_1_dic.get( new_name ) != null ) {
+				new_name = extendName( tag );
+				try {
+					tag.setAttribute( new Attribute( "name", new_name ) );
+				}
+				catch( Exception e ) {}
 			}
-			catch( Exception e ) {}
+			tag_1_dic.put( new_name, tag );
+		}
+		synchronized( name_dic ) {
+			name_dic.put( tag, new_name );
 		}
-
-		tag_1_dic.put( new_name, tag );
-		name_dic.put( tag, new_name );
 		String	index = getIndexName( new_name );
-		HashMap<String,Tag>	map = tag_m_dic.get( index );
+		HashMap<String,Tag>	map = null;
+		synchronized( tag_m_dic ) {
+			map = tag_m_dic.get( index );
+		}
 		if ( map == null ) {
 			map = new HashMap<String,Tag>();
-			tag_m_dic.put( index, map );
+			synchronized( tag_m_dic ) {
+				tag_m_dic.put( index, map );
+			}
 		}
 		map.put( new_name, tag );
 	}
@@ -851,13 +929,19 @@ public abstract class Page implements Serializable {
 		if ( getMainTag() == null )	return;
 		tag.setAssignedPage( this );
 		if ( tag instanceof PageHooker ) {
-			hook.add( (PageHooker)tag );
+			synchronized( hook ) {
+				hook.add( (PageHooker)tag );
+			}
 		}
 		if ( tag instanceof PageBypassedDiv ) {
-			bypass.add( (PageBypassedDiv)tag );
+			synchronized( bypass ) {
+				bypass.add( (PageBypassedDiv)tag );
+			}
 		}
 		if ( tag instanceof Clickable ) {
-			clickable.add( (Clickable)tag );
+			synchronized( clickable ) {
+				clickable.add( (Clickable)tag );
+			}
 		}
 
 		String	name = tag.getNameAttribute();
@@ -905,13 +989,19 @@ public abstract class Page implements Serializable {
 		}
 		tag.setAssignedPage( null );
 		if ( tag instanceof PageHooker ) {
-			hook.remove( (PageHooker)tag );
+			synchronized( hook ) {
+				hook.remove( (PageHooker)tag );
+			}
 		}
 		if ( tag instanceof PageBypassedDiv ) {
-			bypass.remove( (PageBypassedDiv)tag );
+			synchronized( bypass ) {
+				bypass.remove( (PageBypassedDiv)tag );
+			}
 		}
 		if ( tag instanceof Clickable ) {
-			clickable.remove( (Clickable)tag );
+			synchronized( clickable ) {
+				clickable.remove( (Clickable)tag );
+			}
 		}
 		String	name = tag.getNameAttribute();
 		if ( name == null )	return;
@@ -959,6 +1049,18 @@ public abstract class Page implements Serializable {
 		Tag	tag = src.getMainTag();
 		src.setMainTag( null );
 		setMainTag( tag );
+		setDoctype( src.isXML(), src.getDoctype() );
+	}
+
+	/**
+	 * 内容のコピー。moveMainTag と異なり、src が持つ&lt;html&gt;のレプリカを
+	 * this へ上書きします。src の内容は残ったままとなります。<br>
+	 * moveMainTag より処理速度に劣ります。
+	 * @param src 元のページ。
+	 */
+	public void copyMainTag( Page src ) {
+		setMainTag( (Tag)src.getMainTag().getReplica() );
+		setDoctype( src.isXML(), src.getDoctype() );
 	}
 
 	/**
@@ -1028,7 +1130,7 @@ public abstract class Page implements Serializable {
 		StringBuilder	buf = new StringBuilder();
 		if ( isXML() ) {
 			buf = buf.append( "<?xml version=\"1.0\" encoding=\"" );
-			buf = buf.append( getCharset() );
+			buf = buf.append( getParentPage().getCharset() );
 			buf = buf.append( "\"?>" );
 		}
 		String	doc = getDoctype();
@@ -1051,14 +1153,15 @@ public abstract class Page implements Serializable {
 	 * @param script 実行スクリプト。各Stringには改行が付けられます。
 	 */
 	public void addOnLoadScript( String ... script ) {
+		if ( script == null )	return;
 		paraselene.ajax.data.JavaScript	js = null;
 		if ( getOnloadTag().getHTMLPartCount() == 0 ) {
-			js = new paraselene.ajax.data.JavaScript( script );
+			js = new paraselene.ajax.data.JavaScript( true, script );
 			getOnloadTag().addHTMLPart( js );
 			return;
 		}
 		js = (paraselene.ajax.data.JavaScript)getOnloadTag().getHTMLPart( 0 );
-		js.append( script );
+		js.appendWithCRLF( script );
 	}
 
 	/**
@@ -1069,20 +1172,65 @@ public abstract class Page implements Serializable {
 		return getOnloadTag().getHTMLPart( 0 ).toString();
 	}
 
+	private static String css_escape( int cnt, String style ) {
+		if ( style == null )	return "";
+		StringBuilder	buf = new StringBuilder();
+		char[]	data = style.toCharArray();
+		for ( int i = 0; i < data.length; i++ ) {
+			if ( data[i] == '\\' ) {
+				for ( int j = 0; j < cnt; j++ )	buf = buf.append( '\\' );
+				for ( ; i < data.length; i++ ) {
+					if ( data[i] != '\\' )	break;
+				}
+				i--;
+				continue;
+			}
+			buf = buf.append( data[i] );
+		}
+		return buf.toString();
+	}
+
+	/**
+	 * ロード時にスタイルシートを適用します。<br>
+	 * &lt;head&gt;タグに&lt;style&gt;タグを追加します。
+	 * @param style 適用CSS。
+	 */
+	public void addOnLoadStyle( String ... style ) {
+		StringBuilder	css = new StringBuilder();
+		for ( String s: style ) {
+			for ( char ch: s.toCharArray() ) {
+				if ( ch < ' ' )	continue;
+				css = css.append( ch );
+			}
+		}
+		String	css_str = css.toString();
+
+		Tag	tag = new Tag( "style", false );
+		tag.setAttribute( "type", "text/css" );
+		tag.addHTMLPart( new PlainText( css_escape( 1, css_str ) ) );
+		getFirstTagByType( "head" ).addHTMLPart( tag );
+
+		StringBuilder	buf = new StringBuilder( "paraselene.add_css('" );
+		buf = buf.append( css_escape( 2, css_str ) );
+		addOnLoadScript( buf.append( "');" ).toString() );
+	}
+
 	/**
 	 * ロード時に実行する JavaScript をクリアします。
 	 * Paraselene 自身も JavaScript を登録しています。
 	 * 不用意にクリアしないで下さい。
 	 */
 	public void resetOnLoadScript() {
+		if ( this instanceof Downloadable )	return;
 		getOnloadTag().removeHTMLPart();
-		getOnloadTag().addHTMLPart( new paraselene.ajax.data.JavaScript() );
+		getOnloadTag().addHTMLPart( new paraselene.ajax.data.JavaScript( true ) );
 		if ( getAjaxSupport() == Page.AjaxSupport.SERVER_PUSH ) {
 			StringBuilder	buf = new StringBuilder( "paraselene.comet_start('" );
 			buf = buf.append( getUniqueKey() );
 			buf = buf.append( "');" );
 			addOnLoadScript( buf.toString() );
 		}
+		for ( Form f: getForm( getMainTag(), new ArrayList<Form>()) )	f.resetOnLoadScript();
 	}
 
 	/**
@@ -1092,7 +1240,7 @@ public abstract class Page implements Serializable {
 	public void write( PrintWriter w ) throws UnsupportedEncodingException, URISyntaxException {
 		if ( isXML() ) {
 			w.print( "<?xml version=\"1.0\" encoding=\"" );
-			w.print( getCharset() );
+			w.print( getParentPage().getCharset() );
 			w.println( "\"?>" );
 		}
 		String	doc = getDoctype();
@@ -1200,21 +1348,29 @@ public abstract class Page implements Serializable {
 	/**
 	 * フレームワークが使用します。ここからfirstOutputが呼ばれます。
 	 */
-	public void beginning( RequestParameter req ) throws PageException {
+	public void beginning( RequestParameter req, Object p ) throws PageException {
 		if ( beginning_called )	return;
 		beginning_called = true;
 		if ( getMainTag() == null )	return;
 		body_tag = getFirstTagByType( "body" );
-		firstOutput( req );
+		if ( this instanceof EphemeralPage && p != null )	((EphemeralPage)this).firstOutput( req, p );
+		else	firstOutput( req );
 		body_tag = getFirstTagByType( "body" );
 		if ( this instanceof FramesetPage || this instanceof Downloadable ) {
 			ajax_f = false;
+			Option.trace( "%s |ajax_f=%s", getID(), ajax_f );
 			return;
 		}
 		ajax_f = true;
+		Option.trace( "%s |ajax_f=%s", getID(), ajax_f );
+		Tag	head = getFirstTagByType( "head" );
+		if ( head != null && pickAliasURI( req ) != null ) {
+			Tag	meta = new Tag( "meta", true );
+			meta.setAttribute( new Attribute( "name", "robots" ), new Attribute( "content", "none" ) );
+			head.addHTMLPart( 0, meta );
+		}
 		if ( getAccessedMobile() == RequestParameter.Mobile.NO_MOBILE && getAccessedSearchEngine() == RequestParameter.SearchEngine.NO_SEARCHENGINE ) {
 			AjaxSupport	ajax = getAjaxSupport();
-			Tag	head = getFirstTagByType( "head" );
 			Tag	body = body_tag;
 			if ( head != null ) {
 				int	idx = 0;
@@ -1238,7 +1394,10 @@ public abstract class Page implements Serializable {
 					Option.debug( e );
 				}
 			}
-			else	ajax_f = false;
+			else {
+				ajax_f = false;
+				Option.trace( "%s |ajax_f=%s", getID(), ajax_f );
+			}
 			if ( head != null && body != null && ajax != AjaxSupport.NO && getPopupType() == null ) {
 				Tag	script = new Tag( "script", false );
 				try {
@@ -1257,9 +1416,8 @@ public abstract class Page implements Serializable {
 				div[0].include( body, true );
 				body_tag = div[0];
 				Tag eclipse = new Tag( "div", false );
-				eclipse.setAttribute(
-					new Attribute( "id", AJAX_BLACK_ID )
-				);
+				EclipseForm	ec_form = new EclipseForm( this );
+				eclipse.addHTMLPart( ec_form );
 				Tag	temp = new Tag( "iframe", false );
 				temp.setAttribute(
 					new Attribute( "id", AJAX_TEMP_ID ),
@@ -1279,18 +1437,33 @@ public abstract class Page implements Serializable {
 				);
 				body.removeHTMLPart();
 				body.addHTMLPart( div[0], div[1], getOnloadTag() );
-				resetOnLoadScript();
+				eclipse.setAttribute(
+					new Attribute( "id", AJAX_BLACK_ID ),
+					new Attribute( "onclick", ec_form.getAgency() )
+				);
+				//resetOnLoadScript();
+			}
+			else {
+				ajax_f = false;
+				Option.trace( "%s |ajax_f=%s", getID(), ajax_f );
 			}
-			else	ajax_f = false;
 		}
-		else	ajax_f = false;
+		else {
+			ajax_f = false;
+			Option.trace( "%s |ajax_f=%s", getID(), ajax_f );
+			Option.trace( "%s %s", getAccessedMobile(), getAccessedSearchEngine() );
+		}
 		if ( getPopupType() != null ) {
 			ajax_f = true;
-			resetOnLoadScript();
+			Option.trace( "%s |ajax_f=%s", getID(), ajax_f );
+			//resetOnLoadScript();
 		}
 	}
 
 	private String	root_id;
+	/**
+	 * フレームワークが使用します。
+	 */
 	public String getRootID() {
 		return root_id;
 	}
@@ -1299,10 +1472,11 @@ public abstract class Page implements Serializable {
 	private static final String	AJAX_TARGET_ID = "paraseleneDragonsTail";
 	private static final String	AJAX_TEMP_ID = "paraseleneOoltCloud";
 	private static final String	AJAX_ADD_ID = "paraseleneDragonsHead";
-	private boolean ajax_f = false;
+	private volatile boolean ajax_f = false;
 	private RequestParameter	now_req;
 	private RequestParameter.Mobile			access_mobile;
 	private RequestParameter.SearchEngine	access_se;
+	private RequestParameter.SmartPhone	access_sp;
 	private Tag	onload_tag = null;
 	private Tag	body_tag = null;
 
@@ -1372,9 +1546,11 @@ public abstract class Page implements Serializable {
 	 */
 	public void setRequestParameter( RequestParameter req ) {
 		now_req = req;
+		Option.trace( "%s#setRequestParameter(%s)", getID(), req );
 		if ( req != null ) {
 			access_mobile = req.judgeMobile();
 			access_se = req.judgeSearchEngine();
+			access_sp = req.judgeSmartPhone();
 		}
 	}
 
@@ -1383,6 +1559,7 @@ public abstract class Page implements Serializable {
 	 * @return 携帯判定結果。
 	 */
 	public RequestParameter.Mobile getAccessedMobile() {
+		if ( access_mobile == null )	return RequestParameter.Mobile.NO_MOBILE;
 		return access_mobile;
 	}
 	/**
@@ -1390,9 +1567,21 @@ public abstract class Page implements Serializable {
 	 * @return 検索エンジン判定結果。
 	 */
 	public RequestParameter.SearchEngine getAccessedSearchEngine() {
+		if ( access_se == null )	return RequestParameter.SearchEngine.NO_SEARCHENGINE;
 		return access_se;
 	}
+	/**
+	 * RequestParameterから得られたRequestParameter.SmartPhoneを返します。
+	 * @return スマートフォン判定結果。
+	 */
+	public RequestParameter.SmartPhone getAccessedSmartPhone() {
+		if ( access_sp == null )	return RequestParameter.SmartPhone.NO_SMARTPHONE;
+		return access_sp;
+	}
 
+	/**
+	 * フレームワークが使用します。
+	 */
 	public Tag[] getModifiedTag() {
 		Tag	tag = getFirstTagByType( "body" );
 		if ( tag == null )	return new Tag[0];
@@ -1588,5 +1777,47 @@ public abstract class Page implements Serializable {
 	public boolean isEncodeURL() {
 		return false;
 	}
+
+	private Attribute replaceFeedbackURI( Attribute atr, String[] org ) {
+		if ( atr == null )	return null;
+		AttributeValuable	v = atr.get();
+		if ( v == null )	return null;
+		if ( !(v instanceof URIValue) )	return null;
+		URIValue	uri = (URIValue)v;
+		URI	u = uri.getURI();
+		if ( u.isAbsolute() )	return null;
+		QueryItem[]	query = uri.getQuery();
+		String	path = u.getPath();
+		String	f = u.getFragment();
+		for ( String s: org ) {
+			try {
+				if ( path.equals( s ) )	return createPageToURI( atr.getName(), getID(), f, query );
+			}
+			catch( PageException e ) { return null; }
+		}
+		return null;
+	}
+	/**
+	 * 画面遷移先URIの Feedback URI への置換。
+	 * &lt;a&gt;のhrefと、&lt;form&gt;のactionを置換対象とします。<br>
+	 * それぞれの属性値が引数のどれかと完全一致した場合、自ページへ遷移する URI に
+	 * 置換します。<br>
+	 * 属性値が絶対パスであると置換しません。相対パスのみ置換対象とします。<br>
+	 * 文字列比較はパス部分のみで、クエリやフラグメントは含みません。
+	 * 置換後のクエリやフラグメントは、置換前のものを引き継ぎます。
+	 * @param org 置換するURIパス文字列。クエリやフラグメントは含めないで下さい。
+	 */
+	public void replaceFeedbackURI( String ... org ) {
+		Tag[]	tag = getAllTagByType( "a" );
+		for ( Tag a:	tag ) {
+			Attribute	atr = replaceFeedbackURI( a.getAttribute( "href" ), org );
+			if ( atr != null )	a.setAttribute( atr );
+		}
+		tag = getAllTagByType( "form" );
+		for ( Tag form:	tag ) {
+			Attribute	atr = replaceFeedbackURI( form.getAttribute( "action" ), org );
+			if ( atr != null )	form.setAttribute( atr );
+		}
+	}
 }
 
