@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -15,7 +15,7 @@ import java.io.*;
  */
 public class PlainText extends HTMLPart {
 	private static final long serialVersionUID = 2L;
-	private String	text;
+	private String	text = "";
 
 	protected PlainText() {}
 
@@ -46,7 +46,7 @@ public class PlainText extends HTMLPart {
 	}
 
 	public HTMLPart getReplica() {
-		return new PlainText( toString( StringMode.PLAIN ) );
+		return new PlainText( text );
 	}
 
 	/**
@@ -56,6 +56,18 @@ public class PlainText extends HTMLPart {
 	public Valuable getValuableReplica() {
 		return (Valuable)getReplica();
 	}
+
+	/**
+	 * 各引数文字列末尾に改行コードを付けて文字列を追加します。
+	 * @param str 追加文字列。
+	 */
+	public void appendWithCRLF( String ... str ) {
+		StringBuilder	buf = new StringBuilder( text );
+		for( String s: str ) {
+			buf = buf.append( s ).append( "\r\n" );
+		}
+		setText( buf.toString() );
+	}
 }
 
 
