@@ -58,7 +58,9 @@ public class QueryItem implements Serializable {
 	public String toString() {
 		StringBuilder	buf = new StringBuilder( name );
 		buf = buf.append( "=" );
-		buf = buf.append( value );
+		if ( value != null ) {
+			buf = buf.append( value );
+		}
 		return buf.toString();
 	}
 }
