@@ -203,16 +203,12 @@ public class Text extends PlainText implements AttributeValuable, CSSValuable {
 				continue;
 			}
 			spc_cnt = 0;
-			if ( line[i] == '"' ) {
-				buf = buf.append( "&quot;" );
+			WebChar	wc = WebChar.getWebChar( line[i] );
+			if ( wc != null ) {
+				buf = buf.append( wc.getReference() );
 				continue;
 			}
 			if ( mode != StringMode.ATTRIBUTE ) {
-				WebChar	wc = WebChar.getWebChar( line[i] );
-				if ( wc != null ) {
-					buf = buf.append( wc.getReference() );
-					continue;
-				}
 				if ( mode != StringMode.TEXTAREA ) {
 					if ( line[i] == '\n' || line[i] == '\r' ) {
 						if ( i > 0 ) {
