@@ -43,7 +43,7 @@ public class URIValue extends PlainText implements AttributeValuable, CSSValuabl
 	private String getCharset() {
 		if ( out_enc != null )	return out_enc;
 		String	ret = null;
-		ret = getAssignedTag().getAssignedPage().getCharset();
+		ret = getAssignedTag().getAssignedPage().getParentPage().getCharset();
 		if ( ret != null )	return ret;
 		return DEFAULT_ENC;
 	}
