@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -15,11 +15,13 @@ public class Close implements Serializable {
 
 	public String	page_id = "";
 	public boolean	modal = false;
+	public boolean	menu = false;
 
 	private Close(){}
 	public Close( Page page ) {
 		page_id = page.getUniqueKey();
 		modal = Popup.Type.isMode( page );
+		menu = Popup.Type.isAutoClose( page );
 	}
 }
 
