@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -26,6 +26,10 @@ public class Open extends TagData {
 	public boolean	move = false;
 	public boolean	active = false;
 
+	public boolean	menu = false;
+	public int		position = 0;
+	public String	hint_id = null;
+
 	private Open(){
 		super();
 	}
@@ -50,10 +54,19 @@ public class Open extends TagData {
 	}
 
 	private CSSValuable[] shift( Color org, int v ) {
-		YUV	yuv = org.getYUV();
-		if ( yuv.y < 128 )	yuv.y += v;
-		else	yuv.y -= v;
-		return new CSSValuable[] { new Color( yuv ) };
+		HSL	hsl = org.getHSL();
+		if ( hsl.lightness < 50 )	hsl.lightness += v;
+		else	hsl.lightness -= v;
+		return new CSSValuable[] { new Color( hsl ) };
+	}
+
+	private static int getPositionNo( DialogType.Position p ) {
+		DialogType.Position[]	val = DialogType.Position.values();
+		int	no = 0;
+		for ( ; no < val.length; no++ ) {
+			if ( val[no] == p )	break;
+		}
+		return no;
 	}
 
 	public Open( Page page, boolean act_f ) {
@@ -63,8 +76,8 @@ public class Open extends TagData {
 		CSSValuable[]	st = page.getPopupBackGround();
 		Color	c = getColor( st );
 		bg = toBg( st );
-		bg2 = toBg( shift( c, 48 ) );
-		border = toBg( shift( c, 24 ) );
+		bg2 = toBg( shift( c, 20 ) );
+		border = toBg( shift( c, 10 ) );
 
 		HTMLPart[]	title_part = page.getTitleLabel();
 		StringBuilder	buf = new StringBuilder();
@@ -72,14 +85,19 @@ public class Open extends TagData {
 			buf = buf.append( title_part[i].toString( HTMLPart.StringMode.BODY ) );
 		}
 		title = buf.toString();
-		Popup.Type	ptype = page.getPopupType();
+		DialogType	ptype = page.getPopupType();
 		if ( ptype != null ) {
 			modal = ptype.isMode();
 			move = ptype.isTitle();
+			menu = ptype.isAutoClose();
+			position = getPositionNo( ptype.getPosition() );
+			if ( position != 0 )	hint_id = page.getPopupHint().getIDAttribute();
 		}
 		else {
 			modal = true;
 			move = true;
+			menu = false;
+			position = 0;
 		}
 		active = act_f;
 	}
