@@ -6,12 +6,14 @@
  */
 package paraselene.ajax.data;
 
+import paraselene.supervisor.*;
 import java.io.*;
 
 public class PostBack implements Serializable {
 	private static final long serialVersionUID = 2L;
 
 	public String	location = null;
+	public boolean	location_mine = false;
 	public Open		open = null;
 	public Close	close = null;
 	public TagData	tag = null;
@@ -19,8 +21,9 @@ public class PostBack implements Serializable {
 
 	public PostBack(){}
 
-	public PostBack( String l ) {
+	public PostBack( String l, boolean same_protocl ) {
 		location = l;
+		location_mine = same_protocl;
 	}
 
 	public PostBack( Open o ) {
