@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2012  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -16,6 +16,100 @@ import paraselene.mockup.*;
 import paraselene.tag.*;
 import paraselene.supervisor.*;
 
+class CreateParam implements DynamicPageReloader.Magazine {
+	volatile DynamicPage	dp;
+	private volatile DynamicPageException	last_err = null;
+
+	void setError( String s ) {
+		last_err = new DynamicPageException( s );
+	}
+	void setError( Exception e ) {
+		last_err = new DynamicPageException( e );
+	}
+
+	boolean isOld( long now ) {
+		return dp.getCreateDate().getTime() < now;
+	}
+
+	DynamicPage newPage() {
+		DynamicPage	ret = new DynamicPage( dp.resolve, dp.page, dp.provider );
+		ret.copyMainTag( dp );
+		return ret;
+	}
+	DynamicPage newPage( long now, LinkedList<DynamicPage> list ) {
+		DynamicPage	ret = new DynamicPage( dp.resolve, dp.page, dp.provider );
+		if ( text != null || dp.getCreateDate().getTime() > now );
+		else {
+			try {
+				DynamicPage	sub = new DynamicPage( dp.resolve, dp.page, dp.provider );
+				if ( file != null )	sub.create( file, enc );
+				else	sub.create( url, method, enc );
+				dp = sub;
+			}
+			catch( DynamicPageException e ) {
+				last_err = e;
+				return newPage();
+			}
+			list.clear();
+		}
+		ret.copyMainTag( dp );
+		return ret;
+	}
+	private int hash;
+	// 文字列
+	String	text = null;
+
+	// ファイル
+	File	file = null;
+	// URL
+	URL		url = null;
+	RequestParameter.Method	method = null;
+
+	String	enc = null;
+
+	private CreateParam( DynamicPage p ) {
+		dp = new DynamicPage( p.resolve, p.page, p.provider );
+		dp.copyMainTag( p );
+	}
+	CreateParam( DynamicPage p, String str ) {
+		this( p );
+		text = str;
+		hash = text.hashCode();
+	}
+	CreateParam( DynamicPage p, File f, String e ) {
+		this( p );
+		file = f;
+		enc = e;
+		hash = file.hashCode();
+	}
+	CreateParam( DynamicPage p, URL u, RequestParameter.Method m, String e ) {
+		this( p );
+		url = u;
+		method = m;
+		hash = url.hashCode();
+	}
+	public int hashCode() { return hash; }
+	private static boolean eq( Object o1, Object o2 ) {
+		if ( o1 == null )	return o2 == null;
+		return o1.equals( o2 );
+	}
+	public boolean equals( Object o ) {
+		if ( !( o instanceof CreateParam ) )	return false;
+		CreateParam	cp = (CreateParam)o;
+		return eq( file, cp.file ) && eq( enc, cp.enc ) && eq( url, cp.url ) &&
+			eq( method, cp.method ) && eq( text, cp.text );
+	}
+
+	public DynamicPage getPage() {
+		return DynamicPageReloader.getPage( this );
+	}
+	public DynamicPageException getLastError() {
+		DynamicPageException	err = last_err;
+		last_err = null;
+		return err;
+	}
+}
+
 class URIEcho implements URIResolver {
 	public String resolve( String src ) {
 		System.out.print( "URI: " );
@@ -65,10 +159,6 @@ public class DynamicPage extends Page {
 		return true;
 	}
 
-	private Page	page = null;
-	private URIResolver	resolve = null;
-	private GrantTagProvider[]	provider = null;
-
 	/**
 	 * コンストラクタ。以下のメソッドの戻り値は次のようになります。
 	 * <UL>
@@ -153,7 +243,7 @@ public class DynamicPage extends Page {
 	}
 
 	private static final String	START_XML = "<?xml";
-	private static final String START_DOCTYPE = "<!DOCTYPE";
+	private static final String START_DOCTYPE = "<!doctype";
 	private static final String START_HTML = "<html";
 	private static final String XML_ENCODE = "encoding";
 	private String xml_encode = null;
@@ -207,7 +297,7 @@ public class DynamicPage extends Page {
 				}
 			}
 
-			int start = line.indexOf( START_DOCTYPE );
+			int start = line.toLowerCase( Locale.ENGLISH ).indexOf( START_DOCTYPE );
 			if ( start >= 0 ) {
 				doc = new StringBuilder();
 				xml_enc = null;
@@ -233,11 +323,19 @@ public class DynamicPage extends Page {
 
 	private static final String	JAVA_UNICODE = "UTF8";
 
+	Page	page = null;
+	URIResolver	resolve = null;
+	GrantTagProvider[]	provider = null;
+
+	CreateParam	param = null;
+
 	/**
 	 * 構築。
-	 * @param str HTML(XHTML)を表す文字列。
+	 * @param str &lt;html&gt;&lt;body&gt; Hello &lt;/body&gt;&lt;/html&gt;
+	 * のような HTML(XHTML) を表す文字列。
 	 */
 	public void create( String str ) throws DynamicPageException {
+		if ( param != null )	throw new DynamicPageException( "already created." );
 		try {
 			if ( isXHTML( new InStream( str ) ) ) {
 				createXML( new InStream( str ) );
@@ -248,6 +346,7 @@ public class DynamicPage extends Page {
 		}
 		catch( DynamicPageException dpe ) { throw dpe; }
 		catch( Exception e ) { throw new DynamicPageException( e ); }
+		param = new CreateParam( this, str );
 	}
 
 	/**
@@ -258,6 +357,7 @@ public class DynamicPage extends Page {
 	 * 予測できない場合は、null を指定して下さい。
 	 */
 	public void create( File f, String enc ) throws DynamicPageException {
+		if ( param != null )	throw new DynamicPageException( "already created." );
 		try {
 			if ( isXHTML( new InStream( f ) ) ) {
 				createXML( new InStream( f ) );
@@ -268,6 +368,7 @@ public class DynamicPage extends Page {
 		}
 		catch( DynamicPageException dpe ) { throw dpe; }
 		catch( Exception e ) { throw new DynamicPageException( e ); }
+		param = new CreateParam( this, f, enc );
 	}
 
 	private String getEncoding( String type ) {
@@ -296,11 +397,13 @@ public class DynamicPage extends Page {
 	 * 予測できない場合は、null を指定して下さい。
 	 */
 	public void create( URL url, RequestParameter.Method method, String enc ) throws DynamicPageException {
+		if ( param != null )	throw new DynamicPageException( "already created." );
 		InputStream	in = null;
 		try {
 			HttpURLConnection	con = (HttpURLConnection)url.openConnection();
 			con.setInstanceFollowRedirects( true );
 			con.setRequestMethod( method == RequestParameter.Method.GET?	"GET": "POST" );
+			con.setRequestProperty( "User-agent", Version.getTitle() );
 			con.connect();
 			int	retcd = con.getResponseCode();
 			if ( (retcd / 100) != 2 )	{
@@ -338,6 +441,7 @@ public class DynamicPage extends Page {
 			}
 			catch( Exception e ){}
 		}
+		param = new CreateParam( this, url, method, enc );
 	}
 
 	/**
@@ -445,7 +549,7 @@ public class DynamicPage extends Page {
 		return null;
 	}
 	public String getCharset() {
-		if ( page != null )	return page.getCharset();
+		if ( page != null )	return page.getParentPage().getCharset();
 		return "UTF-8";
 	}
 	/**
