@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2012  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -11,8 +11,12 @@ import java.io.*;
 
 class InStream extends ByteArrayInputStream {
 	private boolean eq( int no, int i ) {
-		int	b2 = ((int)buf[no] & 0xff);
-		return b2 == i;
+		try {
+			int	b2 = ((int)buf[no] & 0xff);
+			return b2 == i;
+		}
+		catch( Exception e ) {}
+		return false;
 	}
 
 	private void bom() {
