@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2012  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -81,5 +81,20 @@ public class NameDefine implements Serializable {
 		buf = buf.append( err );
 		return buf.toString();
 	}
+
+	private static final String	CR = System.getProperty( "line.separator" );
+
+	/**
+	 * 文字列を連結して返します。
+	 * @param def 対象の配列。
+	 * @return 文字列内容。
+	 */
+	public static String toString( NameDefine[] def ) {
+		StringBuilder	buf = new StringBuilder();
+		for ( NameDefine	d: def ) {
+			buf = buf.append( d.toString() ).append( CR );
+		}
+		return buf.toString();
+	}
 }
 
