@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -26,7 +26,6 @@ class Config {
 
 	private static ArrayList<String> parse( String org ) {
 		ArrayList<String>	ret = new ArrayList<String>();
-		org = org.trim();
 		if ( org.isEmpty() )	return ret;
 		char[]	dim = org.toCharArray();
 		char	deli = NULL_CHAR;
@@ -78,6 +77,9 @@ class Config {
 		while( true ) {
 			String	str = br.readLine();
 			if ( str == null )	break;
+			str = str.trim();
+			if ( str.length() == 0 )	continue;
+			if ( str.charAt( 0 ) == '#' )	continue;
 			list.addAll( parse( str ) );
 		}
 		br.close();
