@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -19,8 +19,9 @@ public class Download extends PrePage {
 			new paraselene.mockup.output.source.view.download(),
 			new paraselene.mockup.output.source.logic.download()
 		};
+		makeSuper();
 		for ( int i = 0; i < 2; i ++ ) {
-			makeSourceMain( i, output[i] );
+			makeSourceMain( i, java_path, output[i] );
 		}
 	}
 
