@@ -12,13 +12,14 @@ import java.util.*;
 
 class JavaDefine {
 	private static final String[]	def = new String[] {
-		"abstract", "boolean", "break", "byte", "cast", "catch", "char", "class",
-		"const", "continue", "default", "do", "double", "else", "extends", "final",
-		"false", "finally", "float", "for", "goto", "if", "implements", "import",
-		"instanceof", "int", "interface", "long", "native", "new", "package",
-		"private", "protected", "public", "return", "short", "static", "super",
-		"switch", "synchronized", "this", "throw", "throws", "transient", "true",
-		"try", "void", "vlatile", "while"
+		"abstract", "assert", "boolean", "break", "byte", "case", "cast",
+		"catch", "char", "class", "const", "continue", "default", "do",
+		"double", "else", "enum", "extends", "final", "false", "final",
+		"finally", "float", "for", "goto", "if", "implements", "import",
+		"instanceof", "int", "interface", "long", "native", "new", "null",
+		"package", "private", "protected", "public", "return", "strictfp",
+		"short", "static", "super", "switch", "synchronized", "this", "throw",
+		"throws", "transient", "true", "try", "void", "volatile", "while"
 	};
 
 	private static HashMap<String, String>	map = new HashMap<String, String>();
