@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -18,11 +18,16 @@ import paraselene.dyna.*;
  */
 public class Make implements OutputNo {
 	public String getString( int no ) {
+		String	crt = new java.io.File( "a" ).getAbsoluteFile().getParent();
 		switch( no ) {
 		case 1:
 			return Param.PACKAGE.get();
 		case 2:
 			return Param.OUT_ENCODE.get();
+		case 3:
+			return Dominion.fix( crt, Param.HTML_ROOT.get(), false );
+		case 4:
+			return Param.OTHER.get();
 		case 33:
 			return Param.PACKAGE_BASE.get();
 		case 34:
@@ -92,9 +97,10 @@ public class Make implements OutputNo {
 		out.close();
 	}
 
-	private static void read( File root )
+	private static boolean read( File root )
 	throws FileNotFoundException, UnsupportedEncodingException, IOException,
 	DynamicPageException {
+		boolean	do_f = false;
 		if ( !root.exists() ) {
 			System.err.println( root.getPath() + " is not found." );
 			System.exit( 1);
@@ -106,7 +112,7 @@ public class Make implements OutputNo {
 					Linker.readme.echoln( list[i].getPath() + " is ignored." );
 					continue;
 				}
-				read( list[i] );
+				if ( read( list[i] ) )	do_f = true;
 			}
 			else {
 				if ( Param.isHit( list[i].getName() ) ) {
@@ -122,6 +128,7 @@ public class Make implements OutputNo {
 					}
 					Linker.readme.entryPage( page );
 					Linker.readme.echoln( list[i].getPath() + " parsing ended." );
+					do_f = true;
 				}
 				else {
 					ex_copy( list[i] );
@@ -130,6 +137,8 @@ public class Make implements OutputNo {
 				}
 			}
 		}
+		if ( do_f )	Linker.readme.entryPage( new PrePage( new File( root, PrePage.DUMMY_PAGE ) ) );
+		return do_f;
 	}
 
 	private static void write() throws Exception {
