@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -28,6 +28,8 @@ class FunctionInfo {
  * 解析後バッファ。
  */
 public class PrePage extends DynamicPage implements OutputNo {
+	static final String DUMMY_PAGE = "dummy.paraselene";
+
 	class PrePageID implements PageID {
 		private int id = 0;
 		PrePageID( int p ) {
@@ -266,6 +268,18 @@ public class PrePage extends DynamicPage implements OutputNo {
 				}
 				return buf.toString();
 			}
+		case 32:
+			{
+				String[]	dir = package_name.split( "\\." );
+				int	cnt = dir.length - 1;
+				if ( cnt < 1 )	return "";
+				StringBuilder	buf = new StringBuilder();
+				buf = buf.append( "." ).append( Param.PACKAGE_LOGIC.get() );
+				for ( int i = 1; i < cnt; i++ ) {
+					buf = buf.append( "." ).append( dir[i] );
+				}
+				return buf.toString();
+			}
 		case 33:
 			return Param.PACKAGE_BASE.get();
 		case 34:
@@ -288,6 +302,14 @@ public class PrePage extends DynamicPage implements OutputNo {
 		return buf.toString();
 	}
 
+	String getRelativePage() {
+		StringBuilder	buf = new StringBuilder( "new Dominion.RelativePage(\"" );
+		buf = buf.append( Output.toHtmlPath( path ) ).append( "\"," );
+		buf = buf.append( getEnumName( false ) ).append( "," );
+		buf = buf.append( this instanceof Download ).append( ")" );
+		return buf.toString();
+	}
+
 	String getEnumName( boolean only_f ) {
 		if ( only_f )	return enum_name;
 		StringBuilder	buf = new StringBuilder( Param.PACKAGE.get() );
@@ -296,13 +318,13 @@ public class PrePage extends DynamicPage implements OutputNo {
 		return buf.toString();
 	}
 
-	void makeSourceMain( int dir, Output output ) throws Exception {
+	void makeSourceMain( int dir, String fname, Output output ) throws Exception {
 		Linker.readme.setCurrentPage( this );
 		StringBuilder	out_path = new StringBuilder( Make.SRC_PATH );
 		out_path = out_path.append( File.separator );
 		out_path = out_path.append( out_dir[dir] );
 		out_path = out_path.append( File.separator );
-		out_path = out_path.append( java_path );
+		out_path = out_path.append( fname );
 		String	name = out_path.toString();
 		File	file = new File( name );
 		Linker.readme.echoln( name + " output starts." );
@@ -323,13 +345,27 @@ public class PrePage extends DynamicPage implements OutputNo {
 		}
 	}
 
+	private static HashMap<String, String>	super_page = new HashMap<String, String>();
+	void makeSuper() throws Exception {
+		if ( !Boolean.valueOf( Param.WEB_APP.get() ) )	return;
+		if ( super_page.get( package_name ) != null )	return;
+		makeSourceMain( 1, super_path, new paraselene.mockup.output.source.logic.SuperPage() );
+		super_page.put( package_name, package_name );
+	}
+
 	void makeSource() throws Exception {
+		makeSuper();
+		if ( dummy_page_f )	return;
 		Output[]	output = {
-			new paraselene.mockup.output.source.view.view(),
-			new paraselene.mockup.output.source.logic.logic()
+			Boolean.valueOf( Param.WEB_APP.get() )?
+				new paraselene.mockup.output.source.view.view():
+				new paraselene.mockup.output.source.view.xeno(),
+			Boolean.valueOf( Param.WEB_APP.get() )?
+				new paraselene.mockup.output.source.logic.logic():
+				new paraselene.mockup.output.source.logic.xeno()
 		};
 		for ( int i = 0; i < 2; i++ ) {
-			makeSourceMain( i, output[i] );
+			makeSourceMain( i, java_path, output[i] );
 		}
 	}
 
@@ -338,7 +374,8 @@ public class PrePage extends DynamicPage implements OutputNo {
 	private String path = "";
 	// package_nameにParam.PACKAGE + view|logic を付加する。
 	private String package_name;
-	private String java_path;
+	private String super_path;
+	String java_path;
 	private String org_file_name;
 	private String class_name;
 	private String enum_name;
@@ -447,6 +484,7 @@ public class PrePage extends DynamicPage implements OutputNo {
 		}
 		enum_name = buf.toString();
 
+		super_path = java_path + File.separatorChar + "SuperPage.java";
 		java_path = java_path + File.separatorChar + class_name + ".java";
 		String	cf = name_check.get( java_path );
 		if ( cf != null ) {
@@ -455,6 +493,11 @@ public class PrePage extends DynamicPage implements OutputNo {
 			System.err.println( path );
 			System.exit( 1 );
 		}
+		if ( super_path.equals( java_path ) ) {
+			System.err.println( "クラス名が SuperPage となるファイル名は使用できません" );
+			System.err.println( path );
+			System.exit( 1 );
+		}
 		name_check.put( java_path, path );
 
 		id = (Param.PACKAGE.get() + path).hashCode();
@@ -494,6 +537,7 @@ public class PrePage extends DynamicPage implements OutputNo {
 		this( p, false );
 	}
 
+	boolean dummy_page_f = false;
 	PrePage( File p, boolean dev_f )
 	throws FileNotFoundException, UnsupportedEncodingException, IOException,
 	DynamicPageException {
@@ -508,6 +552,10 @@ public class PrePage extends DynamicPage implements OutputNo {
 		out_path = out_path.append( out_dir[0] );
 		out_path = out_path.append( File.separator );
 		out_path = out_path.append( java_path );
+		if ( p.getName().equals( DUMMY_PAGE ) ) {
+			dummy_page_f = true;
+			return;
+		}
 		if ( new File( out_path.toString() ).lastModified() > html_last_time )	return;
 
 		Linker.readme.setCurrentPage( this );
