@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009-2011  Akira Terasaki
+ * Copyright (c) 2009-2014  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -74,13 +74,13 @@ public class TagMap {
 			if ( txt == null ) {
 				throw new TagException( "type属性が不正です" );
 			}
-			name = txt.toString();
+			name = "input_" + txt.toString();
 			if ( class_real.get( name ) == null ) {
 				throw new TagException( "type属性が不正です" );
 			}
 			return name;
 		}
-		if ( class_real.get( name ) == null ) {
+		else if ( class_real.get( name ) == null ) {
 			return TAG;
 		}
 		return name;
@@ -202,7 +202,7 @@ public class TagMap {
 
 	private static final Object[][]	dim = new Object[][]{
 	// input
-		{ "hidden", paraselene.tag.form.Input.class,
+		{ "input_hidden", paraselene.tag.form.Input.class,
 			new TagNew() {
 				public String toString( Tag t ) {
 					return append( "Input.createHidden( ", Make.escape( t.getNameAttribute() ), ",", Make.escape( t.getValueString() ), ")" );
@@ -218,7 +218,7 @@ public class TagMap {
 				}
 			}
 		},
-		{ "file", paraselene.tag.form.UploadFile.class,
+		{ "input_file", paraselene.tag.form.UploadFile.class,
 			"new UploadFile()",
 			new DynaTag() {
 				Tag getTag( String name, ArrayList<Attribute> attr ) {
@@ -226,7 +226,7 @@ public class TagMap {
 				}
 			}
 		},
-		{ "button", paraselene.tag.form.Button.class,
+		{ "input_button", paraselene.tag.form.Button.class,
 			"new Button(Button.Type.BUTTON)",
 			new DynaTag() {
 				Tag getTag( String name, ArrayList<Attribute> attr ) {
@@ -234,7 +234,7 @@ public class TagMap {
 				}
 			}
 		},
-		{ "image", paraselene.tag.form.Button.class,
+		{ "input_image", paraselene.tag.form.Button.class,
 			"new Button(Button.Type.IMAGE)",
 			new DynaTag() {
 				Tag getTag( String name, ArrayList<Attribute> attr ) {
@@ -242,7 +242,7 @@ public class TagMap {
 				}
 			}
 		},
-		{ "reset", paraselene.tag.form.Button.class,
+		{ "input_reset", paraselene.tag.form.Button.class,
 			"new Button(Button.Type.RESET)",
 			new DynaTag() {
 				Tag getTag( String name, ArrayList<Attribute> attr ) {
@@ -250,7 +250,7 @@ public class TagMap {
 				}
 			}
 		},
-		{ "submit", paraselene.tag.form.Button.class,
+		{ "input_submit", paraselene.tag.form.Button.class,
 			"new Button(Button.Type.SUBMIT)",
 			new DynaTag() {
 				Tag getTag( String name, ArrayList<Attribute> attr ) {
@@ -258,7 +258,7 @@ public class TagMap {
 				}
 			}
 		},
-		{ "radio", paraselene.tag.form.CheckBox.class,
+		{ "input_radio", paraselene.tag.form.CheckBox.class,
 			"new CheckBox(true)",
 			new DynaTag() {
 				Tag getTag( String name, ArrayList<Attribute> attr ) {
@@ -266,7 +266,7 @@ public class TagMap {
 				}
 			}
 		},
-		{ "checkbox", paraselene.tag.form.CheckBox.class,
+		{ "input_checkbox", paraselene.tag.form.CheckBox.class,
 			"new CheckBox(false)",
 			new DynaTag() {
 				Tag getTag( String name, ArrayList<Attribute> attr ) {
@@ -274,7 +274,7 @@ public class TagMap {
 				}
 			}
 		},
-		{ "password", paraselene.tag.form.SingleTextBox.class,
+		{ "input_password", paraselene.tag.form.SingleTextBox.class,
 			"new SingleTextBox(SingleTextBox.Type.PASSWORD)",
 			new DynaTag() {
 				Tag getTag( String name, ArrayList<Attribute> attr ) {
@@ -282,7 +282,7 @@ public class TagMap {
 				}
 			}
 		},
-		{ "text", paraselene.tag.form.SingleTextBox.class,
+		{ "input_text", paraselene.tag.form.SingleTextBox.class,
 			"new SingleTextBox(SingleTextBox.Type.TEXT)",
 			new DynaTag() {
 				Tag getTag( String name, ArrayList<Attribute> attr ) {
@@ -291,7 +291,7 @@ public class TagMap {
 			}
 		},
 	// HTML5 input
-		{ "search", paraselene.tag.form.SingleTextBox.class,
+		{ "input_search", paraselene.tag.form.SingleTextBox.class,
 			"new SingleTextBox(SingleTextBox.Type.SEARCH)",
 			new DynaTag() {
 				Tag getTag( String name, ArrayList<Attribute> attr ) {
@@ -299,7 +299,7 @@ public class TagMap {
 				}
 			}
 		},
-		{ "tel", paraselene.tag.form.SingleTextBox.class,
+		{ "input_tel", paraselene.tag.form.SingleTextBox.class,
 			"new SingleTextBox(SingleTextBox.Type.TELEPHONE)",
 			new DynaTag() {
 				Tag getTag( String name, ArrayList<Attribute> attr ) {
@@ -307,7 +307,7 @@ public class TagMap {
 				}
 			}
 		},
-		{ "url", paraselene.tag.form.SingleTextBox.class,
+		{ "input_url", paraselene.tag.form.SingleTextBox.class,
 			"new SingleTextBox(SingleTextBox.Type.URL)",
 			new DynaTag() {
 				Tag getTag( String name, ArrayList<Attribute> attr ) {
@@ -315,7 +315,7 @@ public class TagMap {
 				}
 			}
 		},
-		{ "email", paraselene.tag.form.SingleTextBox.class,
+		{ "input_email", paraselene.tag.form.SingleTextBox.class,
 			"new SingleTextBox(SingleTextBox.Type.EMAIL)",
 			new DynaTag() {
 				Tag getTag( String name, ArrayList<Attribute> attr ) {
@@ -323,7 +323,7 @@ public class TagMap {
 				}
 			}
 		},
-		{ "datetime", paraselene.tag.form.SingleTextBox.class,
+		{ "input_datetime", paraselene.tag.form.SingleTextBox.class,
 			"new SingleTextBox(SingleTextBox.Type.DATE_AND_TIME)",
 			new DynaTag() {
 				Tag getTag( String name, ArrayList<Attribute> attr ) {
@@ -331,7 +331,7 @@ public class TagMap {
 				}
 			}
 		},
-		{ "date", paraselene.tag.form.SingleTextBox.class,
+		{ "input_date", paraselene.tag.form.SingleTextBox.class,
 			"new SingleTextBox(SingleTextBox.Type.DATE)",
 			new DynaTag() {
 				Tag getTag( String name, ArrayList<Attribute> attr ) {
@@ -339,7 +339,7 @@ public class TagMap {
 				}
 			}
 		},
-		{ "month", paraselene.tag.form.SingleTextBox.class,
+		{ "input_month", paraselene.tag.form.SingleTextBox.class,
 			"new SingleTextBox(SingleTextBox.Type.MONTH)",
 			new DynaTag() {
 				Tag getTag( String name, ArrayList<Attribute> attr ) {
@@ -347,7 +347,7 @@ public class TagMap {
 				}
 			}
 		},
-		{ "week", paraselene.tag.form.SingleTextBox.class,
+		{ "input_week", paraselene.tag.form.SingleTextBox.class,
 			"new SingleTextBox(SingleTextBox.Type.WEEK)",
 			new DynaTag() {
 				Tag getTag( String name, ArrayList<Attribute> attr ) {
@@ -355,7 +355,7 @@ public class TagMap {
 				}
 			}
 		},
-		{ "time", paraselene.tag.form.SingleTextBox.class,
+		{ "input_time", paraselene.tag.form.SingleTextBox.class,
 			"new SingleTextBox(SingleTextBox.Type.TIME)",
 			new DynaTag() {
 				Tag getTag( String name, ArrayList<Attribute> attr ) {
@@ -363,7 +363,7 @@ public class TagMap {
 				}
 			}
 		},
-		{ "datetime-local", paraselene.tag.form.SingleTextBox.class,
+		{ "input_datetime-local", paraselene.tag.form.SingleTextBox.class,
 			"new SingleTextBox(SingleTextBox.Type.LOCAL_DATE_AND_TIME)",
 			new DynaTag() {
 				Tag getTag( String name, ArrayList<Attribute> attr ) {
@@ -371,7 +371,7 @@ public class TagMap {
 				}
 			}
 		},
-		{ "number", paraselene.tag.form.SingleTextBox.class,
+		{ "input_number", paraselene.tag.form.SingleTextBox.class,
 			"new SingleTextBox(SingleTextBox.Type.NUMBER)",
 			new DynaTag() {
 				Tag getTag( String name, ArrayList<Attribute> attr ) {
@@ -379,7 +379,7 @@ public class TagMap {
 				}
 			}
 		},
-		{ "range", paraselene.tag.form.SingleTextBox.class,
+		{ "input_range", paraselene.tag.form.SingleTextBox.class,
 			"new SingleTextBox(SingleTextBox.Type.RANGE)",
 			new DynaTag() {
 				Tag getTag( String name, ArrayList<Attribute> attr ) {
@@ -387,7 +387,7 @@ public class TagMap {
 				}
 			}
 		},
-		{ "color", paraselene.tag.form.SingleTextBox.class,
+		{ "input_color", paraselene.tag.form.SingleTextBox.class,
 			"new SingleTextBox(SingleTextBox.Type.COLOR)",
 			new DynaTag() {
 				Tag getTag( String name, ArrayList<Attribute> attr ) {
