@@ -1,10 +1,10 @@
+// Paraselene2 2.2.3 (http://paraselene.sourceforge.jp/) generated this source file.
 /*
  * Paraselene
- * Copyright (c) 2009  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
-// Paraselene generated this source file.
 package paraselene.mockup.output;
 
 import paraselene.*;
@@ -14,6 +14,7 @@ import paraselene.css.*;
 import paraselene.tag.form.*;
 import paraselene.tag.list.*;
 import paraselene.tag.table.*;
+import paraselene.dyna.*;
 
 
 public abstract class Readme extends paraselene.Page {
@@ -25,69 +26,69 @@ super();
 }
 public void init() {
 try{
-Tag tag124=new Tag("html",false);
-Tag tag125=new Tag("head",false);
-Tag tag127=new Tag("meta",true);
+paraselene.tag.Tag tag124=new Tag("html",false);
+paraselene.tag.Tag tag125=new Tag("head",false);
+paraselene.tag.Tag tag127=new Tag("meta",true);
 tag127.setAttribute(new Attribute("content",new Text("text/css")),new Attribute("http-equiv",new Text("Content-Style-Type")));
 tag125.addHTMLPart(tag127);
-Tag tag128=new Tag("title",false);
+paraselene.tag.Tag tag128=new Tag("title",false);
 tag128.setAttribute(new Attribute("name",new Text("title")));
 Text text157=new Text("Read me");
 tag128.addHTMLPart(text157);
 tag125.addHTMLPart(tag128);
-Tag tag129=new Tag("style",false);
+paraselene.tag.Tag tag129=new Tag("style",false);
 tag129.setAttribute(new Attribute("type",new Text("text/css")));
 Text text158=new Text("\n<!--\ntable {\n  border: 1px solid  #000;\nborder-collapse : collapse ;\n}\nth {\n  background-color: #cccccc;\ntext-align: left;\n}\n-->\n");
 tag129.addHTMLPart(text158);
 tag125.addHTMLPart(tag129);
-Tag tag130=new Tag("script",false);
+paraselene.tag.Tag tag130=new Tag("script",false);
 tag130.setAttribute(new Attribute("language",new Text("JavaScript")));
 Text text160=new Text("\n<!--\nfunction load( page ){\n	var top = document.uri_form.url.value;\n	if ( top == \"\" || document.uri_form.url.defaultValue == top ) {\n		alert( \"テキストボックスにURLを指定して下さい\" );\n		return;\n	}\n	if ( top.charAt( top.length -1 ) != \"/\" ) {\n		top = top + \"/\";\n	}\n	window.open( top + page, \"_blank\" );\n}\n-->\n");
 tag130.addHTMLPart(text160);
 tag125.addHTMLPart(tag130);
 tag124.addHTMLPart(tag125);
-Tag tag131=new Tag("body",false);
-Tag tag132=new Tag("div",false);
+paraselene.tag.Tag tag131=new Tag("body",false);
+paraselene.tag.Tag tag132=new Tag("div",false);
 tag132.setAttribute(new Attribute("name",new Text("echo")));
 tag131.addHTMLPart(tag132);
 Text text310=new Text("\n\n以下のファイルを生成しました。内容を確認して下さい。");
 tag131.addHTMLPart(text310);
-Table tag135=new Table();
+paraselene.tag.table.Table tag135=new Table();
 tag135.setAttribute(new Attribute("border",new NumberValue("1")));
-Line tag137=new Line();
-Column tag138=new Column(Column.Type.DATA);
+paraselene.tag.table.Line tag137=new Line();
+paraselene.tag.table.Column tag138=new Column(Column.Type.DATA);
 tag138.setAttribute(new Attribute("name",new Text("root")));
 Text text162=new Text("<root>");
 tag138.addHTMLPart(text162);
 tag137.addHTMLPart(tag138);
-Column tag139=new Column(Column.Type.DATA);
+paraselene.tag.table.Column tag139=new Column(Column.Type.DATA);
 tag137.addHTMLPart(tag139);
 tag135.addHTMLPart(tag137);
-Line tag140=new Line();
-Column tag141=new Column(Column.Type.DATA);
+paraselene.tag.table.Line tag140=new Line();
+paraselene.tag.table.Column tag141=new Column(Column.Type.DATA);
 Text text165=new Text(" <exclude>");
 tag141.addHTMLPart(text165);
 tag140.addHTMLPart(tag141);
-Column tag142=new Column(Column.Type.DATA);
+paraselene.tag.table.Column tag142=new Column(Column.Type.DATA);
 Text text169=new Text("除外されたファイルがコピーされています。\nこれらを、Webサーバー等の所定の場所に配置して下さい。\nこの中に存在するファイルの一覧は、後述の除外ファイル一覧を参照して下さい。");
 tag142.addHTMLPart(text169);
 tag140.addHTMLPart(tag142);
 tag135.addHTMLPart(tag140);
-Line tag145=new Line();
-Column tag146=new Column(Column.Type.DATA);
+paraselene.tag.table.Line tag145=new Line();
+paraselene.tag.table.Column tag146=new Column(Column.Type.DATA);
 tag146.setAttribute(new Attribute("name",new Text("source")));
 Text text174=new Text(" <source>");
 tag146.addHTMLPart(text174);
 tag145.addHTMLPart(tag146);
-Column tag147=new Column(Column.Type.DATA);
+paraselene.tag.table.Column tag147=new Column(Column.Type.DATA);
 tag145.addHTMLPart(tag147);
 tag135.addHTMLPart(tag145);
-Line tag148=new Line();
-Column tag149=new Column(Column.Type.DATA);
+paraselene.tag.table.Line tag148=new Line();
+paraselene.tag.table.Column tag149=new Column(Column.Type.DATA);
 tag149.setAttribute(new Attribute("bgcolor",new Color("#EEEEEE")));
 Text text178=new Text("   <");
 tag149.addHTMLPart(text178);
-Tag tag150=new Tag("span",false);
+paraselene.tag.Tag tag150=new Tag("span",false);
 tag150.setAttribute(new Attribute("name",new Text("base")));
 Text text182=new Text("base");
 tag150.addHTMLPart(text182);
@@ -95,19 +96,19 @@ tag149.addHTMLPart(tag150);
 Text text183=new Text(">");
 tag149.addHTMLPart(text183);
 tag148.addHTMLPart(tag149);
-Column tag151=new Column(Column.Type.DATA);
+paraselene.tag.table.Column tag151=new Column(Column.Type.DATA);
 tag151.setAttribute(new Attribute("bgcolor",new Color("#EEEEEE")));
-Tag tag152=new Tag("b",false);
+paraselene.tag.Tag tag152=new Tag("b",false);
 Text text184=new Text("この中のソースファイルは変更しないで下さい。");
 tag152.addHTMLPart(text184);
 tag151.addHTMLPart(tag152);
 tag148.addHTMLPart(tag151);
 tag135.addHTMLPart(tag148);
-Line tag153=new Line();
-Column tag154=new Column(Column.Type.DATA);
+paraselene.tag.table.Line tag153=new Line();
+paraselene.tag.table.Column tag154=new Column(Column.Type.DATA);
 Text text185=new Text("   <");
 tag154.addHTMLPart(text185);
-Tag tag155=new Tag("span",false);
+paraselene.tag.Tag tag155=new Tag("span",false);
 tag155.setAttribute(new Attribute("name",new Text("logic")));
 Text text189=new Text("logic");
 tag155.addHTMLPart(text189);
@@ -115,10 +116,10 @@ tag154.addHTMLPart(tag155);
 Text text190=new Text(">");
 tag154.addHTMLPart(text190);
 tag153.addHTMLPart(tag154);
-Column tag156=new Column(Column.Type.DATA);
+paraselene.tag.table.Column tag156=new Column(Column.Type.DATA);
 Text text191=new Text("ロジック記述のためのスケルトンソースファイルが格納されています。\n自由に変更可能ですが、");
 tag156.addHTMLPart(text191);
-Tag tag158=new Tag("b",false);
+paraselene.tag.Tag tag158=new Tag("b",false);
 Text text193=new Text("クラス名は変更しないで下さい。");
 tag158.addHTMLPart(text193);
 tag156.addHTMLPart(tag158);
@@ -126,12 +127,12 @@ Text text196=new Text("\nこの中に存在するクラスの一覧は、後述
 tag156.addHTMLPart(text196);
 tag153.addHTMLPart(tag156);
 tag135.addHTMLPart(tag153);
-Line tag160=new Line();
-Column tag161=new Column(Column.Type.DATA);
+paraselene.tag.table.Line tag160=new Line();
+paraselene.tag.table.Column tag161=new Column(Column.Type.DATA);
 tag161.setAttribute(new Attribute("bgcolor",new Color("#EEEEEE")));
 Text text197=new Text("   <");
 tag161.addHTMLPart(text197);
-Tag tag162=new Tag("span",false);
+paraselene.tag.Tag tag162=new Tag("span",false);
 tag162.setAttribute(new Attribute("name",new Text("view")));
 Text text201=new Text("view");
 tag162.addHTMLPart(text201);
@@ -139,105 +140,105 @@ tag161.addHTMLPart(tag162);
 Text text202=new Text(">");
 tag161.addHTMLPart(text202);
 tag160.addHTMLPart(tag161);
-Column tag163=new Column(Column.Type.DATA);
+paraselene.tag.table.Column tag163=new Column(Column.Type.DATA);
 tag163.setAttribute(new Attribute("bgcolor",new Color("#EEEEEE")));
-Tag tag164=new Tag("b",false);
+paraselene.tag.Tag tag164=new Tag("b",false);
 Text text203=new Text("この中のソースファイルは変更しないで下さい。");
 tag164.addHTMLPart(text203);
 tag163.addHTMLPart(tag164);
 tag160.addHTMLPart(tag163);
 tag135.addHTMLPart(tag160);
-Line tag165=new Line();
-Column tag166=new Column(Column.Type.DATA);
+paraselene.tag.table.Line tag165=new Line();
+paraselene.tag.table.Column tag166=new Column(Column.Type.DATA);
 Text text204=new Text("   DummyPage.java");
 tag166.addHTMLPart(text204);
 tag165.addHTMLPart(tag166);
-Column tag167=new Column(Column.Type.DATA);
+paraselene.tag.table.Column tag167=new Column(Column.Type.DATA);
 Text text207=new Text("NullPage派生クラスのスケルトンソースファイルです。\n自由に変更可能ですが、");
 tag167.addHTMLPart(text207);
-Tag tag169=new Tag("b",false);
+paraselene.tag.Tag tag169=new Tag("b",false);
 Text text209=new Text("クラス名は変更しないで下さい。");
 tag169.addHTMLPart(text209);
 tag167.addHTMLPart(tag169);
 tag165.addHTMLPart(tag167);
 tag135.addHTMLPart(tag165);
-Line tag170=new Line();
-Column tag171=new Column(Column.Type.DATA);
+paraselene.tag.table.Line tag170=new Line();
+paraselene.tag.table.Column tag171=new Column(Column.Type.DATA);
 Text text211=new Text("   Gate.java");
 tag171.addHTMLPart(text211);
 tag170.addHTMLPart(tag171);
-Column tag172=new Column(Column.Type.DATA);
+paraselene.tag.table.Column tag172=new Column(Column.Type.DATA);
 Text text214=new Text("サーブレット本体のスケルトンソースファイルです。\ndoGetやdoPostはスーパークラス側で実装されており、その動作は変更できません。\nそれ以外に関しては自由に変更可能ですが、");
 tag172.addHTMLPart(text214);
-Tag tag175=new Tag("b",false);
+paraselene.tag.Tag tag175=new Tag("b",false);
 Text text217=new Text("クラス名は変更しないで下さい。");
 tag175.addHTMLPart(text217);
 tag172.addHTMLPart(tag175);
 tag170.addHTMLPart(tag172);
 tag135.addHTMLPart(tag170);
-Line tag176=new Line();
-Column tag177=new Column(Column.Type.DATA);
+paraselene.tag.table.Line tag176=new Line();
+paraselene.tag.table.Column tag177=new Column(Column.Type.DATA);
 Text text220=new Text("   Json.java");
 tag177.addHTMLPart(text220);
 tag176.addHTMLPart(tag177);
-Column tag178=new Column(Column.Type.DATA);
+paraselene.tag.table.Column tag178=new Column(Column.Type.DATA);
 Text text223=new Text("非同期通信時に返す値をハンドリングするためのクラスです。\n自由に変更可能ですが、");
 tag178.addHTMLPart(text223);
-Tag tag180=new Tag("b",false);
+paraselene.tag.Tag tag180=new Tag("b",false);
 Text text225=new Text("クラス名は変更しないで下さい。");
 tag180.addHTMLPart(text225);
 tag178.addHTMLPart(tag180);
 tag176.addHTMLPart(tag178);
 tag135.addHTMLPart(tag176);
-Line tag181=new Line();
-Column tag182=new Column(Column.Type.DATA);
+paraselene.tag.table.Line tag181=new Line();
+paraselene.tag.table.Column tag182=new Column(Column.Type.DATA);
 Text text227=new Text("   SuperPage.java");
 tag182.addHTMLPart(text227);
 tag181.addHTMLPart(tag182);
-Column tag183=new Column(Column.Type.DATA);
+paraselene.tag.table.Column tag183=new Column(Column.Type.DATA);
 Text text230=new Text("動的ページのスーパークラスのスケルトンソースファイルです。\n全ページで共通となる処理や、ユーティリティ的なメソッドを記述できます。\n自由に変更可能ですが、");
 tag183.addHTMLPart(text230);
-Tag tag186=new Tag("b",false);
+paraselene.tag.Tag tag186=new Tag("b",false);
 Text text233=new Text("クラス名は変更しないで下さい。");
 tag186.addHTMLPart(text233);
 tag183.addHTMLPart(tag186);
 tag181.addHTMLPart(tag183);
 tag135.addHTMLPart(tag181);
-Line tag187=new Line();
-Column tag188=new Column(Column.Type.DATA);
+paraselene.tag.table.Line tag187=new Line();
+paraselene.tag.table.Column tag188=new Column(Column.Type.DATA);
 Text text236=new Text(" build.xml");
 tag188.addHTMLPart(text236);
 tag187.addHTMLPart(tag188);
-Column tag189=new Column(Column.Type.DATA);
-Anchor tag190=new Anchor();
+paraselene.tag.table.Column tag189=new Column(Column.Type.DATA);
+paraselene.tag.Anchor tag190=new Anchor();
 tag190.setAttribute(new Attribute("target",new Text("_blank")),new Attribute("href",new URIValue("http://www.jajakarta.org/ant/")));
 Text text237=new Text("Ant");
 tag190.addHTMLPart(text237);
 tag189.addHTMLPart(tag190);
 Text text238=new Text("のビルドファイルです。この場所で実行するとビルドを行います。\nただし、paraselene.jarにクラスパスを通しておいて下さい。\nまた、必要に応じて、このファイルを変更して使用して下さい。");
 tag189.addHTMLPart(text238);
-List tag193=new List(List.Type.UNORDERED);
-ListItem tag194=new ListItem(ListItem.Type.LIST_ITEM);
+paraselene.tag.list.List tag193=new List(List.Type.UNORDERED);
+paraselene.tag.list.ListItem tag194=new ListItem(ListItem.Type.LIST_ITEM);
 Text text241=new Text("ant\n引数なしで実行するとソースをコンパイルします。\nこの階層に<classes>ディレクトリを作成し、クラスファイルが出力されます。");
 tag194.addHTMLPart(text241);
 tag193.addHTMLPart(tag194);
-ListItem tag197=new ListItem(ListItem.Type.LIST_ITEM);
+paraselene.tag.list.ListItem tag197=new ListItem(ListItem.Type.LIST_ITEM);
 Text text250=new Text("ant doc\ndocを引数にするとjavadocを生成します。\nこの階層に<doc>ディレクトリを作成し、htmlファイルが出力されます。");
 tag197.addHTMLPart(text250);
 tag193.addHTMLPart(tag197);
-ListItem tag200=new ListItem(ListItem.Type.LIST_ITEM);
+paraselene.tag.list.ListItem tag200=new ListItem(ListItem.Type.LIST_ITEM);
 Text text259=new Text("ant clean\ncleanを引数にすると、<classes>と<doc>ディレクトリを削除します。");
 tag200.addHTMLPart(text259);
 tag193.addHTMLPart(tag200);
 tag189.addHTMLPart(tag193);
 tag187.addHTMLPart(tag189);
 tag135.addHTMLPart(tag187);
-Line tag202=new Line();
-Column tag203=new Column(Column.Type.DATA);
+paraselene.tag.table.Line tag202=new Line();
+paraselene.tag.table.Column tag203=new Column(Column.Type.DATA);
 Text text272=new Text(" web.xml");
 tag203.addHTMLPart(text272);
 tag202.addHTMLPart(tag203);
-Column tag204=new Column(Column.Type.DATA);
+paraselene.tag.table.Column tag204=new Column(Column.Type.DATA);
 Text text273=new Text("WEB-INF配下に配置するweb.xmlの雛形です。\nこれをそのまま、または必要箇所をコピーして使用して下さい。");
 tag204.addHTMLPart(text273);
 tag202.addHTMLPart(tag204);
@@ -245,21 +246,21 @@ tag135.addHTMLPart(tag202);
 tag131.addHTMLPart(tag135);
 Text text312=new Text("\n");
 tag131.addHTMLPart(text312);
-Form tag207=new Form();
+paraselene.tag.form.Form tag207=new Form();
 tag207.setAttribute(new Attribute("name",new Text("uri_form")));
-SingleTextBox tag208=new SingleTextBox(false);
+paraselene.tag.form.SingleTextBox tag208=new SingleTextBox(SingleTextBox.Type.TEXT);
 tag208.setAttribute(new Attribute("style",new Style(Property.create("background-color:#FFFF00;","UTF-8"))),new Attribute("name",new Text("url")),new Attribute("value",new Text("http://")),new Attribute("type",new Text("text")),new Attribute("size",new NumberValue("60")));
 tag207.addHTMLPart(tag208);
 Text text282=new Text("\n例えばここに、http://localhost:8080/test/ と予め入力しておき、logicクラス一覧の");
 tag207.addHTMLPart(text282);
-Tag tag210=new Tag("span",false);
+paraselene.tag.Tag tag210=new Tag("span",false);
 tag210.setAttribute(new Attribute("name",new Text("ex")));
 Text text277=new Text("xxx");
 tag210.addHTMLPart(text277);
 tag207.addHTMLPart(tag210);
 Text text278=new Text(" のリンクをクリックすると\nhttp://loclhost:8080/test/");
 tag207.addHTMLPart(text278);
-Tag tag212=new Tag("span",false);
+paraselene.tag.Tag tag212=new Tag("span",false);
 tag212.setAttribute(new Attribute("name",new Text("ex")));
 Text text280=new Text("xxx");
 tag212.addHTMLPart(text280);
@@ -267,10 +268,10 @@ tag207.addHTMLPart(tag212);
 Text text281=new Text(" が開きます。");
 tag207.addHTMLPart(text281);
 tag131.addHTMLPart(tag207);
-Table tag213=new Table();
+paraselene.tag.table.Table tag213=new Table();
 tag213.setAttribute(new Attribute("name",new Text("class_list")),new Attribute("border",new NumberValue("1")));
-Tag tag214=new Tag("caption",false);
-Tag tag215=new Tag("span",false);
+paraselene.tag.Tag tag214=new Tag("caption",false);
+paraselene.tag.Tag tag215=new Tag("span",false);
 tag215.setAttribute(new Attribute("name",new Text("logic")));
 Text text284=new Text("logic");
 tag215.addHTMLPart(text284);
@@ -278,99 +279,99 @@ tag214.addHTMLPart(tag215);
 Text text285=new Text("クラス一覧");
 tag214.addHTMLPart(text285);
 tag213.addHTMLPart(tag214);
-Line tag217=new Line();
-Column tag218=new Column(Column.Type.HEADER);
+paraselene.tag.table.Line tag217=new Line();
+paraselene.tag.table.Column tag218=new Column(Column.Type.HEADER);
 Text text286=new Text("No ");
 tag218.addHTMLPart(text286);
 tag217.addHTMLPart(tag218);
-Column tag219=new Column(Column.Type.HEADER);
+paraselene.tag.table.Column tag219=new Column(Column.Type.HEADER);
 Text text288=new Text("モックアップファイル名");
 tag219.addHTMLPart(text288);
 tag217.addHTMLPart(tag219);
-Column tag220=new Column(Column.Type.HEADER);
+paraselene.tag.table.Column tag220=new Column(Column.Type.HEADER);
 Text text289=new Text("ページタイトル");
 tag220.addHTMLPart(text289);
 tag217.addHTMLPart(tag220);
-Column tag221=new Column(Column.Type.HEADER);
+paraselene.tag.table.Column tag221=new Column(Column.Type.HEADER);
 Text text290=new Text("クラス名");
 tag221.addHTMLPart(text290);
 tag217.addHTMLPart(tag221);
-Column tag222=new Column(Column.Type.HEADER);
+paraselene.tag.table.Column tag222=new Column(Column.Type.HEADER);
 Text text291=new Text("PageID");
 tag222.addHTMLPart(text291);
 tag217.addHTMLPart(tag222);
-Column tag223=new Column(Column.Type.HEADER);
+paraselene.tag.table.Column tag223=new Column(Column.Type.HEADER);
 Text text292=new Text("実行時URL\n※getAliasURI()が優先されます。");
 tag223.addHTMLPart(text292);
 tag217.addHTMLPart(tag223);
-Column tag225=new Column(Column.Type.HEADER);
+paraselene.tag.table.Column tag225=new Column(Column.Type.HEADER);
 Text text295=new Text("特記");
 tag225.addHTMLPart(text295);
 tag217.addHTMLPart(tag225);
 tag213.addHTMLPart(tag217);
-Line tag227=new Line();
-Column tag228=new Column(Column.Type.DATA);
+paraselene.tag.table.Line tag227=new Line();
+paraselene.tag.table.Column tag228=new Column(Column.Type.DATA);
 tag228.setAttribute(new Attribute("align",new Text("right")));
 Text text296=new Text("1");
 tag228.addHTMLPart(text296);
 tag227.addHTMLPart(tag228);
-Column tag229=new Column(Column.Type.DATA);
+paraselene.tag.table.Column tag229=new Column(Column.Type.DATA);
 Text text297=new Text("index.html");
 tag229.addHTMLPart(text297);
 tag227.addHTMLPart(tag229);
-Column tag230=new Column(Column.Type.DATA);
+paraselene.tag.table.Column tag230=new Column(Column.Type.DATA);
 Text text298=new Text("xxxx");
 tag230.addHTMLPart(text298);
 tag227.addHTMLPart(tag230);
-Column tag231=new Column(Column.Type.DATA);
+paraselene.tag.table.Column tag231=new Column(Column.Type.DATA);
 Text text299=new Text("x.logic.x");
 tag231.addHTMLPart(text299);
 tag227.addHTMLPart(tag231);
-Column tag232=new Column(Column.Type.DATA);
+paraselene.tag.table.Column tag232=new Column(Column.Type.DATA);
 Text text300=new Text("enum");
 tag232.addHTMLPart(text300);
 tag227.addHTMLPart(tag232);
-Column tag233=new Column(Column.Type.DATA);
+paraselene.tag.table.Column tag233=new Column(Column.Type.DATA);
 Text text301=new Text("on.x.na");
 tag233.addHTMLPart(text301);
 tag227.addHTMLPart(tag233);
-Column tag234=new Column(Column.Type.DATA);
+paraselene.tag.table.Column tag234=new Column(Column.Type.DATA);
 tag227.addHTMLPart(tag234);
 tag213.addHTMLPart(tag227);
 tag131.addHTMLPart(tag213);
 Text text313=new Text("\n");
 tag131.addHTMLPart(text313);
-Table tag236=new Table();
+paraselene.tag.table.Table tag236=new Table();
 tag236.setAttribute(new Attribute("name",new Text("ex_list")),new Attribute("border",new NumberValue("1")));
-Tag tag237=new Tag("caption",false);
+paraselene.tag.Tag tag237=new Tag("caption",false);
 Text text302=new Text("除外ファイル一覧");
 tag237.addHTMLPart(text302);
 tag236.addHTMLPart(tag237);
-Line tag239=new Line();
-Column tag240=new Column(Column.Type.HEADER);
+paraselene.tag.table.Line tag239=new Line();
+paraselene.tag.table.Column tag240=new Column(Column.Type.HEADER);
 Text text303=new Text("No");
 tag240.addHTMLPart(text303);
 tag239.addHTMLPart(tag240);
-Column tag241=new Column(Column.Type.HEADER);
+paraselene.tag.table.Column tag241=new Column(Column.Type.HEADER);
 Text text304=new Text("モックアップファイル名");
 tag241.addHTMLPart(text304);
 tag239.addHTMLPart(tag241);
-Column tag242=new Column(Column.Type.HEADER);
+paraselene.tag.table.Column tag242=new Column(Column.Type.HEADER);
 Text text306=new Text("解決パス");
 tag242.addHTMLPart(text306);
 tag239.addHTMLPart(tag242);
 tag236.addHTMLPart(tag239);
-Line tag244=new Line();
-Column tag245=new Column(Column.Type.DATA);
+paraselene.tag.table.Line tag244=new Line();
+paraselene.tag.table.Column tag245=new Column(Column.Type.DATA);
 tag245.setAttribute(new Attribute("align",new Text("right")));
 Text text307=new Text("1");
 tag245.addHTMLPart(text307);
 tag244.addHTMLPart(tag245);
-Column tag246=new Column(Column.Type.DATA);
+paraselene.tag.table.Column tag246=new Column(Column.Type.DATA);
 Text text308=new Text("index.html");
 tag246.addHTMLPart(text308);
 tag244.addHTMLPart(tag246);
-Column tag247=new Column(Column.Type.DATA);
+paraselene.tag.table.Column tag247=new Column(Column.Type.DATA);
 Text text309=new Text("index.html");
 tag247.addHTMLPart(text309);
 tag244.addHTMLPart(tag247);
@@ -379,7 +380,7 @@ tag131.addHTMLPart(tag236);
 tag124.addHTMLPart(tag131);
 setMainTag(tag124);
 setDoctype(false,null);
-addVersionMeta("Paraselene 2.0.4 (http://paraselene.sourceforge.jp/)","Mon Nov 09 21:53:42 JST 2009");
+addVersionMeta("Paraselene2 2.2.3 (http://paraselene.sourceforge.jp/)","Tue Oct 11 11:12:37 JST 2011");
 
 }
 catch(Exception e){}
@@ -402,6 +403,13 @@ public int getUploadMaxBytes(){return 0;}
 public boolean isCheckRepeatSameRequest(){ return false; }
 public AjaxSupport getAjaxSupport() { return AjaxSupport.NO; }
 public void firstOutput( RequestParameter req ) throws PageException{}
+/**
+ * ex.
+ * <br>&lt;span&gt;
+ **/
+public paraselene.tag.Tag getExSpan() {
+return (paraselene.tag.Tag)getTag( "ex" );
+}
 /**
  * ex.
  **/
@@ -410,10 +418,10 @@ return getAllTag( "ex" );
 }
 /**
  * ex_list.
- * <br>&lt;table&nbsp;name=&quot;ex_list&quot;&nbsp;border=&quot;1&quot;&gt;
+ * <br>&lt;table border=&quot;1&quot;&gt;
  **/
-public Table getExListTable() {
-return (Table)getTag( "ex_list" );
+public paraselene.tag.table.Table getExListTable() {
+return (paraselene.tag.table.Table)getTag( "ex_list" );
 }
 /**
  * ex_list.
@@ -423,10 +431,10 @@ return getAllTag( "ex_list" );
 }
 /**
  * title.
- * <br>&lt;title&nbsp;name=&quot;title&quot;&gt;
+ * <br>&lt;title&gt;
  **/
-public Tag getTitleTitle() {
-return (Tag)getTag( "title" );
+public paraselene.tag.Tag getTitleTitle() {
+return (paraselene.tag.Tag)getTag( "title" );
 }
 /**
  * title.
@@ -436,10 +444,10 @@ return getAllTag( "title" );
 }
 /**
  * source.
- * <br>&lt;td&nbsp;name=&quot;source&quot;&gt;
+ * <br>&lt;td&gt;
  **/
-public Column getSourceTd() {
-return (Column)getTag( "source" );
+public paraselene.tag.table.Column getSourceTd() {
+return (paraselene.tag.table.Column)getTag( "source" );
 }
 /**
  * source.
@@ -449,10 +457,10 @@ return getAllTag( "source" );
 }
 /**
  * root.
- * <br>&lt;td&nbsp;name=&quot;root&quot;&gt;
+ * <br>&lt;td&gt;
  **/
-public Column getRootTd() {
-return (Column)getTag( "root" );
+public paraselene.tag.table.Column getRootTd() {
+return (paraselene.tag.table.Column)getTag( "root" );
 }
 /**
  * root.
@@ -462,10 +470,10 @@ return getAllTag( "root" );
 }
 /**
  * base.
- * <br>&lt;span&nbsp;name=&quot;base&quot;&gt;
+ * <br>&lt;span&gt;
  **/
-public Tag getBaseSpan() {
-return (Tag)getTag( "base" );
+public paraselene.tag.Tag getBaseSpan() {
+return (paraselene.tag.Tag)getTag( "base" );
 }
 /**
  * base.
@@ -475,10 +483,10 @@ return getAllTag( "base" );
 }
 /**
  * view.
- * <br>&lt;span&nbsp;name=&quot;view&quot;&gt;
+ * <br>&lt;span&gt;
  **/
-public Tag getViewSpan() {
-return (Tag)getTag( "view" );
+public paraselene.tag.Tag getViewSpan() {
+return (paraselene.tag.Tag)getTag( "view" );
 }
 /**
  * view.
@@ -488,10 +496,10 @@ return getAllTag( "view" );
 }
 /**
  * uri_form.
- * <br>&lt;form&nbsp;id=&quot;paraselene$id$c1l6pzgtqgom&quot;&nbsp;name=&quot;uri_form&quot;&gt;
+ * <br>&lt;form id=&quot;paraselene$id$clap10zgqq71&quot;&gt;
  **/
-public Form getUriFormForm() {
-return (Form)getTag( "uri_form" );
+public paraselene.tag.form.Form getUriFormForm() {
+return (paraselene.tag.form.Form)getTag( "uri_form" );
 }
 /**
  * uri_form.
@@ -501,10 +509,10 @@ return getAllTag( "uri_form" );
 }
 /**
  * echo.
- * <br>&lt;div&nbsp;name=&quot;echo&quot;&gt;
+ * <br>&lt;div&gt;
  **/
-public Tag getEchoDiv() {
-return (Tag)getTag( "echo" );
+public paraselene.tag.Tag getEchoDiv() {
+return (paraselene.tag.Tag)getTag( "echo" );
 }
 /**
  * echo.
@@ -514,10 +522,10 @@ return getAllTag( "echo" );
 }
 /**
  * url.
- * <br>&lt;input&nbsp;style=&quot;background-color:#FFFF00;&quot;&nbsp;name=&quot;url&quot;&nbsp;value=&quot;http://&quot;&nbsp;type=&quot;text&quot;&nbsp;size=&quot;60&quot;&gt;
+ * <br>&lt;input style=&quot;background-color:#FFFF00;&quot; value=&quot;http://&quot; type=&quot;text&quot; size=&quot;60&quot;&gt;
  **/
-public SingleTextBox getUrlInput() {
-return (SingleTextBox)getTag( "url" );
+public paraselene.tag.form.SingleTextBox getUrlInput() {
+return (paraselene.tag.form.SingleTextBox)getTag( "url" );
 }
 /**
  * url.
@@ -525,6 +533,31 @@ return (SingleTextBox)getTag( "url" );
 public Tag[] getUrlTags() {
 return getAllTag( "url" );
 }
+/**
+ * logic.
+ * <br>&lt;span&gt;
+ **/
+public paraselene.tag.Tag getLogicSpan() {
+return (paraselene.tag.Tag)getTag( "logic" );
+}
+/**
+ * class_list用getLogicSpan.
+ **/
+public paraselene.tag.Tag getLogicSpan4ClassList(int y)throws Table.TableException{
+Table table=(Table)getTag("class_list");
+if (table==null) return null;
+return (paraselene.tag.Tag)table.getFirstInnerHTMLPart(y,getAllTag("logic"));
+}
+/**
+ * class_list用getLogicSpan.
+ **/
+public paraselene.tag.Tag getLogicSpan4ClassList(int no,int y)throws Table.TableException{
+Tag[] tag=getAllTag("class_list");
+if (tag==null) return null;
+ if (no<0 || no>=tag.length) return null;
+Table table=(Table)tag[no];
+return (paraselene.tag.Tag)table.getFirstInnerHTMLPart(y,getAllTag("logic"));
+}
 /**
  * logic.
  **/
@@ -533,10 +566,10 @@ return getAllTag( "logic" );
 }
 /**
  * class_list.
- * <br>&lt;table&nbsp;name=&quot;class_list&quot;&nbsp;border=&quot;1&quot;&gt;
+ * <br>&lt;table border=&quot;1&quot;&gt;
  **/
-public Table getClassListTable() {
-return (Table)getTag( "class_list" );
+public paraselene.tag.table.Table getClassListTable() {
+return (paraselene.tag.table.Table)getTag( "class_list" );
 }
 /**
  * class_list.
@@ -544,6 +577,27 @@ return (Table)getTag( "class_list" );
 public Tag[] getClassListTags() {
 return getAllTag( "class_list" );
 }
+/**
+ * name 属性の検証。
+ * @param page 検証するページ
+ * @param exclude 検証から除外する name。
+ * @return エラーとなった name。
+ */
+public NameDefine[] inspectName(Page page,String ... exclude){
+return DynamicPage.inspectName(page,new NameDefine[]{
+new NameDefine("ex",paraselene.tag.Tag.class),
+new NameDefine("title",paraselene.tag.Tag.class),
+new NameDefine("ex_list",paraselene.tag.table.Table.class),
+new NameDefine("source",paraselene.tag.table.Column.class),
+new NameDefine("root",paraselene.tag.table.Column.class),
+new NameDefine("base",paraselene.tag.Tag.class),
+new NameDefine("view",paraselene.tag.Tag.class),
+new NameDefine("echo",paraselene.tag.Tag.class),
+new NameDefine("uri_form",paraselene.tag.form.Form.class),
+new NameDefine("logic",paraselene.tag.Tag.class),
+new NameDefine("url",paraselene.tag.form.SingleTextBox.class),
+new NameDefine("class_list",paraselene.tag.table.Table.class)},exclude);
+}
 
 }
 
