@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -30,7 +30,8 @@ public class Closure extends Forward implements AjaxForward {
 
 	private static PageID getLastPage( Page myself, History history ) {
 		if ( myself == null || history == null )	return CLOSE;
-		if ( myself.getPopupType() != null )	return myself.getID();
+		//if ( myself.getPopupType() != null )	return myself.getID();
+		myself = myself.getParentPage();
 		Page	last = history.getPage();
 		if ( myself == last ) {
 			for ( int i = 1; last != null; i++ ) {
@@ -63,6 +64,7 @@ public class Closure extends Forward implements AjaxForward {
 	public Closure() {
 		super( getLastPage( SandBox.getCurrentPage().getParentPage(), SandBox.getCurrentRequestParameter().getHistory() ) );
 		close_page = SandBox.getCurrentPage().getParentPage();
+		Option.traceWithStack( "close %s", close_page.getID() );
 	}
 
 	/**
@@ -73,6 +75,7 @@ public class Closure extends Forward implements AjaxForward {
 	public Closure( Page page ) {
 		super( page.getParentPage().getID() );
 		close_page = page.getParentPage();
+		Option.traceWithStack( "close %s", close_page.getID() );
 	}
 
 	boolean is_refresh() {
@@ -81,8 +84,9 @@ public class Closure extends Forward implements AjaxForward {
 
 	static boolean isClosure( Page from, Page next, RequestParameter req ) {
 		if ( from == null || next == null )	return false;
+		if ( (from instanceof NullPage) || (next instanceof NullPage) )	return false;
 		if ( from.getPopupType() != null )	return true;
-		return next.getID() == getLastPage( from, req.getHistory( from.getHistoryKey() ) );
+		return next.getParentPage().getID() == getLastPage( from, req.getHistory( from.getHistoryKey() ) );
 	}
 
 	public String toString() {
@@ -92,22 +96,22 @@ public class Closure extends Forward implements AjaxForward {
 		return buf.toString();
 	}
 
-	OutputCall makeOutput( int nk, Page lp, RequestParameter r, SessionData sd ) {
+	OutputCall makeOutput( PageFactory pf, int nk, Page lp, RequestParameter r, SessionData sd ) {
 		if ( close_page.getPopupType() == null ) {
 			Option.trace( "new LocationOutput <- %s", this );
-			return new LocationOutput( nk, lp, this, r, sd );
+			return new LocationOutput( pf, nk, lp, this, r, sd );
 		}
 		Option.trace( "new CloseOutput <- %s", this );
-		return new CloseOutput( nk, lp, this, r, sd );
+		return new CloseOutput( pf, nk, lp, this, r, sd );
 	}
 
-	CometCall makeCometCall( History h ) {
+	CometCall makeCometCall( PageFactory pf, History h ) {
 		if ( close_page.getPopupType() == null ) {
 			Option.trace( "new LocationCometCall <- %s", this );
-			return new LocationCometCall( h, this );
+			return new LocationCometCall( pf, h, this );
 		}
 		Option.trace( "new CloseCometCall <- %s", this );
-		return new CloseCometCall( h, this );
+		return new CloseCometCall( pf, h, this );
 	}
 }
 
