@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -55,9 +55,9 @@ class CometCall {
 		}
 	}
 
-	CometCall( History h, Forward f ) {
+	CometCall( PageFactory pf, History h, Forward f ) {
 		hist = h;
-		next_page = f.getPage( null );
+		next_page = f.getPage( pf, null );
 		if ( f.isRefresh( true ) ) {
 			setModify( next_page );
 		}
@@ -70,9 +70,9 @@ class CometCall {
 }
 
 class OpenCometCall extends CometCall {
-	OpenCometCall( History h, Forward f, Popup.Type type ) {
-		super( h, f );
-		next_page.setPopupType( type );
+	OpenCometCall( PageFactory pf, History h, Forward f, DialogType type ) {
+		super( pf, h, f );
+		next_page.setPopupType( type, null );
 	}
 
 	PostBack[] make() throws Exception {
@@ -81,8 +81,8 @@ class OpenCometCall extends CometCall {
 }
 
 class CloseCometCall extends CometCall {
-	CloseCometCall( History h, Closure f ) {
-		super( h, f );
+	CloseCometCall( PageFactory pf, History h, Closure f ) {
+		super( pf, h, f );
 	}
 
 	PostBack[] make() throws Exception {
@@ -92,8 +92,8 @@ class CloseCometCall extends CometCall {
 }
 
 class ScriptCometCall extends CometCall {
-	ScriptCometCall( History h, Forward f ) {
-		super( h, f );
+	ScriptCometCall( PageFactory pf, History h, Forward f ) {
+		super( pf, h, f );
 	}
 
 	PostBack[] make() throws Exception {
@@ -102,8 +102,8 @@ class ScriptCometCall extends CometCall {
 }
 
 class NopCometCall extends CometCall {
-	NopCometCall( History h, Forward f ) {
-		super( h, f );
+	NopCometCall( PageFactory pf, History h, Forward f ) {
+		super( pf, h, f );
 	}
 
 	PostBack[] make() throws Exception {
@@ -112,13 +112,14 @@ class NopCometCall extends CometCall {
 }
 
 class LocationCometCall extends CometCall {
-	LocationCometCall( History h, Forward f ) {
-		super( h, f );
+	LocationCometCall( PageFactory pf, History h, Forward f ) {
+		super( pf, h, f );
 	}
 
 	PostBack[] make() throws Exception {
 		String	url = null;
-		if ( !forward.isLeave() ) {
+		boolean	same_f = !forward.isLeave();
+		if ( same_f ) {
 			url = URIValue.pageToURI( forward.getPageID(), null );
 		}
 		else {
@@ -130,7 +131,7 @@ class LocationCometCall extends CometCall {
 		if ( tag == null )	return new PostBack[0];
 		url = Supervisor.makeWithSessionURI( url, null, tag );
 		Option.trace( "%s redirect JSON", url );
-		return new PostBack[] { new PostBack( url ) };
+		return new PostBack[] { new PostBack( url, same_f ) };
 	}
 }
 
@@ -138,7 +139,7 @@ class CometHolder {
 	private	Forward[]	forward = null;
 	private CometCall[]	cc = null;
 
-	CometHolder( History hist, Forward fw ) {
+	CometHolder( PageFactory pf, History hist, Forward fw ) {
 		AjaxForward[]	af = fw.getAjaxForward( true );
 		if ( af != null ) {
 			forward = new Forward[af.length];
@@ -152,7 +153,7 @@ class CometHolder {
 			cc = new CometCall[1];
 		}
 		for ( int i = 0; i < forward.length; i++ ) {
-			cc[i] = forward[i].makeCometCall( hist );
+			cc[i] = forward[i].makeCometCall( pf, hist );
 		}
 	}
 
