@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -14,6 +14,29 @@ import paraselene.*;
 import paraselene.ajax.data.*;
 import paraselene.ajax.*;
 import paraselene.ui.*;
+import paraselene.tag.*;
+
+
+class CallStack {
+	private static final long serialVersionUID = 2L;
+	Child	child;
+	private Page	dialog;
+	Forward	fw;
+	volatile Object	result = null;
+	CallStack( Child base, Page call, EphemeralPosition p, Tag hint ) {
+		child = base;
+		dialog = call.getParentPage();
+		fw = new EphemeralPopup( dialog, p, hint );
+	}
+	boolean isMyself( Child ch ) {
+		return child == ch;
+	}
+	boolean isMyself( Page p ) {
+		p = p.getParentPage();
+		Option.trace( "isMyself:dialog(%s) <-> p(%s)", dialog.getUniqueKey(), p.getUniqueKey() );
+		return dialog.getUniqueKey().equals( p.getUniqueKey() );
+	}
+}
 
 /**
  * 画面遷移履歴。<br>
@@ -30,6 +53,111 @@ public class History implements Serializable {
 	volatile boolean drop_f = false;
 	volatile String	session_id;
 
+	private transient LinkedList<CallStack>	callstack = null;
+
+	void callStack( Child base, Page call, EphemeralPosition p, Tag hint ) {
+		Option.trace( "callStack:%s %s", base, call.getID() );
+		synchronized( callstack ) {
+			callstack.push( new CallStack( base, call, p, hint ) );
+		}
+	}
+	Object popStack( Child base ) {
+		synchronized( callstack ) {
+			while( callstack.size() > 0 ) {
+				CallStack	cs = callstack.pop();
+				if ( cs.isMyself( base ) ) {
+					Object	ret = cs.result;
+					if ( ret == null )	return EphemeralPage.NO_ANSWER;
+					return ret;
+				}
+				if ( cs.child == null )	continue;
+				synchronized( cs.child ) {
+					unlock();
+					cs.child.notifyAll();
+				}
+			}
+		}
+		return EphemeralPage.ABORT;
+	}
+	private void deadStack( Page p ) {
+		if ( hist.contains( p ) )	return;
+		Option.traceWithStack( "deadStack: %s", p.getID() );
+		synchronized( callstack ) {
+			boolean	flag = false;
+			for ( CallStack	cs: callstack ) {
+				if ( flag = cs.isMyself( p ) )	break;
+			}
+			if ( !flag )	return;
+			while( callstack.size() > 0 ) {
+				CallStack	cs = callstack.pop();
+				flag = cs.isMyself( p );
+				if ( cs.child == null )	continue;
+				synchronized( cs.child ) {
+					unlock();
+					cs.child.notifyAll();
+				}
+				if ( flag )	return;
+			}
+		}
+	}
+	private Child continueStack( Page p, Object result ) {
+		Option.traceWithStack( "continueStack:%s / return %s", p.getID(), result );
+		synchronized( callstack ) {
+			boolean	flag = false;
+			for ( CallStack	cs: callstack ) {
+				if ( flag = cs.isMyself( p ) )	break;
+			}
+			if ( !flag ) {
+				Option.trace( "continueStack null return" );
+				return null;
+			}
+			while( callstack.size() > 0 ) {
+				CallStack	cs = callstack.pop();
+				if ( cs.child == null )	continue;
+				if ( cs.isMyself( p ) ) {
+					cs.result = result;
+					callstack.push( cs );
+					return cs.child;
+				}
+				synchronized( cs.child ) {
+					unlock();
+					cs.child.notifyAll();
+				}
+			}
+		}
+		Option.trace( "continueStack null return" );
+		return null;
+	}
+	private Forward returnStack( Closure fw ) throws Throwable {
+		Page	page = ((Closure)fw).close_page;
+		Object	result = ( fw instanceof EphemeralClosure )?
+			((EphemeralClosure)fw).result_data:	null;
+		Child	child = continueStack( page, result );
+		if ( child != null )	return Forward.merge( fw, SandBox.input_sub( child, false, this ) );
+		return fw;
+	}
+	Forward returnStack( Forward fw, boolean call_f ) throws Throwable {
+		if ( callstack == null )	callstack = new LinkedList<CallStack>();
+		if ( call_f && fw instanceof Closure )	return returnStack( (Closure)fw );
+		if ( fw.isAjaxHold() ) {
+			ArrayList<Forward>	list = new ArrayList<Forward>();
+			for ( AjaxForward af: fw.getAjaxForward( true ) ) {
+				list.add( (Forward)af );
+				if ( af instanceof Closure ) list.add( returnStack( (Closure)af, call_f ) );
+			}
+			return Forward.merge( list.toArray( new Forward[0] ) );
+		}
+		return fw;
+	}
+	Forward getStackForward( Child c ) {
+		synchronized( callstack ) {
+			for ( CallStack cs:	callstack ) {
+				if ( cs.isMyself( c ) )	return cs.fw;
+			}
+		}
+		return null;
+	}
+
 	private void comet_stop( Page p ) {
 		StringBuilder	buf = new StringBuilder( "paraselene.comet_stop('" );
 		buf = buf.append( p.getUniqueKey() );
@@ -62,8 +190,11 @@ public class History implements Serializable {
 	/**
 	 * コンストラクタ。
 	 */
-	private History() {}
+	private History() {
+		callstack = new LinkedList<CallStack>();
+	}
 	History( int n, String s ) {
+		this();
 		histry_no = n;
 		session_id = s;
 	}
@@ -75,7 +206,10 @@ public class History implements Serializable {
 	public void addSatellitePage( Page page ) {
 		if ( page == null )	return;
 		synchronized( popup ) {
-			removePopup( page );
+			String	key = page.getUniqueKey();
+			for ( Page p: popup ) {
+				if ( p.getUniqueKey().equals( key ) )	return;
+			}
 			setInfo( page );
 			popup.add( page );
 		}
@@ -117,7 +251,7 @@ public class History implements Serializable {
 			int	cnt = popup.size();
 			for ( int i = 0; i < cnt; i++ ) {
 				if ( popup.get( i ).getUniqueKey().equals( key ) ) {
-					popup.remove( i );
+					deadStack( popup.remove( i ) );
 					Option.trace( "removePopup %s", key );
 					return;
 				}
@@ -128,6 +262,7 @@ public class History implements Serializable {
 
 	private void clearPopup() {
 		synchronized( popup ) {
+			for ( Page p: popup )	deadStack( p );
 			popup.clear();
 			Option.traceWithStack( "popup clear" );
 		}
@@ -154,7 +289,9 @@ public class History implements Serializable {
 					Page	h = hist.get( i );
 					if ( page.equals( h ) ) {
 						for ( int j = cnt -1; j >= i; j-- ) {
-							hist.remove( j ).setHistoryKey( HistorySet.ROOT );
+							Page	tmp = hist.remove( j );
+							tmp.setHistoryKey( HistorySet.ROOT );
+							if ( page != tmp )	deadStack( tmp );
 						}
 						break;
 					}
@@ -249,37 +386,64 @@ public class History implements Serializable {
 				list.add( popup.get( i ) );
 			}
 		}
-		list.add( getPage() );
+		Page	p = getPage();
+		if ( p != null )	list.add( p );
+		return list.toArray( new Page[0] );
+	}
+
+	private Page[] getBrowsingPage( Page page, PageID ... id ) {
+		Page[]	dmy = new Page[0];
+		if ( page == null )	return dmy;
+		ArrayList<Page>	list = new ArrayList<Page>();
+		PageID	pid = page.getID();
+		for ( PageID i: id ) {
+			if ( pid.getID() == i.getID() ) {
+				list.add( page );
+				break;
+			}
+		}
+		for ( PageBypassedDiv div: page.getPageBypassedDiv() ) {
+			for ( Page b: getBrowsingPage( div.getBypassPage(), id ) ) {
+				list.add( b );
+			}
+		}
+		return list.toArray( dmy );
+	}
+
+	/**
+	 * 現在カレントのブラウザで表示されているページから、ページIDが一致する
+	 * ものを返します。
+	 * ポップアップやバイパスページを含めて探します。
+	 * @param id 検索するID。
+	 * @return 該当ページ。
+	 */
+	public Page[] getBrowsingPage( PageID ... id ) {
+		ArrayList<Page>	list = new ArrayList<Page>();
+		for ( Page p: getBrowsingPage() ) {
+			for ( Page p2: getBrowsingPage( p, id ) ) {
+				initSatellitePage( p2 );
+				list.add( p2 );
+			}
+		}
 		return list.toArray( new Page[0] );
 	}
 
 	/**
 	 * 現在カレントのブラウザで表示されているページから、ユニークキー
 	 * ({@link paraselene.Page#getUniqueKey()})が一致するものを返します。
-	 * ポップアップを含めて探します。
+	 * ポップアップやバイパスページを含めて探します。
 	 * @param uni ユニークキー。
 	 * @return 一致したページ。
 	 */
 	public Page getBrowsingPage( String uni ) {
 		Option.trace( "getBrowsingPage  %d >> %s", hashCode(), uni );
 		Page	page = null;
-		synchronized( popup ) {
-			int cnt = popup.size();
-			for ( int i = 0; i < cnt; i++ ){
-				page = popup.get( i );
-				Option.trace( "getBrowsingPage popup %d %s", hashCode(), page.getUniqueKey() );
-				if ( page.getUniqueKey().equals( uni ) )	return page;
-			}
-		}
-		synchronized( hist ) {
-			int	cnt = getHistoryCount();
-			for ( int i = 0; i < cnt; i++ ) {
-				page = hist.get( i );
-				Page	hit = page.getBypassPage( uni );
-				if ( hit != null ) {
-					initSatellitePage( page );
-					return hit;
-				}
+		for ( Page p: getBrowsingPage() ) {
+			if ( p.getUniqueKey().equals( uni ) )	return p;
+			p = p.getBypassPage( uni );
+			if ( p != null ) {
+				initSatellitePage( page );
+				return p;
 			}
 		}
 		return null;
@@ -297,7 +461,9 @@ public class History implements Serializable {
 			int	cnt = getHistoryCount();
 			for ( int i = cnt - 1; i >= 0; i-- ) {
 				if ( last_no == 0 )	{
-					hist.remove( i ).setHistoryKey( HistorySet.ROOT );
+					Page	old = hist.remove( i );
+					old.setHistoryKey( HistorySet.ROOT );
+					deadStack( old );
 					return;
 				}
 				last_no--;
@@ -318,7 +484,9 @@ public class History implements Serializable {
 			for ( int i = cnt - 1; i >= 0; i-- ) {
 				Page	page = hist.get( i );
 				if ( page.getID() == page_id )	{
-					hist.remove( i ).setHistoryKey( HistorySet.ROOT );
+					Page	old = hist.remove( i );
+					old.setHistoryKey( HistorySet.ROOT );
+					deadStack( old );
 					if ( i == (cnt - 1) ) {
 						clearPopup();
 						init_f = true;
@@ -338,7 +506,9 @@ public class History implements Serializable {
 		synchronized( hist ) {
 			int	cnt = getHistoryCount();
 			for ( int i = 0; i < cnt; i++ ) {
-				hist.get( i ).setHistoryKey( HistorySet.ROOT );
+				Page	old = hist.get( i );
+				old.setHistoryKey( HistorySet.ROOT );
+				deadStack( old );
 			}
 			hist.clear();
 		}
