@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -41,14 +41,14 @@ public class JavaScript extends Feedback {
 		return false;
 	}
 
-	OutputCall makeOutput( int nk, Page lp, RequestParameter r, SessionData sd ) {
+	OutputCall makeOutput( PageFactory pf, int nk, Page lp, RequestParameter r, SessionData sd ) {
 		Option.trace( "new ScriptOutput <- %s", this );
-		return new ScriptOutput( nk, lp, this, r, sd );
+		return new ScriptOutput( pf, nk, lp, this, r, sd );
 	}
 
-	CometCall makeCometCall( History h ) {
+	CometCall makeCometCall( PageFactory pf, History h ) {
 		Option.trace( "new ScriptCometCall <- %s", this );
-		return new ScriptCometCall( h, this );
+		return new ScriptCometCall( pf, h, this );
 	}
 }
 
