@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -30,14 +30,14 @@ public class NOP extends Feedback {
 		return false;
 	}
 
-	OutputCall makeOutput( int nk, Page lp, RequestParameter r, SessionData sd ) {
+	OutputCall makeOutput( PageFactory pf, int nk, Page lp, RequestParameter r, SessionData sd ) {
 		Option.trace( "new NopOutput <- %s", this );
-		return new NopOutput( nk, lp, this, r, sd );
+		return new NopOutput( pf, nk, lp, this, r, sd );
 	}
 
-	CometCall makeCometCall( History h ) {
+	CometCall makeCometCall( PageFactory pf, History h ) {
 		Option.trace( "new NopCometCall <- %s", this );
-		return new NopCometCall( h, this );
+		return new NopCometCall( pf, h, this );
 	}
 }
 
