@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -10,6 +10,7 @@ package paraselene.supervisor;
 import java.net.*;
 import java.io.*;
 import paraselene.*;
+import paraselene.tag.form.*;
 
 
 /**
@@ -67,3 +68,23 @@ class NullPage4Alias extends NullPage {
 	}
 }
 
+class Service extends NullPage {
+	Page	page = null;
+	Page	last = null;
+
+	public Forward input( RequestParameter req, Forward fw ) throws PageException {
+		RequestItem	item = req.getItem( PageFactory.CLOSE_ID );
+		if ( item == null )	return new Forward( 403 );
+		String[]	id = item.getAllValue();
+		if ( id.length != 1)	return new Forward( 403 );
+		Closure	cls = null;
+		History	hist = req.getHistory();
+		page = hist.getBrowsingPage( id[0] );
+		last = hist.getBrowsingPage( req.getItem( Form.FORM_AJAX ).getValue( 0 ) );
+		cls = new Closure( page );
+		return new Forward( cls );
+	}
+	public AjaxSupport getAjaxSupport() { return AjaxSupport.POPUP_DIALOG; }
+	public boolean isAjax() { return true; }
+}
+
