@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -200,8 +200,11 @@ public class Option implements Serializable {
 	 * @param param パラメーター。
 	 */
 	public static void debug( String format, Object ... param ) {
-		if ( isReleaseMode() )	return;
-		debug( String.format( format, param ), Thread.currentThread().getStackTrace() );
+		try {
+			if ( isReleaseMode() )	return;
+			debug( String.format( format, param ), Thread.currentThread().getStackTrace() );
+		}
+		catch(Exception e){}
 	}
 
 	/**
@@ -209,9 +212,9 @@ public class Option implements Serializable {
 	 * @param e 例外。
 	 */
 	public static void debug( Throwable e ) {
-		if ( isReleaseMode() )	return;
 		System.out.println( new java.util.Date().toString() );
 		e.printStackTrace();
+		if ( isReleaseMode() )	return;
 		debug( e.toString(), e.getStackTrace() );
 	}
 
@@ -349,14 +352,20 @@ public class Option implements Serializable {
 		trace( buf.toString(), false );
 	}
 
-	static void trace( String format, Object ... o ) {
-		if ( trace_writer == null )	return;
-		trace( String.format( format, o ), false );
+	public static void trace( String format, Object ... o ) {
+		try {
+			if ( trace_writer == null )	return;
+			trace( String.format( format, o ), false );
+		}
+		catch( Exception e ){}
 	}
 
-	static void traceWithStack( String format, Object ... o ) {
-		if ( trace_writer == null )	return;
-		trace( String.format( format, o ), true );
+	public static void traceWithStack( String format, Object ... o ) {
+		try {
+			if ( trace_writer == null )	return;
+			trace( String.format( format, o ), true );
+		}
+		catch( Exception e ){}
 	}
 }
 
