@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -9,6 +9,7 @@ package paraselene.supervisor;
 import java.util.*;
 import java.io.*;
 import paraselene.*;
+import paraselene.tag.*;
 import paraselene.ajax.*;
 import paraselene.ajax.data.*;
 
@@ -25,10 +26,10 @@ class OutputCall {
 		return out;
 	}
 
-	OutputCall( int nk, Page lp, Forward fw, RequestParameter r, SessionData sd ) {
+	OutputCall( PageFactory pf, int nk, Page lp, Forward fw, RequestParameter r, SessionData sd ) {
 		next_key = nk;
 		last_page = ( lp instanceof NullPage)?	null:	lp;
-		next_page = fw.getPage( lp );
+		next_page = fw.getPage( pf, lp );
 		forward = fw;
 		req = r;
 		data = sd;
@@ -37,12 +38,12 @@ class OutputCall {
 		}
 	}
 
-	void call_main( boolean refresh_f ) throws Throwable {
+	void call_main( PageFactory pf, boolean refresh_f ) throws Throwable {
 		next_page.setRequestParameter( req );
-		Option.trace( "%s/%s output(%s) call", next_page.getID(), next_page.getUniqueKey(), (last_page == null)?	"null": last_page.getID() );
+		Option.traceWithStack( "%s/%s output(%s) call", next_page.getID(), next_page.getUniqueKey(), (last_page == null)?	"null": last_page.getID() );
 		data.hist.forceNewNo( next_page.getHistoryKey() );
 		data.hist.get( next_page.getHistoryKey() ).add( next_page.getParentPage() );
-		Page	view = SandBox.output( next_page, last_page, req, refresh_f );
+		Page	view = SandBox.output( pf, next_page, last_page, req, refresh_f );
 		if ( view == null )	view = next_page;
 		next_page.setAgencyPage( view );
 		next_page.setInitialized( false );
@@ -55,7 +56,7 @@ class OutputCall {
 		out = new Page[]{ next_page, view };
 	}
 
-	void call( boolean refresh_f ) throws Throwable {
+	void call( PageFactory pf, boolean refresh_f ) throws Throwable {
 		PageID	last_id = null;
 		if ( last_page != null ) {
 			last_id = last_page.getID();
@@ -63,7 +64,7 @@ class OutputCall {
 		if ( data == null )	return;
 		if ( forward.history_f ) {
 			if ( next_page.getID() == last_id ) {
-				last_id.getPageFactory().returnPage( next_page );
+				pf.returnPage( next_page );
 				next_page = last_page;
 			}
 			else if ( next_page.isAllowHistoryAdd() ) {
@@ -73,12 +74,12 @@ class OutputCall {
 					sub = history.getPage( next_page.getID() );
 				}
 				if ( sub != null ) {
-					next_page.getID().getPageFactory().returnPage( next_page );
+					pf.returnPage( next_page );
 					next_page = sub;
 				}
 			}
 		}
-		call_main( refresh_f );
+		call_main( pf, refresh_f );
 	}
 
 	static PostBack[] make( History h, Page next_page, Page[] out, boolean lock_f ) throws Exception {
@@ -106,19 +107,19 @@ class OutputCall {
 }
 
 class OpenOutput extends OutputCall {
-	OpenOutput( int nk, Page lp, Forward fw, Popup.Type type, RequestParameter r, SessionData sd ) {
-		super( nk, lp, fw, r, sd );
-		next_page.setPopupType( type );
+	OpenOutput( PageFactory pf, int nk, Page lp, Forward fw, DialogType type, Tag hint, RequestParameter r, SessionData sd ) {
+		super( pf, nk, lp, fw, r, sd );
+		next_page.setPopupType( type, hint );
 	}
 
-	void call( boolean refresh_f ) throws Throwable {
+	void call( PageFactory pf, boolean refresh_f ) throws Throwable {
 		Popup	p = (Popup)forward;
 		if ( p.active_page != null )	return;
-		call_main( refresh_f );
+		call_main( pf, refresh_f );
 	}
 
 	static PostBack[] make( Popup p, History h, Page next_page, Page out, boolean lock_f  ) throws Exception {
-		if ( p.active_page == null ) {
+		if ( p.active_page == null || p instanceof EphemeralPopup ) {
 			h.add( next_page );
 			Option.trace( "%s/%s to Popup open JSON", next_page.getID(), next_page.getUniqueKey() );
 			try {
@@ -129,7 +130,7 @@ class OpenOutput extends OutputCall {
 				if ( lock_f )	h.unlock();
 			}
 		}
-		Popup.Type	ptype = p.active_page.getPopupType();
+		DialogType	ptype = p.active_page.getPopupType();
 		if ( !Popup.isModeless( ptype ) ) {
 			Option.trace( "%s/%s to Popup active cancel, because it is not MODELESS opened", next_page.getID(), next_page.getUniqueKey() );
 			return new PostBack[0];
@@ -154,11 +155,11 @@ class OpenOutput extends OutputCall {
 }
 
 class CloseOutput extends OutputCall {
-	CloseOutput( int nk, Page lp, Forward fw, RequestParameter r, SessionData sd ) {
-		super( nk, lp, fw, r, sd );
+	CloseOutput( PageFactory pf, int nk, Page lp, Forward fw, RequestParameter r, SessionData sd ) {
+		super( pf, nk, lp, fw, r, sd );
 	}
 
-	void call( boolean refresh_f ) throws Throwable {}
+	void call( PageFactory pf, boolean refresh_f ) throws Throwable {}
 
 	static PostBack[] make( Closure c, History h, Page next_page ) {
 		h.removePopup( c.close_page );
@@ -173,10 +174,10 @@ class CloseOutput extends OutputCall {
 }
 
 class ScriptOutput extends OutputCall {
-	ScriptOutput( int nk, Page lp, Forward fw, RequestParameter r, SessionData sd ) {
-		super( nk, lp, fw, r, sd );
+	ScriptOutput( PageFactory pf, int nk, Page lp, Forward fw, RequestParameter r, SessionData sd ) {
+		super( pf, nk, lp, fw, r, sd );
 	}
-	void call( boolean refresh_f ) throws Throwable {}
+	void call( PageFactory pf, boolean refresh_f ) throws Throwable {}
 
 	static PostBack[] make( JavaScript js ) throws Exception {
 		StringBuilder	buf = new StringBuilder();
@@ -195,10 +196,10 @@ class ScriptOutput extends OutputCall {
 }
 
 class NopOutput extends OutputCall {
-	NopOutput( int nk, Page lp, Forward fw, RequestParameter r, SessionData sd ) {
-		super( nk, lp, fw, r, sd );
+	NopOutput( PageFactory pf, int nk, Page lp, Forward fw, RequestParameter r, SessionData sd ) {
+		super( pf, nk, lp, fw, r, sd );
 	}
-	void call( boolean refresh_f ) throws Throwable {}
+	void call( PageFactory pf, boolean refresh_f ) throws Throwable {}
 
 	static PostBack[] _make() throws Exception {
 		Option.trace( "NOP JSON" );
@@ -211,24 +212,26 @@ class NopOutput extends OutputCall {
 }
 
 class LocationOutput extends OutputCall {
-	LocationOutput( int nk, Page lp, Forward fw, RequestParameter r, SessionData sd ) {
-		super( nk, lp, fw, r, sd );
+	LocationOutput( PageFactory pf, int nk, Page lp, Forward fw, RequestParameter r, SessionData sd ) {
+		super( pf, nk, lp, fw, r, sd );
+		Option.traceWithStack( "%s", fw.toString() );
 	}
 
-	void call( boolean refresh_f ) throws Throwable {
-		if ( !forward.isLeave() )	super.call( refresh_f );
+	void call( PageFactory pf, boolean refresh_f ) throws Throwable {
+		if ( !forward.isLeave() )	super.call( pf, refresh_f );
 	}
 
 	PostBack[] make() throws Exception {
 		data.hist.forceNewNo( next_key );
 		data.hist.get( next_key ).add( next_page );
 		Forward	fw = forward;
-		if ( !forward.isLeave() ) {
+		boolean	same_f = !forward.isLeave();
+		if ( same_f ) {
 			fw = data.redirect( out, forward, req );
 		}
 		String	url = Supervisor.makeWithSessionURI( fw.getRedirectURI().toString(), null, null );
 		Option.trace( "%s redirect JSON", url );
-		return new PostBack[] { new PostBack( url ) };
+		return new PostBack[] { new PostBack( url, same_f ) };
 	}
 }
 
@@ -237,7 +240,7 @@ class OutputHolder {
 	private OutputCall[]	opc = null;
 	private boolean[]		refresh_f = null;
 
-	OutputHolder( boolean ajax_f, int nk, Page lp, Forward fw, RequestParameter r, SessionData sd ) {
+	OutputHolder( PageFactory pf, boolean ajax_f, int nk, Page lp, Forward fw, RequestParameter r, SessionData sd ) {
 		Option.trace( "%s ajax %s", lp.getID(), ajax_f );
 		AjaxForward[]	af = fw.getAjaxForward( ajax_f );
 		if ( af != null ) {
@@ -256,21 +259,17 @@ class OutputHolder {
 		}
 		if ( ajax_f ) {
 			for ( int i = 0; i < forward.length; i++ ) {
-				opc[i] = forward[i].makeOutput( nk, lp, r, sd );
+				opc[i] = forward[i].makeOutput( pf, nk, lp, r, sd );
 			}
 			return;
 		}
-/**
-		Option.trace( "new OutputCall <- %s", forward[0] );
-		opc[0] = new OutputCall( nk, lp, forward[0], r, sd );
-**/
 		Option.trace( "new LocationOutput <- %s", forward[0] );
-		opc[0] = new LocationOutput( nk, lp, forward[0], r, sd );
+		opc[0] = new LocationOutput( pf, nk, lp, forward[0], r, sd );
 	}
 
-	void call() throws Throwable {
+	void call( PageFactory pf ) throws Throwable {
 		for ( int i = 0; i < opc.length; i++ ) {
-			opc[i].call( refresh_f[i] );
+			opc[i].call( pf, refresh_f[i] );
 		}
 	}
 
