@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -23,6 +23,27 @@ class AliasData {
  * スレッドセーフです。
  */
 public abstract class PageFactory extends Thread {
+	private class XenoID implements PageID {
+		private int id;
+		private String name;
+		private XenoID( int n, String cls ) {
+			id = n;
+			name = cls;
+		}
+		public boolean isSame( Page p ) { return p.getID() == this; }
+		public int getID() { return id; }
+		public PageFactory getPageFactory() { return SandBox.getPageFactory(); }
+		public PageID getPageID( int id ) {
+			PageFactory	pf = getPageFactory();
+			if ( pf == null )	return null;
+			Page	p = pf.getPage( id );
+			if ( p == null )	return null;
+			pf.returnPage( p );
+			return p.getID();
+		}
+		public String toString() { return name; }
+	}
+
 	/**
 	 * ページロード情報。
 	 */
@@ -191,6 +212,31 @@ public abstract class PageFactory extends Thread {
 		}
 	}
 
+	private HashMap<Class<? extends XenoPage>, PageID>	xeno_map =
+		new HashMap<Class<? extends XenoPage>, PageID>();
+	/**
+	 * 外部ページの登録。
+	 * @param cls クラス定義。
+	 * @return 新規発行したPageID。
+	 */
+	public PageID addDefine( Class<? extends XenoPage> cls ) throws Exception {
+		int	hash = (int)new Date().getTime() + cls.hashCode();
+		synchronized( class_def ) {
+			PageID	id = xeno_map.get( cls );
+			if ( id != null )	return id;
+			while ( true ) {
+				if ( hash < 0 )	hash *= -1;
+				if ( hash < 10 )	hash = 10;
+				if ( class_def.get( hash ) == null )	break;
+				hash++;
+			}
+			id = new XenoID( hash, cls.toString() );
+			xeno_map.put( cls, id );
+			addDefine( id, cls );
+			return id;
+		}
+	}
+
 	/**
 	 * nullページ(遷移元が無い時のページ)の取得。
 	 * @return nullページ。
@@ -232,7 +278,6 @@ public abstract class PageFactory extends Thread {
 			return pg;
 		}
 		catch( Exception e ) {
-			e.printStackTrace();
 			return null;
 		}
 	}
@@ -252,6 +297,11 @@ public abstract class PageFactory extends Thread {
 		return uri;
 	}
 
+	/** PARASLENEサービスURL */
+	public static final String	PARASELENE_SERVICE = "paraselene.service.na";
+	/** ダイアログクローズ要求 name */
+	public static final String	CLOSE_ID = "paraseleneEclipseCloseId";
+	private static final Page service = new Service();
 
 	AliasData getPage( String uri ) {
 		if ( !Supervisor.isMyHost( uri ) )	return null;
@@ -268,7 +318,10 @@ public abstract class PageFactory extends Thread {
 			if ( path[i].length() < 4 )	continue;
 			if ( !TransactionSequencer.EXTENSION.equals( path[i].substring( path[i].length() - 3 ) ) )	continue;
 			path[i] = parseAlias( path[i], alias_data );
-			Option.trace( "alias URI = %s", uri );
+			if ( PARASELENE_SERVICE.equals( path[i] ) ) {
+				alias_data.page = service;
+				return alias_data;
+			}
 			String	hit = null;
 			for ( int j = 0; j < list_cnt; j++ ) {
 				String	name = alias_list.get( j );
