@@ -20,6 +20,7 @@ public class PageServerInformation implements ServerInformation {
 	private TransactionSequencer	seq;
 	private boolean	search_flag;
 	private HistorySet	hist;
+	private String mms_id;
 
 	PageServerInformation( DataHolder holder ) {
 		server = holder.getServerName();
@@ -27,6 +28,7 @@ public class PageServerInformation implements ServerInformation {
 		seq = getTransactionSequencer();
 		search_flag = holder.isSearchEngine();
 		hist = holder.getHistorySet();
+		mms_id = holder.getMultiStageSessionID();
 		synchronized( fact ) {
 			if ( fact.get( context ) == null ) {
 				fact.put( context, holder.getPageFactory() );
@@ -40,5 +42,6 @@ public class PageServerInformation implements ServerInformation {
 	public boolean isSearchEngine() { return search_flag; }
 	public HistorySet getHistorySet() { return hist; }
 	public PageFactory getPageFactory() { return fact.get( context ); }
+	public String getMultiStageSessionID() { return mms_id; }
 }
 
