@@ -1,12 +1,13 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
 package paraselene.supervisor;
 
 import paraselene.*;
+import paraselene.tag.*;
 
 /**
  * 遷移先指定。output するページをポップアップ表示します。<br>
@@ -19,7 +20,7 @@ public class Popup extends Forward implements AjaxForward {
 	/**
 	 * ポップアップ種別。
 	 */
-	public enum Type {
+	public enum Type implements DialogType {
 		/**
 		 * ポップアップの下のページのUI操作を許す。
 		 */
@@ -52,33 +53,61 @@ public class Popup extends Forward implements AjaxForward {
 		public boolean isMode() {
 			return modal_f;
 		}
+		/**
+		 * 自動クローズであるか？
+		 * @return 常にfalse。自動クローズしない。
+		 */
+		public boolean isAutoClose() {
+			return false;
+		}
+		/**
+		 * 表示位置の取得。
+		 * @return 表示位置。常にCENTER。
+		 */
+		public DialogType.Position getPosition() {
+			return DialogType.Position.CENTER;
+		}
 		/**
 		 * モーダルであるか？
 		 * @return true:モーダル、false:モードレスまたはダイアログではない。
 		 */
 		public static boolean isMode( Page page ) {
-			Type	ptype = page.getPopupType();
+			DialogType	ptype = page.getPopupType();
 			if ( ptype == null )	return false;
 			return ptype.isMode();
 		}
+
+		/**
+		 * 自動クローズであるか？
+		 * @return true:自動クローズ、false:自動クローズではない、
+		 * またはダイアログではない。
+		 */
+		public static boolean isAutoClose( Page page ) {
+			DialogType	ptype = page.getPopupType();
+			if ( ptype == null )	return false;
+			return ptype.isAutoClose();
+		}
 	}
 
-	private Type type;
+	private DialogType type;
 
 	boolean is_refresh() {
 		return view_page != null;
 	}
 
+	Popup( PageID id, DialogType dialog_type ) {
+		super( id );
+		type = dialog_type;
+		if ( SandBox.isCurrentDaemon() )	return;
+		initType( SandBox.getCurrentRequestParameter().getHistory() );
+	}
 	/**
 	 * コンストラクタ。新しいダイアログを表示します。
 	 * @param id 表示するページ。
 	 * @param dialog_type ポップアップ種別。
 	 */
 	public Popup( PageID id, Type dialog_type ) {
-		super( id );
-		type = dialog_type;
-		if ( SandBox.isCurrentDaemon() )	return;
-		initType( SandBox.getCurrentRequestParameter().getHistory() );
+		this( id, (DialogType)dialog_type );
 	}
 
 	void initType( History hist ) {
@@ -87,15 +116,7 @@ public class Popup extends Forward implements AjaxForward {
 		}
 	}
 
-	/**
-	 * コンストラクタ。新しいダイアログを表示します。
-	 * または、指定ページの Z順を手前にします。<br>
-	 * 指定pageがダイアログであればアクティブ指示となり、そうでなければ
-	 * 新規ダイアログとしてポップアップ表示します。
-	 * @param page 表示するページ。
-	 * @param dialog_type ポップアップ種別。
-	 */
-	public Popup( Page page, Type dialog_type ) {
+	Popup( Page page, DialogType dialog_type ) {
 		this( page.getParentPage().getID(), dialog_type );
 		page = page.getParentPage();
 		if ( page.getPopupType() != null ) {
@@ -105,20 +126,31 @@ public class Popup extends Forward implements AjaxForward {
 			view_page = page;
 		}
 	}
+	/**
+	 * コンストラクタ。新しいダイアログを表示します。
+	 * または、指定ページの Z順を手前にします。<br>
+	 * 指定pageがダイアログであればアクティブ指示となり、そうでなければ
+	 * 新規ダイアログとしてポップアップ表示します。
+	 * @param page 表示するページ。
+	 * @param dialog_type ポップアップ種別。
+	 */
+	public Popup( Page page, Type dialog_type ) {
+		this( page, (DialogType)dialog_type );
+	}
 
-	static boolean isModeless( Type mine ) {
+	static boolean isModeless( DialogType mine ) {
 		if ( mine == null )	return false;
 		return !mine.isMode();
 	}
 
-	static boolean isModelessAlert( Type mine, History hist, boolean unlock_f ) {
+	static boolean isModelessAlert( DialogType mine, History hist, boolean unlock_f ) {
 		if ( hist == null )	return false;
 		if ( mine == null )	return false;
 		if ( mine.isMode() )	return false;
 		try {
 			Page[]	page = hist.getBrowsingPage();
 			for ( int i = 0; i < page.length; i++ ) {
-				Type	ptype = page[i].getPopupType();
+				DialogType	ptype = page[i].getPopupType();
 				if ( ptype == null )	continue;
 				if ( ptype.isMode() )	return true;
 			}
@@ -138,7 +170,7 @@ public class Popup extends Forward implements AjaxForward {
 		this( page, Type.MODELESS );
 	}
 
-	Page getPage( Page from ) {
+	Page getPage( PageFactory pf, Page from ) {
 		if ( active_page != null ) {
 			Option.trace( "Popup#getPage -> %s", active_page.getUniqueKey() );
 			return active_page;
@@ -151,18 +183,18 @@ public class Popup extends Forward implements AjaxForward {
 			Option.trace( "Popup#getPage -> %s", view_page.getUniqueKey() );
 			return view_page;
 		}
-		Page	p = out_page.getPageFactory().getPage( out_page.getID() );
+		Page	p = pf.getPage( out_page.getID() );
 		Option.trace( "Popup#getPage -> %s", p.getUniqueKey() );
 		return p;
 	}
 
-	void overwriteType( Type t ) {
+	void overwriteType( DialogType t ) {
 		if ( type == null )	return;
-		if ( t == Type.MODELESS )	return;
+		if ( !t.isMode() )	return;
 		type = t;
 	}
 
-	Type getType() {
+	DialogType getType() {
 		return type;
 	}
 
@@ -197,14 +229,18 @@ public class Popup extends Forward implements AjaxForward {
 		return buf.toString();
 	}
 
-	OutputCall makeOutput( int nk, Page lp, RequestParameter r, SessionData sd ) {
-		Option.trace( "new OpenOutput <- %s", this );
-		return new OpenOutput( nk, lp, this, getType(), r, sd );
+	Tag getHint() {
+		return null;
 	}
 
-	CometCall makeCometCall( History h ) {
+	OutputCall makeOutput( PageFactory pf, int nk, Page lp, RequestParameter r, SessionData sd ) {
+		Option.trace( "new OpenOutput <- %s", this );
+		return new OpenOutput( pf, nk, lp, this, getType(), getHint(), r, sd );
+	}
+
+	CometCall makeCometCall( PageFactory pf, History h ) {
 		Option.trace( "new OpenCometCall <- %s", this );
-		return new OpenCometCall( h, this, getType() );
+		return new OpenCometCall( pf, h, this, getType() );
 	}
 }
 
