@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2012  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -11,6 +11,7 @@ import java.util.*;
 import java.io.*;
 import java.net.*;
 import javax.servlet.http.*;
+import paraselene.util.*;
 
 /**
  * リクエスト。
@@ -160,6 +161,69 @@ public class RequestParameter implements Serializable {
 		return SearchEngine.NO_SEARCHENGINE;
 	}
 
+	/**
+	 * スマートフォン/タブレット。
+	 */
+	public enum SmartPhone {
+		/**
+		 * Androidスマートフォン。<br>
+		 * 一部のAndroidタブレットがスマートフォンと認識される場合もあります。
+		 */
+		ANDROID( "Android", "Mobile" ),
+		/**
+		 * Androidタブレット。
+		 */
+		ANDROID_TABLET( "Android" ),
+		/**
+		 * iPhone。
+		 */
+		IPHONE( "iPhone" ),
+		/**
+		 * iPad。
+		 */
+		IPAD( "iPad" ),
+		/**
+		 * iPod。
+		 */
+		IPOD( "iPod" ),
+		/**
+		 * BlackBerry。
+		 */
+		BLACKBERRY( "BlackBerry" ),
+		/**
+		 * Windows Phone。
+		 */
+		WINDOWS_PHONE( "Windows", "Phone" ),
+		/**
+		 * スマートフォンではない。
+		 */
+		NO_SMARTPHONE();
+		private String[]	str = null;
+		private SmartPhone( String ... s ) {
+			str = s;
+		}
+		boolean isHit( String ua ) {
+			if ( str == null )	return true;
+			for ( int i = 0; i < str.length; i++ ) {
+				if ( ua.indexOf( str[i] ) == -1 )	return false;
+			}
+			return true;
+		}
+	}
+	/**
+	 * ユーザーエージェントから、スマートフォンやタブレットを判定する。
+	 * @param ua ユーザーエージェント。nullなら、NO_SMARTPHONEを返します。
+	 * @return 判定結果。
+	 */
+	public static SmartPhone judgeSmartPhone( String ua ) {
+		if ( ua == null )	return SmartPhone.NO_SMARTPHONE;
+		SmartPhone[]	dim = SmartPhone.values();
+		for ( int i = 0; i < dim.length; i++ ) {
+			if ( dim[i].isHit( ua ) )	return dim[i];
+		}
+		return SmartPhone.NO_SMARTPHONE;
+	}
+
 	private HashMap<String,RequestItem>	item_map = new HashMap<String,RequestItem>();
 	private Method	method = Method.GET;
 	private URI	uri = null;
@@ -172,13 +236,12 @@ public class RequestParameter implements Serializable {
 	private transient Supervisor	supervisor = null;
 	static final String UA_HEAD = "User-Agent";
 
-	private static final String	AJAX_CALLED = "paraselene$ajax$called";
+	private volatile boolean ajax_used_f = false;
 	/**
 	 * フレームワークが使用します。
 	 */
-	public void markAjaxCalled() {
-		if ( session == null )	return;
-		session.setAttribute( AJAX_CALLED, new Boolean( true ) );
+	void markAjaxCalled() {
+		ajax_used_f = true;
 	}
 
 	/**
@@ -186,8 +249,7 @@ public class RequestParameter implements Serializable {
 	 * @return true:使用した痕跡がある、false:通信の痕跡がない。
 	 */
 	public boolean wasUsedAjax() {
-		if ( session == null )	return false;
-		return session.getAttribute( AJAX_CALLED ) != null;
+		return ajax_used_f;
 	}
 
 	/**
@@ -224,7 +286,6 @@ public class RequestParameter implements Serializable {
 		if ( ua.length < 1 )	return Mobile.NO_MOBILE;
 		return judgeMobile( ua[0] );
 	}
-
 	/**
 	 * ユーザーエージェントから、検索エンジンクローラーを判定する。
 	 * @return 判定結果。
@@ -235,6 +296,16 @@ public class RequestParameter implements Serializable {
 		if ( ua.length < 1 )	return SearchEngine.NO_SEARCHENGINE;
 		return judgeSearchEngine( ua[0] );
 	}
+	/**
+	 * ユーザーエージェントから、スマートフォンを判定する。
+	 * @return 判定結果。
+	 */
+	public SmartPhone judgeSmartPhone() {
+		String[]	ua = getHeader( UA_HEAD );
+		if ( ua == null )	return SmartPhone.NO_SMARTPHONE;
+		if ( ua.length < 1 )	return SmartPhone.NO_SMARTPHONE;
+		return judgeSmartPhone( ua[0] );
+	}
 
 	/**
 	 * コンストラクタ。
@@ -344,7 +415,7 @@ public class RequestParameter implements Serializable {
 	void setParam( Method m, HttpServletRequest request, Supervisor sv ) {
 		setSupervisor( sv );
 		setMethod( m );
-		setSession( request.getSession( false ) );
+		setSession( TransactionSequencer.getOriginSession( getSupervisor().isMultiStageSession(), request, false ) );
 		setCookie( request.getCookies() );
 		setRemoteAddr( getRemoteAddr( request ) );
 		try {
@@ -483,6 +554,48 @@ public class RequestParameter implements Serializable {
 		return remote_addr;
 	}
 
+	/**
+	 * アクセス元検証の戻り値。
+	 */
+	public enum HitRemoteAddrResult {
+		/**
+		 * リクエスト元がIPアドレスを設定していない、
+		 * または、IPアドレスフォーマットではない。
+		 */ 
+		REMOTE_NOT_IP,
+		/**
+		 * 引数 mask が null または 0件である。
+		 */
+		MASK_NON,
+		/**
+		 * 引数 mask のどれかにリクエスト元が一致した。
+		 */
+		HIT,
+		/**
+		 * 引数 mask のどれにもリクエスト元が一致しない。
+		 */
+		NO_HIT
+	}
+
+	/**
+	 * アクセス元検証。
+	 * アクセス元IPアドレスと、mask(ネットマスク適用後のIPアドレス)を
+	 * 比較します。この時の比較は、{@link paraselene.util.IP#equalsLowBit(IP)}を
+	 * 使用します。
+	 * @param mask 検証用マスク。
+	 * @return 検証結果。
+	 */
+	public HitRemoteAddrResult isHitRemoteAddr( IP.IPMask ... mask ) {
+		IP	ip = IP.toIP( getRemoteAddr() );
+		if ( ip == null )	return HitRemoteAddrResult.REMOTE_NOT_IP;
+		if ( mask == null || mask.length == 0 )	return HitRemoteAddrResult.MASK_NON;
+		for ( IP.IPMask ms: mask ) {
+			IP	chk = ms.getIP().mask( ms.getMask() );
+			if ( chk.equalsLowBit( ip.mask( ms.getMask() ) ) )	return HitRemoteAddrResult.HIT;
+		}
+		return HitRemoteAddrResult.NO_HIT;
+	}
+
 	/**
 	 * リクエストされたURIの取得。クエリも含めたフルパスです。
 	 * @return URI。
@@ -636,7 +749,7 @@ public class RequestParameter implements Serializable {
 	}
 
 	/**
-	 * 履歴の取得。
+	 * 履歴の取得。実行中ページを含む{@link HistorySet}から取得します。
 	 * @return 履歴。セッションが発生していない場合はnull。
 	 */
 	public History getHistory() {
@@ -646,7 +759,7 @@ public class RequestParameter implements Serializable {
 	/**
 	 * リクエスト項目の取得。
 	 * @param key リクエスト項目名。
-	 * @return リクエスト項目。
+	 * @return リクエスト項目。存在しなければnullです。
 	 */
 	public RequestItem getItem( String key ) {
 		if ( key == null )	return null;
