@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -19,8 +19,10 @@ import paraselene.ajax.data.*;
 class Child extends Thread implements DaemonChannel {
 	static volatile HashMap<String, Child>	name_space = new HashMap<String, Child>();
 
+	volatile Thread	parent = null;
 	Date	start_dt;
 
+	volatile PageFactory	factory = null;
 	volatile Page main_page = null;
 	volatile boolean call_input;
 	volatile boolean refresh_f;
@@ -146,7 +148,7 @@ class Child extends Thread implements DaemonChannel {
 				for ( int j = 0; j < p.length; j++ ) {
 					for ( int fw_i = 0; fw_i < fw.length; fw_i++ ) {
 						if ( fw[fw_i].page == p[j] ) {
-							CometHolder	ch = new CometHolder( h, fw[fw_i].forward );
+							CometHolder	ch = new CometHolder( factory, h, fw[fw_i].forward );
 							try {
 								Ajax.addComet( h.session_id, ch.getPostBack() );
 							}
@@ -166,21 +168,44 @@ class Child extends Thread implements DaemonChannel {
 		limit_dt = new Date( now.getTime() + SandBox.DAEMON_TIMEOUT );
 	}
 
-	private static Forward input( Page page, RequestParameter req, Forward fw ) throws Exception {
+	private static Forward fix( Forward old_fw, Forward new_fw ) {
+		Option.trace( "old_fw=%s / new_fw=%s", old_fw, new_fw );
+		if ( new_fw == null || old_fw == new_fw )	return old_fw;
+		if ( old_fw == null )	return new_fw;
+		if ( old_fw.isAjax() )	return Forward.merge( old_fw, new_fw );
+		return new_fw;
+	}
+
+	static class HistoryDroped extends Exception {}
+
+	private static Forward input( Page page, RequestParameter req, Forward fw ) throws Throwable {
 		if ( page == null )	return fw;
 		PageHooker[]	hook = page.getPageHooker();
-		for ( int i = 0; i < hook.length; i++ ) {
-			Forward	old = fw;
-			fw = hook[i].beforeInput( page, req, fw );
-			if ( fw == null )	fw = old;
+		History	hist = req.getHistory( page.getHistoryKey() );
+		if ( hist == null )	return fw;
+		try {
+			for ( int i = 0; i < hook.length; i++ ) {
+				fw = fix( fw, hist.returnStack( hook[i].beforeInput( page, req, fw ), false ) );
+				if ( hist.drop_f )	throw new HistoryDroped();
+			}
+			fw = fix( fw, hist.returnStack( page.input( req, fw ), false ) );
+			fw = hist.returnStack( fw, true );
+			if ( hist.drop_f )	throw new HistoryDroped();
 		}
-		return page.input( req, fw );
+		catch( HistoryDroped hd ) {
+			throw hd;
+		}
+		catch( Throwable e ) {
+			if ( hist.drop_f )	throw new HistoryDroped();
+			throw e;
+		}
+		return fw;
 	}
 
 	private static Page output( Page page, Page from, RequestParameter req, boolean new_f ) throws Exception {
 		if ( page == null )	return null;
 		Page	old = page;
-		page.beginning( req );
+		page.beginning( req, null );
 		page = page.output( from, req );
 		if ( page == null )	page = old;
 		Tag	body = page.getBodyTag();
@@ -365,6 +390,14 @@ public class SandBox extends Thread {
 		return child.request;
 	}
 
+	/**
+	 * 履歴の取得。実行中ページを含む履歴を返します。
+	 * @return 履歴。
+	 */
+	public static History getCurrentPageHistory() {
+		return getCurrentRequestParameter().getHistory();
+	}
+
 	/**
 	 * Input処理中であるか。
 	 * 各ページの、input または output が呼ばれている時、現在どちらを
@@ -379,6 +412,56 @@ public class SandBox extends Thread {
 		return child.call_input;
 	}
 
+	/**
+	 * ページファクトリーの取得。
+	 * 現在実行中スレッドで使用されているページファクトリーを返します。
+	 * @return ページファクトリー。
+	 */
+	public static PageFactory getPageFactory() {
+		Child	child = getMyself();
+		if ( child == null )	return null;
+		return child.factory;
+	}
+
+	/**
+	 * 一時問い合わせダイアログの表示。<br>
+	 * このメソッドを呼ぶと、一旦ブラウザへ制御が移り、現在実行中の処理は
+	 * このダイアログからの戻り値が得られるまで中断します。
+	 * @param id 表示するダイアログ。これが{@link paraselene.EphemeralPage}を
+	 * 実装していない場合、例外が発生します。
+	 * @param p ダイアログ動作指定。
+	 * @param hint ダイアログ動作が、MODAL、LITE_MODAL 以外であれば表示位置
+	 * 指定のため必須です。必須でありながら null 指定を行うと例外が発生します。
+	 * @param c ダイアログ呼出パラメータ。不要であればnull。
+	 * @return ダイアログが{@link EphemeralClosure}で戻した戻り値。
+	 * {@link paraselene.EphemeralPage#ABORT}または
+	 * {@link paraselene.EphemeralPage#NO_ANSWER}を返す可能性もあります。
+	 */
+	public static Object doModal( PageID id, EphemeralPosition p, Tag hint, Object c ) throws Page.PageException {
+		if ( !isCurrentInput() )	throw new Page.PageException( "no input method." );
+		RequestParameter	req = getCurrentRequestParameter();
+		if ( req == null )	throw new Page.PageException( "cannot getCurrentRequestParameter()" );
+		Page	page = getPageFactory().getPage( id );
+		if ( !(page instanceof EphemeralPage) )	throw new Page.PageException( id + " isn't EphemeralPage" );
+
+		Child	child = getMyself();
+		History	hist = req.getHistory();
+		page.setPopupType( p, hint );
+		page.beginning( req, c );
+		page.setPopupType( null, null );
+		hist.callStack( child, page, p, hint );
+		child.parent.interrupt();
+		synchronized( child ) {
+			try {
+				hist.unlock();
+				child.wait( 1000 * 60 * 60 );
+				hist.lock();
+			}
+			catch( Exception e ){}
+		}
+		return hist.popStack( child );
+	}
+
 	/**
 	 * このスレッドがデーモンであるか判定します。
 	 * @return true:デーモン、false:デーモンではない。
@@ -585,6 +668,7 @@ public class SandBox extends Thread {
 			child = Child.name_space.get( name );
 			if ( child == null ) {
 				child = getChild();
+				child.factory = getPageFactory();
 				child.daemon = daemon;
 				child.hist = new ArrayList<History>();
 				if ( name != null ) {
@@ -659,8 +743,14 @@ public class SandBox extends Thread {
 	}
 
 	@SuppressWarnings("deprecation")
-	private static void kick( Child child ) throws Throwable {
-		startChild( child );
+	private static void kick( Child child, boolean start_f ) throws Throwable {
+		child.parent = Thread.currentThread();
+		if ( start_f )	startChild( child );
+		else {
+			synchronized( child ) {
+				child.notifyAll();
+			}
+		}
 		child.join( wait_ms );
 		if ( !child.isAlive() ) {
 			removeChild( child );
@@ -670,26 +760,46 @@ public class SandBox extends Thread {
 		throw ChildKiller.kill( child );
 	}
 
-	static Forward input( Page action, RequestParameter req, Forward fw )
+	static Forward input( PageFactory pf, Page action, RequestParameter req, Forward fw )
 	throws Throwable {
 		Child	child = getChild();
+		child.factory = pf;
 		child.main_page = action;
 		child.request = req;
 		child.forward = fw;
 		child.call_input = true;
-		kick( child );
+		return input_sub( child, true, null );
+	}
+
+	static Forward input_sub( Child child, boolean start_f, History hist ) throws Throwable {
+		try {
+			if ( hist != null )	hist.unlock();
+			kick( child, start_f );
+			if ( hist != null )	hist.lock();
+		}
+		catch( InterruptedException e ) {
+			Thread.interrupted();
+			Forward	next = null;
+			if ( hist == null ) {
+				hist = child.request.getHistory( child.main_page.getHistoryKey() );
+			}
+
+			if ( hist != null )	next = hist.getStackForward( child );
+			if ( next != null )	child.forward = next;
+		}
 		return child.forward;
 	}
 
-	static Page output( Page action, Page page, RequestParameter req, boolean refresh_f )
+	static Page output( PageFactory pf, Page action, Page page, RequestParameter req, boolean refresh_f )
 	throws Throwable {
 		Child	child = getChild();
+		child.factory = pf;
 		child.main_page = action;
 		child.param_page = page;
 		child.request = req;
 		child.call_input = false;
 		child.refresh_f = refresh_f;
-		kick( child );
+		kick( child, true );
 		return child.param_page;
 	}
 }
