@@ -76,15 +76,11 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 		SandBox.doStart();
 	}
 
-	private static Supervisor org_sv = null;
 	/**
 	 * コンストラクタ。
 	 */
 	public Supervisor() {
 		super();
-		if ( org_sv == null ) {
-			org_sv = this;
-		}
 	}
 
 	private static String resolvePage( ServerInformation holder, Page from, String p, int from_key, int to_key ) {
@@ -95,12 +91,13 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 				from_page = from.getID();
 			}
 			PageID	to = null;
-			Page	page = holder.getPageFactory().getPage(
+			PageFactory	pf = holder.getPageFactory();
+			Page	page = pf.getPage(
 				Integer.parseInt( u.getPath().substring( LINK_LEN[0] ) )
 			);
 			if ( page != null ) {
 				to = page.getID();
-				to.getPageFactory().returnPage( page );
+				pf.returnPage( page );
 			}
 			if ( from != null ) {
 				Page	parent = from.getParentPage();
@@ -153,6 +150,10 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 				buf = buf.append( port );
 			}
 			buf = buf.append( holder.getContextPath() );
+			String	mss = holder.getMultiStageSessionID();
+			if ( mss != null ) {
+				buf = buf.append( "/" ).append( TransactionSequencer.SESSION_DIR ).append( mss );
+			}
 			return buf.toString();
 		}
 		catch( Exception e ) {
@@ -224,6 +225,7 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 		ServerInformation	holder = getDataHolder( null );
 		if ( holder == null && page != null )	holder = page.getPageServerInformation();
 		if ( holder == null )	return URIValue.encode( uri, enc, xml_f );
+
 		int from_key, to_key;
 		if ( page != null ) {
 			from_key = page.getHistoryKey();
@@ -302,7 +304,7 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 			buf = buf.append( uri );
 			uri = buf.toString();
 		}
-		return uri;
+		return TransactionSequencer.rewritePath( uri, holder );
 	}
 
 	private static boolean isMyHost( DataHolder holder, String uri ) {
@@ -365,7 +367,19 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 
 	private Forward onErrorDebug( Throwable e, HttpServletRequest req, HttpServletResponse res, int status ) {
 		Forward fw = new Forward( status );
+		if ( e instanceof Child.HistoryDroped ) {
+			fw = new Forward( 403 );
+			try{
+				fw = onIllegalRequest( IllegalRequest.SESSION_ERROR, null, null, null );
+			}
+			catch( Exception ee ){
+				Option.debug( ee );
+				onError( ee );
+			}
+			return fw;
+		}
 		Option.debug( e );
+		Option.trace( e.toString() );
 		if ( !(e instanceof SocketException) )	onError( e );
 		try {
 			fw.Action( this, res );
@@ -375,7 +389,7 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 			onError( e2 );
 		}
 		if ( !(e instanceof SocketException) && status != 413 ) {
-			HttpSession	session = req.getSession( false );
+			HttpSession	session = TransactionSequencer.getOriginSession( isMultiStageSession(), req, false );
 			clear_session( session );
 		}
 		return fw;
@@ -402,6 +416,7 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 	private static final Page	null4alias = new NullPage4Alias();
 
 	private void doAction( HttpServletRequest request, HttpServletResponse res ) {
+		boolean	session_error = false;
 		HttpSession	session = null;
 		SessionData	data = null;
 		DataHolder	holder = getDataHolder();
@@ -434,13 +449,21 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 						clear_session( session );
 						return;
 					}
-					if ( holder.session_null && path_data != null ) {
-						Option.trace( "%s(%s->%s)", IllegalRequest.SESSION_ERROR, path_data.from.getID(), path_data.to.getID() );
-						fw = onIllegalRequest( IllegalRequest.SESSION_ERROR, req, path_data.from, path_data.to );
+					if ( holder.session_null ) {
+						session_error = true;
+						if ( path_data != null ) {
+							Option.trace( "%s(%s->%s)", IllegalRequest.SESSION_ERROR, path_data.from.getID(), path_data.to.getID() );
+							fw = onIllegalRequest( IllegalRequest.SESSION_ERROR, req, path_data.from, path_data.to );
+						}
+						else {
+							Option.trace( "%s", IllegalRequest.SESSION_ERROR );
+							fw = onIllegalRequest( IllegalRequest.SESSION_ERROR, req, null, null );
+						}
 						if ( fw != null ) {
+							if ( path_data == null )	path_data = new PathData();
 							session_f = fw.session_clear_f;
-							path_data.from = last_page = null;
-							path_data.to = next_page = fw.getPage( null );
+							path_data.from = last_page = fact.getNullPage();
+							path_data.to = next_page = fw.getPage( fact, null );
 							if ( next_page == null ) {
 								fw.Action( this, res );
 								if ( session_f )	clear_session( session );
@@ -451,9 +474,15 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 				}
 			}
 			else {
-				path_data.from = null4alias;
-				path_data.to = alias.page;
 				path_data.to_histry = alias.to_histry;
+				if ( alias.page instanceof Service ) {
+					path_data.from = alias.page;
+					path_data.to = alias.page;
+				}
+				else {
+					path_data.from = null4alias;
+					path_data.to = alias.page;
+				}
 			}
 			if ( path_data == null ) {
 				fw = new Forward( 403 );
@@ -462,8 +491,9 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 				return;
 			}
 			if ( path_data.redirect != null ) {
-				if ( !holder.data.write( this, path_data.redirect, holder ) ) {
-					fw = new Forward( 403 );
+				Forward	rd = holder.data.write( this, path_data.redirect, holder );
+				if ( rd != null ) {
+					fw = rd;
 					fw.Action( this, res );
 					//clear_session( session );
 				}
@@ -474,33 +504,50 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 			RequestItem	ukey = req.getItem( Form.PAGE_UKEY );
 			RequestItem	ajax = req.getItem( A_AJAX_KEY );
 			if ( ajax == null )	ajax = req.getItem( Form.FORM_AJAX );
-			if ( ajax != null || ukey != null ) {
+			if ( !(last_page instanceof Service) && (ajax != null || ukey != null) ) {
 				String	call_key = ( ajax != null )?	ajax.getValue( 0 ):	ukey.getValue( 0 );
 				Option.trace( "call_key=%s", call_key );
 				Page	sub = null;
 				History	history = data.hist.get( (path_data.from_histry != null)? path_data.from_histry: HistorySet.ROOT );
 				if ( history != null ) {
 					sub = history.getBrowsingPage( call_key );
+					Option.trace( "sub%s", sub==null?"=null":"!=null" );
+					history.unlock();
 				}
 				if ( sub != null ) {
 					fact.returnPage( last_page );
 					last_page = sub;
 				}
 				else if ( !"-1".equals( call_key ) ) {
-					fw = data.redirect( req.getURI() );
+					fw = data.redirect( req.getURI(), ajax != null );
 					if ( fw != null ) {
 						fw.Action( this, res );
 						return;
 					}
-					fw = new Forward( 403 );
-					fw.Action( this, res );
-					clear_session( session );
-					return;
+					Option.trace( "%s(%s->%s)", IllegalRequest.DISAPPROVAL_REQUEST, last_page.getID(), next_page.getID() );
+					fw = onIllegalRequest( IllegalRequest.DISAPPROVAL_REQUEST, req, last_page, next_page );
+					if ( fw != null ) {
+						session_f = fw.session_clear_f;
+						last_page = fact.getNullPage();
+						next_page = fw.getPage( fact, null );
+						if ( next_page == null ) {
+							fw.Action( this, res );
+							if ( session_f )	clear_session( session );
+							return;
+						}
+					}
+					else {
+						fw = new Forward( 403 );
+						fw.Action( this, res );
+						//clear_session( session );
+						return;
+					}
 				}
 				else	ajax = null;
 			}
 			Page[]	history_pages = new Page[0];
 			if ( ajax == null && last_page != null ) {
+/*
 				if ( last_page instanceof Null ) {
 					System.out.println( "last page is null" );
 					fw = new Forward( 403 );
@@ -508,6 +555,7 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 					clear_session( session );
 					return;
 				}
+*/
 				if ( last_page.isAllowHistoryAdd() ) {
 					Page	sub = null;
 					History	history = data.hist.get( (path_data.from_histry != null)? path_data.from_histry: HistorySet.ROOT );
@@ -525,7 +573,7 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 						if ( fw != null ) {
 							session_f = fw.session_clear_f;
 							last_page = fact.getNullPage();
-							next_page = fw.getPage( null );
+							next_page = fw.getPage( fact, null );
 							if ( next_page == null ) {
 								fw.Action( this, res );
 								if ( session_f )	clear_session( session );
@@ -560,7 +608,7 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 				if ( fw != null ) {
 					session_f = fw.session_clear_f;
 					last_page = fact.getNullPage();
-					next_page = fw.getPage( null );
+					next_page = fw.getPage( fact, null );
 					if ( next_page == null ) {
 						fw.Action( this, res );
 						if ( session_f )	clear_session( session );
@@ -568,6 +616,8 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 					}
 				}
 			}
+			boolean	service_f = false;
+			Page	dummy_last = null;
 			if ( fw == null ) {
 				int	from_key = HistorySet.ROOT;
 				int	to_key = HistorySet.ROOT;
@@ -589,7 +639,7 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 					if ( fw != null ) {
 						session_f = fw.session_clear_f;
 						last_page = fact.getNullPage();
-						next_page = fw.getPage( null );
+						next_page = fw.getPage( fact, null );
 						if ( next_page == null ) {
 							fw.Action( this, res );
 							if ( session_f )	clear_session( session );
@@ -604,30 +654,42 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 					Option.trace( String.format( "reflect -> %s(%s)", last_page.getID().toString(), last_page.getUniqueKey() ) );
 				}
 				last_page.setRequestParameter( req );
-				if ( next_page != null ) {
+				if ( last_page instanceof Service ) {
+					fw = null;
+				}
+				else if ( next_page != null ) {
 					if ( from_key != to_key ) {
 						fw = new Forward( next_page.getID(), true, false );
 					}
 					else {
-						if ( last_page.getID() == next_page.getID() ) {
+						if ( last_page.getParentPage().getID() == next_page.getParentPage().getID() ) {
 							fw = new Feedback( last_page );
 						}
 						else if ( Closure.isClosure( last_page, next_page, req ) ) {
-							if ( last_page.getPopupType() == null ) {
-								fw = new Closure( next_page );
-							}
-							else {
-								fw = new Closure( last_page );
-							}
+							fw = new Closure( last_page );
 						}
 						else {
-							fw = new Forward( next_page.getID(), true, false );
+							fw = new Forward( fact, next_page.getID(), true, false );
 						}
 					}
 					fact.returnPage( next_page );
 				}
+				if ( last_page instanceof Service ) {
+					Service	sv = (Service)last_page;
+					service_f = true;
+					fw = SandBox.input( getPageFactory(), last_page, req, fw );
+					last_page = sv.page;
+					if ( last_page == null ) {
+						fw.Action( this, res );
+						clear_session( session );
+						return;
+					}
+					dummy_last = sv.last;
+				}
 				Option.trace( "%s input(%s) call", last_page.getID(), fw );
-				fw = SandBox.input( last_page, req, fw );
+				if ( ajax != null )	req.markAjaxCalled();
+				fw.weak_f = true;
+				fw = SandBox.input( getPageFactory(), last_page, req, fw );
 				session = req.getSession();
 				Option.trace( "%s input return %s", last_page.getID(), fw );
 				last_page.setInitialized( false );
@@ -648,37 +710,52 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 			if ( path_data.to_histry != null ) {
 				out_hist_key = path_data.to_histry;
 			}
-			OutputHolder	oh = new OutputHolder( ajax != null && last_page.getParentPage().isAjax(), out_hist_key, last_page, fw, req, data );
-			oh.call();
+			Option.trace( "%s(last_page)/ %s (last->parent)/%s (last_page popup)", last_page.getID(), last_page.getParentPage().getID(), last_page.getPopupType() );
+			Option.trace( "%s && %s", ajax != null, last_page.getParentPage().isAjax() );
+			OutputHolder	oh = new OutputHolder( fact, ajax != null && last_page.getParentPage().isAjax(), out_hist_key, last_page, fw, req, data );
+			oh.call( getPageFactory() );
+			if ( oh.getPage() != null ) {
+				for ( Page p: oh.getPage() ) {
+					if ( p instanceof ForwardPage ) {
+						fw = ((ForwardPage)p).fw;
+						if ( (!last_page.isAjax() && fw.isLeave()) || fw.getStatus() != 0 ) {
+							fw.Action( this, res );
+							if ( session_f )	clear_session( session );
+							return;
+						}
+						oh = new OutputHolder( fact, true, out_hist_key, last_page, fw, req, data );
+						break;
+					}
+				}
+			}
 			String	key = last_page.getUniqueKey();
 			ajax = req.getItem( A_AJAX_KEY );
 			if ( ajax != null ) {
 				String	call_key = ajax.getValue( 0 );
-				if ( key.equals( call_key ) ) {
-					Ajax.remove( session, key );
-					Ajax.add( session, key, oh.getPostBack() );
+				if ( key.equals( call_key ) || session_error ) {
+					Ajax.remove( session, call_key );
+					Ajax.add( session, call_key, oh.getPostBack() );
 					Page	ajax_page = getPageFactory().getPage( PAGE_ID_JSON );
 					ajax_page.output( null, req );
 					write( new Page[]{ ajax_page, ajax_page }, session_f, fw, holder );
-					Option.trace( "JSON postback %s", key );
+					Option.trace( "JSON postback %s", call_key );
 					return;
 				}
 			}
 			ajax = req.getItem( Form.FORM_AJAX );
 			if ( ajax != null ) {
 				String	call_key = ajax.getValue( 0 );
-				if ( key.equals( call_key ) ) {
+				if ( service_f ) {
+					key = call_key;
+					last_page = dummy_last;
+				}
+				if ( key.equals( call_key ) || session_error ) {
 					Ajax.remove( session, key );
 					Ajax.add( session, key, oh.getPostBack() );
 					Page	ajax_page = getPageFactory().getPage( PAGE_ID_FORM_JSON );
 					ajax_page.output( last_page, req );
-					if ( isPRG() ) {
-						data.redirect( new Page[]{ ajax_page, ajax_page }, fw, req ).Action( this, res );
-					}
-					else {
-						write( new Page[]{ ajax_page, ajax_page }, session_f, fw, holder );
-					}
-					Option.trace( "FORM postback %s", key );
+					write( new Page[]{ ajax_page, ajax_page }, session_f, fw, holder );
+					Option.trace( "FORM(NO PRG) postback %s", call_key );
 					return;
 				}
 			}
@@ -708,6 +785,19 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 	 */
 	public abstract boolean isPRG();
 
+	/**
+	 * セッション管理方法指定。
+	 * @return true:アクセス単位に分離、false:通常動作。
+	 */
+	public abstract boolean isMultiStageSession();
+
+	/**
+	 * Forward動作。Ajax有効時にのみ機能します。
+	 * @return true:自サイト遷移ではURLを変更しない、
+	 * false:従来通りの画面遷移を行う。
+	 */
+//	public abstract boolean isAlternativeForward();
+
 	private static final int PAGE_ID_JSON = -1;
 	private static final int PAGE_ID_FORM_JSON = -2;
 	/**
@@ -718,12 +808,15 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 	HttpSession makeNewSession( HttpSession old ) {
 		DataHolder	holder = getDataHolder();
 		if ( holder == null )	return old;
+		if ( isMultiStageSession() ) {
+			TransactionSequencer.replaceSession( holder.getRequest() );
+		}
 		if ( old != null ) {
 			if ( holder.data != null )	holder.data.planed_clear = true;
 			clear_session( old );
 			if ( holder.data != null )	holder.data.planed_clear = false;
 		}
-		HttpSession	session = holder.getRequest().getSession( true );
+		HttpSession	session = TransactionSequencer.getOriginSession( isMultiStageSession(), holder.getRequest(), true );
 		holder.getHistorySet().replaceSession( session.getId() );
 		session.setAttribute( SESSION_DATA, holder.data );
 		return session;
@@ -776,7 +869,7 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 			session = null;
 		}
 		else if ( session == null ) {
-			session = holder.getRequest().getSession( true );
+			session = TransactionSequencer.getOriginSession( isMultiStageSession(), holder.getRequest(), true );
 			session.setAttribute( SESSION_DATA, data );
 		}
 		if ( isPRG() && !(out_ret[1] instanceof Downloadable) && !session_f && param.getMethod() == RequestParameter.Method.POST ) {
@@ -786,30 +879,6 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 			String	mime = out_ret[1].getContentType();
 			if ( mime == null ) {
 				StringBuilder	buf = null;
-/* 処理変更
-				if ( next_page.isXML() ) {
-					RequestParameter.HeaderQuality[]	head = param.getHeaderWithQuality( "Accept" );
-					if ( head != null ) {
-						for ( int i = 0; i < head.length; i++ ) {
-							Float	f = head[i].getQuality();
-							if ( f != null ) {
-								if ( f <= 0.0 )	continue;
-							}
-							if ( !XHTML.equalsIgnoreCase( head[i].getValue() ) )	continue;
-							buf = new StringBuilder( XHTML );
-							break;
-						}
-					}
-					if ( buf == null ) {
-						RequestParameter.Mobile	mob = param.judgeMobile();
-						switch( mob ) {
-						case AU: case DOCOMO: case J_PHONE:
-							buf = new StringBuilder( XHTML );
-							break;
-						}
-					}
-				}
-*/
 				if ( next_page.isXML() ) {
 					RequestParameter.Mobile	mob = param.judgeMobile();
 					switch( mob ) {
@@ -820,7 +889,7 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 				}
 				if ( buf == null )	buf = new StringBuilder( "text/html" );
 				buf = buf.append( "; charset=" );
-				mime = buf.append( next_page.getCharset() ).toString();
+				mime = buf.append( next_page.getParentPage().getCharset() ).toString();
 			}
 			res.setContentType( mime );
 			HTTPDate	date = next_page.getLastModified();
@@ -917,7 +986,7 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 			w.writeTo( res, new PrintWriter(
 				new OutputStreamWriter(
 					gz_out,
-					page.getCharset()
+					page.getParentPage().getCharset()
 				) )
 			);
 			gz_out.finish();
@@ -933,6 +1002,7 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 			String	key = (String)e.nextElement();
 			String[]	val = req.getParameterValues( key );
 			for ( int i = 0; i < val.length; i++ ) {
+				Option.trace( "%s=%s", key, val[i] );
 				ret.addItem( key, val[i] );
 			}
 		}
@@ -958,24 +1028,24 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 		PageFactory	fact = getPageFactory();
 		if ( fact.teapot_f )	return new Forward( 418 );
 		DataHolder	holder = new DataHolder( this, request );
-		HttpSession	session = request.getSession( false );
+		HttpSession	session = TransactionSequencer.getOriginSession( isMultiStageSession(), request, false );
 		SessionData	data = null;
 		if ( session == null ) {
-			data = new SessionData( request );
+			data = new SessionData( request, this );
 			holder.session_null = true;
 		}
 		else {
 			data = (SessionData)session.getAttribute( SESSION_DATA );
 			holder.session_null = false;
 			if ( data == null ) {
-				data = new SessionData( request );
+				data = new SessionData( request, this );
 				session.setAttribute( SESSION_DATA, data );
 				holder.session_null = true;
 			}
 			else if ( !data.isSame( request ) ) {
 				clear_session( session );
 				session = null;
-				data = new SessionData( request );
+				data = new SessionData( request, this );
 				holder.session_null = true;
 			}
 		}
@@ -985,7 +1055,7 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 		PathData	p = TransactionSequencer.parsePath( null, request.getRequestURI() , fact, null );
 		if ( p != null ) {
 			if ( p.from != null ) {
-				request.setCharacterEncoding( p.from.getCharset() );
+				request.setCharacterEncoding( p.from.getParentPage().getCharset() );
 			}
 		}
 		RequestParameter	req = null;
@@ -1046,20 +1116,119 @@ public abstract class Supervisor extends HttpServlet implements Cloneable {
 		return normalReq( request );
 	}
 
+	private static class SupervisorHolder {
+		private static volatile HashMap<Supervisor, ArrayList<SupervisorHolder>>	map = new HashMap<Supervisor, ArrayList<SupervisorHolder>>();
+		private volatile boolean used_f = false;
+		private Supervisor sv;
+		private SupervisorHolder( Supervisor org ) {
+			try {
+				sv = (Supervisor)org.clone();
+			}
+			catch( CloneNotSupportedException ce ){}
+		}
+		private static ArrayList<SupervisorHolder> getList( Supervisor org ) {
+			int	cnt = org.getRequestMaxCount();
+			if ( cnt < 1 )	return null;
+			ArrayList<SupervisorHolder>	list = null;
+			synchronized( map ) {
+				list = map.get( org );
+				if ( list == null ) {
+					list = new ArrayList<SupervisorHolder>();
+					map.put( org, list );
+				}
+			}
+			synchronized( list ) {
+				for ( int i = list.size(); i < cnt; i++ ) {
+					list.add( new SupervisorHolder( org ) );
+				}
+			}
+			return list;
+		}
+		private static Supervisor get( Supervisor org ) {
+			ArrayList<SupervisorHolder>	list = getList( org );
+			if ( list == null ) {
+				try {
+					return (Supervisor)org.clone();
+				}
+				catch( CloneNotSupportedException ce ){}
+			}
+			synchronized( list ) {
+				int cnt = list.size();
+				for ( int i = 0; i < cnt; i++ ) {
+					SupervisorHolder	sh = list.get( i );
+					if ( sh.used_f )	continue;
+					sh.used_f = true;
+					return sh.sv;
+				}
+			}
+			return null;
+		}
+		private static void free( Supervisor org, Supervisor sv ) {
+			if ( sv == null )	return;
+			ArrayList<SupervisorHolder>	list = getList( org );
+			if ( list == null )	return;
+			synchronized( list ) {
+				int	cnt = list.size();
+				for ( int i = 0; i < cnt; i++ ) {
+					SupervisorHolder	sh = list.get( i );
+					if ( sh.sv != sv )	continue;
+					sh.used_f = false;
+					break;
+				}
+			}
+		}
+	}
+
 	protected final void doGet( HttpServletRequest req, HttpServletResponse res )  {
+		Supervisor	sv = null;
 		try {
-			Supervisor	sv = (Supervisor)clone();
+			sv = SupervisorHolder.get( this );
+			if ( sv == null ) {
+				new Forward( 503 ).Action( this, res );
+				return;
+			}
+
+			String	mss = TransactionSequencer.makeNewMSSPath( sv.isMultiStageSession(), req );
+			if ( mss != null ) {
+				try {
+					mss = makeWithSessionURI( mss, null, null );
+				}
+				catch( Exception e ){}
+				res.sendRedirect( mss );
+				return;
+			}
 			sv.doMain( RequestParameter.Method.GET, req, res );
 		}
-		catch( CloneNotSupportedException ce ){}
+		catch( Exception e ) {
+			onErrorDebug( e, req, res );
+		}
+		finally {
+			SupervisorHolder.free( this, sv );
+		}
 	}
 
 	protected final void doPost( HttpServletRequest req, HttpServletResponse res )  {
+		Supervisor	sv = null;
 		try{
-			Supervisor	sv = (Supervisor)clone();
+			sv = SupervisorHolder.get( this );
+			if ( sv == null ) {
+				new Forward( 503 ).Action( this, res );
+				return;
+			}
+
+			String	mss = TransactionSequencer.makeNewMSSPath( sv.isMultiStageSession(), req );
+			if ( mss != null ) {
+				new Forward( 403 ).Action( sv, res );
+				return;
+			}
 			sv.doMain( RequestParameter.Method.POST, req, res );
 		}
-		catch( CloneNotSupportedException ce ){}
+		catch( Exception e ) {
+			onErrorDebug( e, req, res );
+		}
+		finally {
+			SupervisorHolder.free( this, sv );
+		}
 	}
 
 	private void doMain( RequestParameter.Method m, HttpServletRequest req, HttpServletResponse res )  {
