@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -44,7 +44,7 @@ public abstract class UploadableSupervisor extends Supervisor {
 		int	max = p.from.getUploadMaxBytes();
 		if ( max < 0 )	max = -1;
 		upload.setSizeMax( max );
-		upload.setHeaderEncoding( p.from.getCharset() );
+		upload.setHeaderEncoding( p.from.getParentPage().getCharset() );
 		List<?>	items = null;
 		try {
 			items = upload.parseRequest( req );
