@@ -205,10 +205,14 @@ public class Attribute implements Serializable {
 		AttributeValuable[]	v = getAll();
 		if ( v == null )	return null;
 		if ( v.length < 1 )	return null;
-		StringBuilder	buf = new StringBuilder( v[0].toString( mode ) );
+		String	first = v[0].toString( mode );
+		if ( first == null )	first = "";
+		StringBuilder	buf = new StringBuilder( first );
 		for ( int  i = 1; i < v.length; i++ ) {
 			buf = buf.append( "," );
-			buf = buf.append( v[i].toString( mode ) );
+			String	next = v[i].toString( mode );
+			if ( next == null )	continue;
+			buf = buf.append( next );
 		}
 		return buf.toString();
 	}
