@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009-2012  Akira Terasaki
+ * Copyright (c) 2009-2014  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -675,23 +675,16 @@ public class Tag extends HTMLPart {
 		if ( d instanceof Tag ) {
 			Tag tag = (Tag)d;
 			int	cnt = doc.size();
-			Tag	last_tag = null;
+			idx = 0;
 			synchronized( doc ) {
 				for ( HTMLPart p: doc ) {
 					if ( p == d )	break;
-					if ( p instanceof Tag )	last_tag = (Tag)p;
+					if ( p instanceof Tag )	idx++;
 				}
 			}
-			if ( last_tag != null ) {
-				synchronized( tag_only ) {
-					idx = tag_only.indexOf( last_tag );
-					if ( idx >= 0 ) {
-						tag_only.add( idx + 1, tag );
-					}
-					else	tag_only.add( tag );
-				}
+			synchronized( tag_only ) {
+				tag_only.add( idx, tag );
 			}
-			else	tag_only.add( tag );
 			getAssignedPage().nameTag( tag );
 			if ( tag.getAttribute( "name" ) != null )	makeID();
 			setLocation();
