@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -67,19 +67,18 @@ public class Button extends Input implements PageHooker, Clickable {
 		setClicked( false );
 	}
 
-	public boolean isClicked( RequestParameter req ) {
-		Form	form = getForm();
+	static boolean isClicked( RequestParameter req, Control ctl ) {
+		Form	form = ctl.getForm();
 		if ( form == null )	return false;
-		RequestItem	item = req.getItem( getNameAttribute() );
+		RequestItem	item = req.getItem( ctl.getNameAttribute() );
 		if ( item == null )	return false;
 		RequestItem	form_id = req.getItem( Form.FORM_ID );
 		if ( form_id == null )	return false;
-		if ( !form.getID().equals( form_id.getValue() ) )	return false;
-		String	iv = item.getValue();
-		if ( iv == null )	iv = "";
-		String	tv = getValueAttribute();
-		if ( tv == null )	tv = "";
-		return iv.equals( tv );
+		return	form.getID().equals( form_id.getValue() );
+	}
+
+	public boolean isClicked( RequestParameter req ) {
+		return isClicked( req, this );
 	}
 
 	/**
@@ -103,11 +102,15 @@ public class Button extends Input implements PageHooker, Clickable {
 	}
 
 	public void commitDaemon() {
+		setHandler( this );
+	}
+
+	static void setHandler( Tag t ) {
 		StringBuilder	buf = new StringBuilder( "function(ev){" );
 		buf = buf.append( "paraselene.form_kill=" );
-		buf = buf.append( isAjaxEnable()?	"false":	"true" );
+		buf = buf.append( t.isAjaxEnable()?	"false":	"true" );
 		buf = buf.append( ";}" );
-		setAnonymousEventHandler( "click", buf.toString() );
+		t.setAnonymousEventHandler( "click", buf.toString() );
 	}
 }
 
