@@ -14,11 +14,13 @@ import java.util.regex.*;
 import java.math.*;
 import paraselene.*;
 import paraselene.tag.*;
+import paraselene.ui.*;
+import paraselene.supervisor.*;
 
 /**
  * 入力部品基底クラス。
  */
-public abstract class Control extends Tag {
+public abstract class Control extends Tag implements PageHooker {
 	enum Status {
 		SELECTED("selected"),
 		DISABLED("disabled"),
@@ -484,5 +486,67 @@ public abstract class Control extends Tag {
 		}
 		return false;
 	}
+
+	/**
+	 * サブミット発生イベント。
+	 */
+	public enum SubmitEvent {
+		/** クリック時 */
+		CLICK( "click" ),
+		/** ダブルクリック時 */
+		DBLCLICK( "dblclick" ),
+		/** フォーカス獲得時 */
+		FOCUS( "focus" ),
+		/** フォーカス喪失時 */
+		BLUR( "focus" ),
+		/** 内容変更時 */
+		CHANGE( "change" );
+		private String event;
+		private String on;
+		private SubmitEvent( String e ) {
+			event = e;
+			on = "on" + e;
+		}
+		private void setHandler( Control ctl ) {
+			Form	form = ctl.getForm();
+			if ( form == null )	return;
+			ctl.removeAttribute( on );
+			String	func = form.getSubmitHandler();
+			if ( func == null ) {
+				StringBuilder	buf = new StringBuilder( form.makeID() );
+				buf = buf.append( ".submit();" );
+				ctl.setAttribute( on, buf.toString() );
+				return;
+			}
+			StringBuilder	buf = new StringBuilder( "function(ev){" );
+			buf = buf.append( func );
+			buf = buf.append( "(ev);" );
+			buf = buf.append( Form.get_id( form.makeID() ) );
+			buf = buf.append( ".submit();return true;}" );
+			ctl.setAnonymousEventHandler( event, buf.toString() );
+		}
+	}
+
+	private SubmitEvent[] submit_event = null;
+
+	/**
+	 * 指定イベントによりサブミットを発生させます。<br>
+	 * Ajax動作時か否かで、サブミット方法を変更します。<br>
+	 * onXXXXハンドラを書き換えるため、別のハンドラを指定している場合は
+	 * 使用しないで下さい。<br>
+	 * 初期状態はどのイベントでもサブミットしません。
+	 */
+	public void setSubmitEvent( SubmitEvent ... ev ) {
+		submit_event = ev;
+	}
+
+	public Forward beforeInput( Page page, RequestParameter req, Forward fw ) throws Exception { return fw; }
+	public void afterOutput( Page from, Page to, RequestParameter req ) throws Exception { commitDaemon(); }
+	public void commitDaemon() {
+		if ( submit_event == null )	return;
+		for ( SubmitEvent se: submit_event ) {
+			se.setHandler( this );
+		}
+	}
 }
 
