@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -89,6 +89,8 @@ public class Form extends Tag implements PageHooker {
 	}
 
 	private Input	form_ukey = Input.createHidden( FORM_ID, "-1" );
+	protected Input	form_ajax = Input.createHidden( FORM_AJAX, "-1" );
+	protected Input	form_dummy = Input.createHidden( FORM_DUMMY, "-1" );
 	private Input	page_ukey = Input.createHidden( PAGE_UKEY, "-1" );
 
 	/**
@@ -98,8 +100,8 @@ public class Form extends Tag implements PageHooker {
 		super( "form", false );
 		Input[]	id = new Input[] {
 			form_ukey,
-			Input.createHidden( FORM_AJAX, "-1" ),
-			Input.createHidden( FORM_DUMMY, "-1" ),
+			form_ajax,
+			form_dummy,
 			page_ukey
 		};
 		addHTMLPart( id );
@@ -137,16 +139,41 @@ public class Form extends Tag implements PageHooker {
 		}
 	}
 
+	/**
+	 * フレームワークが使用します。
+	 */
+	protected static String get_id( String id ) {
+		StringBuilder	buf = new StringBuilder( "paraselene.get_id('" );
+		buf = buf.append( id );
+		buf = buf.append( "')" );
+		return buf.toString();
+	}
 	public void commitDaemon() {
-		if ( !isAjaxEnable() )	return;
+		getSubmitHandler();
+	}
+
+	private String handler = null;
+
+	String getSubmitHandler() {
+		if ( handler != null )	return handler;
+		if ( !isAjaxEnable() )	return null;
 		StringBuilder	buf = new StringBuilder( "function(ev){" );
 		buf = buf.append( "if(paraselene.form_kill)return;" );
-		buf = buf.append( "if(!paraselene.agency_form(paraselene.get_id('" );
-		buf = buf.append( makeID() );
-		buf = buf.append( "'),'" );
+		buf = buf.append( "if(!paraselene.agency_form(" );
+		buf = buf.append( get_id( makeID() ) ).append( "," );
+		buf = buf.append( get_id( form_ajax.makeID() ) ).append( "," );
+		buf = buf.append( get_id( form_dummy.makeID() ) ).append( "," );
+		buf = buf.append( "'" );
 		buf = buf.append( getAssignedPage().getUniqueKey() );
 		buf = buf.append( "'))paraselene.kill_event(ev);}" );
-		setAnonymousEventHandler( "submit", buf.toString() );
+		return handler = setAnonymousEventHandler( "submit", buf.toString() );
+	}
+
+	/**
+	 * フレームワークが使用します。
+	 */
+	public void resetOnLoadScript() {
+		handler = null;
 	}
 
 	protected Tag newReplica() {
@@ -279,6 +306,7 @@ public class Form extends Tag implements PageHooker {
 		for ( int i = 0; i < cont.length; i++ ) {
 			String	name = cont[i].getNameAttribute();
 			if ( name == null )	continue;
+			Option.trace( "form[%s] %s", getID(), name );
 			if ( skip_name.get( name ) != null )	continue;
 			CheckBox	cbox = null;
 			if ( cont[i] instanceof CheckBox ) {
@@ -288,9 +316,9 @@ public class Form extends Tag implements PageHooker {
 					continue;
 				}
 			}
-			Button	button = null;
-			if ( cont[i] instanceof Button ) {
-				button = (Button)cont[i];
+			Clickable	button = null;
+			if ( cont[i] instanceof Clickable ) {
+				button = (Clickable)cont[i];
 				button.setClicked( false );
 			}
 			RequestItem	item = req.getItem( name );
@@ -316,7 +344,7 @@ public class Form extends Tag implements PageHooker {
 			}
 			if ( button != null ) {
 				button.setClicked( true );
-				set.add( button );
+				set.add( (Control)button );
 			}
 			else if ( cbox != null ) {
 				if ( !cbox.isChecked() ) {
