@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -57,7 +57,15 @@ public class Select extends Control implements PageHooker {
 		return copy4Replica( new Select() );
 	}
 
-	private void setup( HTMLPart d ) {
+	void setup( HTMLPart d ) {
+		if ( d instanceof SelectGroup ) {
+			SelectGroup	grp = (SelectGroup)d;
+			grp.list = this;
+			for ( SelectItem s: grp.getItemArray() ) {
+				setup( s );
+			}
+			return;
+		}
 		if ( !(d instanceof SelectItem) )	return;
 		SelectItem	item = (SelectItem)d;
 		item.list = this;
@@ -76,21 +84,36 @@ public class Select extends Control implements PageHooker {
 		setup( d );
 	}
 
-	/**
-	 * 選択項目の取得。
-	 * @return 選択項目の配列。
-	 */
-	public SelectItem[] getItemArray() {
-		Tag[]	tag = getTagArray();
+	static SelectItem[] getItemArray( Tag t ) {
+		Tag[]	tag = t.getTagArray();
 		ArrayList<SelectItem>	item = new ArrayList<SelectItem>();
 		for ( int i = 0; i < tag.length; i++ ) {
 			if ( tag[i] instanceof SelectItem ) {
 				item.add( (SelectItem)tag[i] );
 			}
+			else if ( tag[i] instanceof SelectGroup ) {
+				for ( SelectItem ret: getItemArray( tag[i] ) ) {
+					item.add( ret );
+				}
+			}
 		}
 		return item.toArray( new SelectItem[0] );
 	}
 
+	/**
+	 * 選択項目の取得。
+	 * @return 選択項目の配列。
+	 */
+	public SelectItem[] getItemArray() {
+		return getItemArray( this );
+	}
+
+	/**
+	 * 所属リスト取得。
+	 * @return リスト。
+	 */
+	public Select getSelect() { return this; }
+
 	/**
 	 * 値の取得。<br>
 	 * 選択されているOPTIONのvalueを返します。<br>
@@ -261,6 +284,7 @@ public class Select extends Control implements PageHooker {
 	}
 
 	public void commitDaemon() {
+		super.commitDaemon();
 		if ( !isAjaxEnable() )	return;
 		String	name = getNameAttribute();
 		if ( name == null )	return;
