@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -20,16 +20,98 @@ import paraselene.supervisor.*;
  * パスワード入力用ボックスであれば、ブラウザへvalueを返しません。
  */
 public class SingleTextBox extends Input implements PageHooker {
+	/**
+	 * テキスト種別。
+	 */
+	public enum Type {
+		/**
+		 * 通常テキスト。
+		 */
+		TEXT( Input.Type.TEXT ),
+		/**
+		 * パスワード用テキスト。
+		 */
+		PASSWORD( Input.Type.PASSWORD ),
+		/**
+		 * 検索用テキスト。
+		 */
+		SEARCH( Input.Type.SEARCH ),
+		/**
+		 * 電話番号用テキスト。
+		 */
+		TELEPHONE( Input.Type.TELEPHONE ),
+		/**
+		 * URL用テキスト。
+		 */
+		URL( Input.Type.URL ),
+		/**
+		 * 電子メール用テキスト。
+		 */
+		EMAIL( Input.Type.EMAIL ),
+		/**
+		 * タイムゾーン無し日時用テキスト。
+		 */
+		DATE_AND_TIME( Input.Type.DATE_AND_TIME ),
+		/**
+		 * 日付用テキスト。
+		 */
+		DATE( Input.Type.DATE ),
+		/**
+		 * 月用テキスト。
+		 */
+		MONTH( Input.Type.MONTH ),
+		/**
+		 * 週用テキスト。
+		 */
+		WEEK( Input.Type.WEEK ),
+		/**
+		 * 時間用テキスト。
+		 */
+		TIME( Input.Type.TIME ),
+		/**
+		 * タイムゾーン付き日時用テキスト。
+		 */
+		LOCAL_DATE_AND_TIME( Input.Type.LOCAL_DATE_AND_TIME ),
+		/**
+		 * 数値用テキスト。
+		 */
+		NUMBER( Input.Type.NUMBER ),
+		/**
+		 * 範囲用テキスト。
+		 */
+		RANGE( Input.Type.RANGE ),
+		/**
+		 * 色用テキスト。
+		 */
+		COLOR( Input.Type.COLOR );
+
+		Input.Type	text_type;
+		private Type( Input.Type t ) {
+			text_type = t;
+		}
+	}
+
 	private static final long serialVersionUID = 2L;
 	private boolean password_f = false;
 	private boolean hidden_f = false;
+	private Type	text_type;
+
 	/**
 	 * コンストラクタ。
 	 * @param pw_f true:パスワード、false:平文。
 	 */
 	public SingleTextBox( boolean pw_f ) {
-		super( pw_f?	Input.Type.PASSWORD: Input.Type.TEXT );
-		password_f = pw_f;
+		this( pw_f?	Type.PASSWORD: Type.TEXT );
+	}
+
+	/**
+	 * コンストラクタ。
+	 * @param type テキスト種別。
+	 */
+	public SingleTextBox( Type type ) {
+		super( type.text_type );
+		text_type = type;
+		password_f = type == Type.PASSWORD;
 	}
 
 	/**
@@ -41,7 +123,7 @@ public class SingleTextBox extends Input implements PageHooker {
 	}
 
 	protected Tag newReplica() {
-		return copy4Replica( new SingleTextBox( password_f ) );
+		return copy4Replica( new SingleTextBox( text_type ) );
 	}
 
 	/**
