@@ -153,6 +153,7 @@ public class TestSession implements HttpSession {
 		if ( !ok_f ) throw new IllegalStateException();
 		Object	old = session.get( name );
 		if ( old == null )	old = value;
+		else if ( old == value )	return;
 		else	removeAttribute( name );
 		session.put( name, value );
 		if ( value instanceof HttpSessionBindingListener ) {
@@ -197,6 +198,12 @@ public class TestSession implements HttpSession {
 		}
 		ok_f = false;
 	}
+	/**
+	 * フレームワークが使用します。
+	 */
+	public void reset() {
+		ok_f = true;
+	}
 
 	/**
 	 * 常にfalseを返します。
