@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009, 2010  Akira Terasaki
+ * Copyright (c) 2009-2011  Akira Terasaki
  * このファイルは同梱されている License.txt に定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -42,6 +42,8 @@ public class MimeType {
 		}
 	}
 
+	private static final String FIX_TYPE = "application/octet-stream";
+
 	/**
 	 * MIME Media Type の取得。拡張子から判定します。
 	 * @param file ファイル名。
@@ -49,10 +51,11 @@ public class MimeType {
 	 * 未知の拡張子であれば application/octet-stream を返します。
 	 */
 	public static String getMimeType( String file ) {
+		if ( file == null )	return FIX_TYPE;
 		String[]	ext = file.split( "\\." );
 		String	seek = ext[ext.length - 1].toLowerCase( Locale.ENGLISH );
 		String	ret = map.get( seek );
-		if ( ret == null )	return "application/octet-stream";
+		if ( ret == null )	return FIX_TYPE;
 		return ret;
 	}
 
@@ -63,6 +66,7 @@ public class MimeType {
 	 * 未知の拡張子であれば application/octet-stream を返します。
 	 */
 	public static String getMimeType( File file ) {
+		if ( file == null )	return FIX_TYPE;
 		return getMimeType( file.getName() );
 	}
 
@@ -74,6 +78,7 @@ public class MimeType {
 	 * @return 拡張子。未知の MIME Media Type であると null。
 	 */
 	public static String[] getExtension( String mime ) {
+		if ( mime == null )	return null;
 		String[]	type = mime.split( "/" );
 		HashMap<String, String[]>	sub = rev.get( type[0] );
 		if ( sub == null )	return null;
