@@ -1,4 +1,4 @@
-/* Paraselene Copyright (c) 2009, 2010  Akira Terasaki */
+/* Paraselene Copyright (c) 2009-2012  Akira Terasaki */
 Paraselene=function(){
 this.get_id_by_doc=function(doc,id){
 	if(doc.getElementById){
@@ -10,7 +10,7 @@ this.get_id_by_doc=function(doc,id){
 	}
 };
 this.get_id=function(id){
-	return this.get_id_by_doc(document,id);
+	return paraselene.get_id_by_doc(document,id);
 };
 
 /*
@@ -39,12 +39,22 @@ this.init=function(){
 	else if(ua.indexOf("MSIE")>=0){
 		paraselene.browser=500;
 	}
+	paraselene.back_kill_start();
+};
+
+this.add_css=function(s){
+	var head=document.getElementsByTagName("head")[0];
+	var tag=document.createElement("style");
+	tag.type="text/css";
+	if(tag.styleSheet)	tag.styleSheet.cssText=s;
+	else tag.appendChild(document.createTextNode(s));
+	head.appendChild(tag);
 };
 
 this.set_inner=function(tag,c){
 	if(!tag)	return tag;
 	tag.innerHTML="";
-	var doc=this.get_iframe_document("paraseleneOoltCloud");
+	var doc=paraselene.get_iframe_document(paraselene.OOLT);
 	doc.open();
 	doc.write('<html><head></head><body>' + c + '</body></html>');
 	doc.close();
@@ -101,13 +111,15 @@ this.TagSize=function(tag){
 };
 
 this.TagXY=function(tag){
-	this.x=parseInt(tag.style.left);
-	this.y=parseInt(tag.style.top);
-	if (!this.x && !this.y){
-		var rect=tag.getBoundingClientRect();
-		this.x=rect.left;
-		this.y=rect.top;
-	}
+	var rect=tag.getBoundingClientRect();
+	var sx=paraselene.max(window.pageXOffset,window.scrollLeft);
+	sx=paraselene.max(sx,document.documentElement.scrollLeft);
+	sx=paraselene.max(sx,document.body.scrollLeft);
+	var sy=paraselene.max(window.pageYOffset,window.scrollTop);
+	sy=paraselene.max(sy,document.documentElement.scrollTop);
+	sy=paraselene.max(sy,document.body.scrollTop);
+	this.x=Math.round(sx+rect.left);
+	this.y=Math.round(sy+rect.top);
 };
 
 this.tag_position=function(tag,x,y){
@@ -132,6 +144,33 @@ this.tag_position=function(tag,x,y){
 	tag.style.top=y+"px";
 };
 
+this.tag_align=function(tag,hint,pos){
+	var tag_size=new paraselene.TagSize(tag);
+	var hint_size=new paraselene.TagSize(hint);
+	var hint_xy=new paraselene.TagXY(hint);
+	var x,y;
+	switch(pos){
+	case 1:
+		x=hint_xy.x;
+		y=hint_xy.y-tag_size.height;
+		break;
+	case 2:
+		x=hint_xy.x;
+		y=hint_xy.y+hint_size.height;
+		break;
+	case 3:
+		x=hint_xy.x-tag_size.width;
+		y=hint_xy.y;
+		break;
+	case 4:
+		x=hint_xy.x+hint_size.width;
+		y=hint_xy.y;
+		break;
+	}
+	tag.style.left=x+"px";
+	tag.style.top=y+"px";
+};
+
 this.tag_center=function(tag,x,y){
 	var sc_x=document.documentElement.scrollLeft || document.body.scrollLeft;
 	var sc_y=document.documentElement.scrollTop || document.body.scrollTop;
@@ -191,6 +230,7 @@ this.safe_add_event=function(id,kind,func){
 this.kill_event=function(ev){
 	try {
 		ev=paraselene.get_event(ev);
+		if(ev.keyCode)ev.keyCode=0;
 		if(ev.preventDefault){
 			ev.preventDefault();
 		}
@@ -223,12 +263,22 @@ this.get_http=function(f){
 	case 300:
 	case 400:
 		obj.onload=function(){
+			url=obj.getResponseHeader('Location');
+			if (url){
+				paraselene.jumper(url);
+				return;
+			}
 			f(obj);
 		};
 		break;
 	default:
 		obj.onreadystatechange=function(){
 			if(obj.readyState==4){
+				url=obj.getResponseHeader('Location');
+				if (url){
+					paraselene.jumper(url);
+					return;
+				}
 				f(obj);
 			}
 		};
@@ -252,23 +302,25 @@ this.json_url_get=function(p){
 	return url;
 };
 
-this.back_kill_f=false;
-this.back_id;
+this.back_frag="__paraselene__";
+this.back_kill_f=true;
+this.back_kill_id;
 this.back_kill=function(){
-	if(!paraselene.back_kill_f) return;
-	history.forward();
-	paraselene.back_id=setTimeout(paraselene.back_kill,10);
+	if(!paraselene.back_kill_f)	return;
+	var part=document.location.href.split('#');
+	if(part[1]!=paraselene.back_frag){
+		history.forward();
+		part=document.location.href.split('#');
+		if(part[1]!=paraselene.back_frag)	document.location.href=part[0]+"#"+paraselene.back_frag;
+	}
+	paraselene.back_kill_id=setTimeout(paraselene.back_kill,10);
 };
-
 this.back_kill_start=function(){
-	if(paraselene.back_id){
-		clearTimeout(paraselene.back_id);
-	}
-	else{
-		document.location.href=document.location.href.split('#')[0]+"#__paraselene__";
-	}
-	paraselene.back_kill_f=true;
-	paraselene.back_kill();
+	paraselene.back_kill_id=setTimeout(paraselene.back_kill,10);
+};
+this.back_kill_stop=function(){
+	paraselene.back_kill_f=false;
+	clearTimeout(paraselene.back_kill_id);
 };
 
 this.page_drop_f=false;
@@ -283,18 +335,9 @@ this.comet_count=function() {
 
 this.popup=new Array();
 
-this.back_kill_stop=function(){
-	if(!paraselene.page_drop_f){
-		if(paraselene.comet_count()>0)	return;
-		if(paraselene.popup.length>0)	return;
-	}
-	paraselene.back_kill_f=false;
-};
-
 this.tag_remove=function(tag){
 	var out=tag.parentNode;
 	if(out) out.removeChild(tag);
-	if(paraselene.popup.length===0)	paraselene.back_kill_stop();
 };
 
 this.z_order=function(pop,del_f){
@@ -347,6 +390,30 @@ this.z_order=function(pop,del_f){
 };
 
 this.modal_count=0;
+this.menu_count=0;
+this.back_color_set=function(back){
+	if(paraselene.modal_count==0)	return;
+/*
+	if(paraselene.modal_count>paraselene.menu_count){
+		back.style.backgroundColor="black";
+		back.style.backgroundImage="url('image/eclipse.png/paraselene.resource.na')";
+		back.style.backgroundRepeat="repeat";
+	}else{
+		back.style.backgroundColor="TRANSPARENT";
+		back.style.backgroundImage="none";
+	}
+*/
+};
+
+this.back_handler=function(form,aj,dm,key){
+	if(paraselene.menu_count==0)	return false;
+	paraselene.agency_form(form,aj,dm,key);
+	var dialog=paraselene.popup[paraselene.popup.length-1];
+	var param=paraselene.get_id("paraseleneEclipseCloseId");
+	param.value=dialog.id;
+	form.submit();
+	return true;
+};
 
 this.back_resize=function(){
 	if(paraselene.modal_count===0)	return;
@@ -358,12 +425,13 @@ this.back_resize=function(){
 		x=paraselene.max(x,size.width);
 		y=paraselene.max(y,size.height);
 	}
-	var back=paraselene.get_id("paraseleneEclipse");
+	var back=paraselene.get_id(paraselene.wall);
 	back.style.height=y+"px";
 	back.style.width=x+"px";
 	setTimeout(paraselene.back_resize,200);
 };
 
+this.wall = "paraseleneEclipse";
 this.dialog_open=function(dialog){
 	var point=paraselene.get_id("paraseleneDragonsHead");
 	if(!point)	return;
@@ -376,7 +444,7 @@ this.dialog_open=function(dialog){
 
 	var z=paraselene.popup.length+dialog.base_z+1;
 	if(dialog.modal==true){
-		var back=paraselene.get_id("paraseleneEclipse");
+		var back=paraselene.get_id(paraselene.wall);
 		if(paraselene.modal_count<1){
 			back.style.zIndex=z;
 			back.style.display="block";
@@ -387,6 +455,10 @@ this.dialog_open=function(dialog){
 			back.style.zIndex++;
 			paraselene.modal_count++;
 		}
+		if(dialog.menu==true){
+			paraselene.menu_count++;
+		}
+		paraselene.back_color_set(back);
 	}
 	var base=document.createElement("div");
 	base.id=pageid;
@@ -395,7 +467,7 @@ this.dialog_open=function(dialog){
 	var body=document.createElement("div");
 	body.id=dialog.id;
 	body.style.background=dialog.bg;
-	body=this.set_inner(body,dialog.body);
+	body=paraselene.set_inner(body,dialog.body);
 	if(dialog.move==true){
 		base.className="paraselenePopupBase paraseleneTopOrder";
 		base.style.borderColor=dialog.border;
@@ -407,7 +479,7 @@ this.dialog_open=function(dialog){
 
 		var a=document.createElement("span");
 		a.className="paraselenePopupHead";
-		a=this.set_inner(a,dialog.title);
+		a=paraselene.set_inner(a,dialog.title);
 		head.appendChild(a);
 
 		body.className="paraselenePopupBody";
@@ -435,9 +507,9 @@ this.dialog_open=function(dialog){
 		paraselene.dialog_set_event(base,head);
 	}
 	else{
-		paraselene.tag_center(base,size.width/2,size.height/2);
+		if(dialog.position==0)	paraselene.tag_center(base,size.width/2,size.height/2);
+		else paraselene.tag_align(base,paraselene.get_id(dialog.hint_id),dialog.position);
 	}
-	paraselene.back_kill_start();
 };
 
 this.ClassZOrder=function(tag,n){
@@ -451,12 +523,8 @@ this.ClassZOrder=function(tag,n){
 
 this.url_cut=function(url){
 	var parts=url.split("//");
-	if(url.length<2)	return undefined;
-	var tail=parts[1];
-	for(var i=2;i<parts.length;i++){
-		tail=tail+"/"+parts[i];
-	}
-	var dir=tail.split("/");
+	if(parts.length<2)	return undefined;
+	var dir=parts[1].split("/");
 	var head=parts[0]+"//"+dir[0];
 	var foot="";
 	for(var i=1;i<dir.length;i++){
@@ -469,14 +537,14 @@ this.url_cut=function(url){
 this.jump_url=undefined;
 this.location_replace=function(next){
 	var org=undefined;
-	if(this.jump_url){
-		org=this.url_cut(this.jump_url);
+	if(paraselene.jump_url){
+		org=paraselene.url_cut(paraselene.jump_url);
 	}
-	this.jump_url=undefined;
+	paraselene.jump_url=undefined;
 	if(!org){
-		org=this.url_cut(window.location.href);
+		org=paraselene.url_cut(window.location.href);
 	}
-	var tgt=this.url_cut(next);
+	var tgt=paraselene.url_cut(next);
 	return org[0]+tgt[1];
 };
 
@@ -485,6 +553,17 @@ this.selected_index=function(form_id,name,no){
 	f.elements[name].options[no].selected=true;
 };
 
+this.jumper=function(loc){
+	paraselene.back_kill_stop();
+	document.location.href=document.location.href.split('#')[0]+"#_paraselene___";
+	if(paraselene.browser===300){
+		setTimeout(function(){
+			window.location.href=loc;
+		},100);
+	}
+	else window.location.href=loc;
+};
+
 this.forwarding=false;
 this.action=function(obj){
 	var resize_f=false;
@@ -493,12 +572,11 @@ this.action=function(obj){
 		if(val.location){
 			paraselene.form_reset();
 			paraselene.page_drop_f=true;
-			paraselene.back_kill_stop();
 			if(val.location_mine){
-				window.location.href=this.location_replace(val.location);
+				paraselene.jumper(paraselene.location_replace(val.location));
 			}
 			else{
-				window.location.href=val.location;
+				paraselene.jumper(val.location);
 			}
 			paraselene.forwarding=true;
 			continue;
@@ -516,7 +594,7 @@ this.action=function(obj){
 				paraselene.z_order(pop,true);
 			}
 			if(dialog.modal==true){
-				var back=paraselene.get_id("paraseleneEclipse");
+				var back=paraselene.get_id(paraselene.wall);
 				if(paraselene.modal_count>0)	paraselene.modal_count--;
 				if(paraselene.modal_count==0) {
 					back.style.display="none";
@@ -524,6 +602,10 @@ this.action=function(obj){
 				else{
 					back.style.zIndex--;
 				}
+				if(dialog.menu==true){
+					paraselene.menu_count--;
+				}
+				paraselene.back_color_set(back);
 			}
 			resize_f=true;
 			continue;
@@ -531,7 +613,7 @@ this.action=function(obj){
 		if(val.tag){
 			var update_tag=val.tag;
 			var target=paraselene.get_id(update_tag.id);
-			target=this.set_inner(target,update_tag.body);
+			target=paraselene.set_inner(target,update_tag.body);
 			resize_f=true;
 			if(update_tag.cmd)	paraselene.exec(update_tag.cmd);
 			continue;
@@ -566,10 +648,12 @@ this.url_check=function(url,param){
 	return url;
 };
 
-this.error_page=function(svr){
-	var err=svr.responseText;
-	document.open();
-	document.write(err);
+this.OOLT="paraseleneOoltCloud";
+this.rewrite_page=function(svr){
+	var txt=svr.responseText;
+	paraselene = undefined;
+	paraselene_init();
+	document.write(txt);
 	document.close();
 };
 
@@ -580,11 +664,16 @@ this.get_a=function(o,url,key){
 	var org=o.onclick;
 	var svr=paraselene.get_http(function(svr){
 			if(svr.status!=200){
-				paraselene.error_page(svr);
+				paraselene.rewrite_page(svr);
 			}
 			else{
 				o.onclick=org;
-				paraselene.action(eval('('+svr.responseText+')'));
+				try{
+					paraselene.action(eval('('+svr.responseText+')'));
+				}
+				catch(e){
+					paraselene.rewrite_page(svr);
+				}
 			}
 			document.body.style.cursor="auto";
 		}
@@ -620,9 +709,10 @@ this.agency_a=function(o,key){
 };
 
 this.called_form;
+this.form_ajax;
 this.form_org_action;
 
-this.agency_form=function(o,key){
+this.agency_form=function(o,aj,dm,key){
 	if(paraselene.forwarding)	return false;
 	if(!o)	return false;
 	if(!o.action)	return false;
@@ -636,11 +726,12 @@ this.agency_form=function(o,key){
 	paraselene.form_org_action=o.action;
 	var url=paraselene.url_check(o.action,undefined);
 	if(!url)	return true;
-	this.jump_url=o.action;
+	paraselene.jump_url=o.action;
 	o.target="paraseleneDragonsTail";
-	o.paraselene_form_ajax.value=key;
-	o.paraselene_dummy.value=paraselene.make_dummy();
+	aj.value=key;
+	dm.value=paraselene.make_dummy();
 	paraselene.called_form=o;
+	paraselene.form_ajax=aj;
 	return true;
 };
 
@@ -648,14 +739,14 @@ this.form_reset=function(){
 	if(!paraselene.called_form)return;
 	paraselene.called_form.action=paraselene.form_org_action;
 	paraselene.called_form.target="_self";
-	paraselene.called_form.paraselene_form_ajax.value=-1;
+	paraselene.form_ajax.value=-1;
 };
 
 this.get_form=function(key){
 	paraselene.form_reset();
 	var svr=paraselene.get_http(function(svr){
 			if(svr.status!=200){
-				paraselene.error_page(svr);
+				paraselene.rewrite_page(svr);
 			}
 			else{
 				paraselene.action(eval('('+svr.responseText+')'));
@@ -689,7 +780,7 @@ this.comet_start=function(id){
 	if(paraselene.comet_page[id])	return;
 	paraselene.comet_page[id]=true;
 	if(pre>0)	return;
-	paraselene.back_kill_start();
+	/*paraselene.back_kill_start();*/
 	paraselene.comet_callback();
 };
 
@@ -701,7 +792,6 @@ this.comet_stop=function(id){
 		paraselene.comet_svr.abort();
 		paraselene.comet_svr=undefined;
 	}
-	paraselene.back_kill_stop();
 };
 
 this.form_ok=function (key){
@@ -723,19 +813,24 @@ this.get_iframe_document=function( id ) {
 
 this.form_comp=function(){
 	if(!paraselene.called_form)	return;
-	var doc=this.get_iframe_document("paraseleneDragonsTail");
-	var cont="";
-	var head=doc.getElementsByTagName("head");
-	if(head){
-		if(head[0])	cont=head[0].innerHTML;
+	var doc=paraselene.get_iframe_document("paraseleneDragonsTail");
+	try{
+		var cont="";
+		var head=doc.getElementsByTagName("head");
+		var body=doc.getElementsByTagName("body");
+		if(head){
+			if(head[0])	cont=head[0].innerHTML;
+		}
+		if(body){
+			if(body[0])	cont+=body[0].innerHTML;
+		}
+		if(cont.indexOf("form_ok")>0)	return;
+		document.open();
+		document.write(cont);
+		document.close();
 	}
-	if(!doc.body && doc.body!=null){
-		cont+=doc.body.innerHTML;
+	catch(e){
 	}
-	if(cont.indexOf("form_ok")>0)	return;
-	document.open();
-	document.write(cont);
-	document.close();
 };
 
 this.get_key=function(ev){
@@ -752,11 +847,28 @@ this.kill_enter=function(ev){
 	}
 	return true;
 };
-
+this.get_lang=function(){
+	var ret=undefined;
+	try{
+		ret=(navigator.browserLanguage||navigator.language||navigator.userLanguage).substr(0,2);
+	}
+	catch(e){}
+	return ret;
+};
+this.unload_ask=function(ev){
+	if(!window.attachEvent)	return;
+	window.attachEvent("onbeforeunload",function(ev){
+		ev=paraselene.get_event(ev);
+		if(event.clientY>=0||ev.clientX>(document.body.clientWidth-32))    return;
+		return ev.returnValue="ja"==paraselene.get_lang()?
+		"画面の内容を失いますので、この画面から移動しないで下さい。":
+		"Since the contents of a screen are lost,\n\rplease do not move from this screen.";
+	});
+};
 };
 
 var paraselene;
-if(!paraselene){
+function paraselene_init(){
 	paraselene=new Paraselene();
 	paraselene.init();
 	document.onmouseup=function(kmouse){
@@ -781,4 +893,16 @@ if(!paraselene){
 		paraselene.move_y=kmouse.clientY;
 		return false;
 	};
+	document.onkeydown=function(ev){
+		var k=paraselene.get_key(ev);
+		if(k===116||k===82){
+			paraselene.kill_event(ev);
+			return false;
+		}
+		return true;
+	};
+	paraselene.unload_ask();
 }
+
+if(!paraselene)	paraselene_init();
+
